(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1082319,      20352]
NotebookOptionsPosition[   1063374,      20045]
NotebookOutlinePosition[   1063773,      20061]
CellTagsIndexPosition[   1063730,      20058]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LJ - Gaussian example", "Chapter",
 CellChangeTimes->{{3.921767241734104*^9, 
  3.921767245671411*^9}},ExpressionUUID->"23601fc3-e0e5-4798-8a4b-\
a7d16a3bcd44"],

Cell[CellGroupData[{

Cell["General setup", "Section",
 CellChangeTimes->{{3.9221848420508966`*^9, 
  3.922184845328759*^9}},ExpressionUUID->"c7ed6467-48d7-42a3-aca2-\
a8261b9fba92"],

Cell["\<\
Working precision.  Needs to be larger for larger nG (e.g., for nG = 5, this \
should be at about 70 if not using Mathematica\[CloseCurlyQuote]s Fit \
function)\
\>", "Text",
 CellChangeTimes->{{3.922106965719241*^9, 3.9221069680211678`*^9}, {
  3.922112321663707*^9, 3.9221123273293037`*^9}, {3.9221124099933023`*^9, 
  3.922112424796204*^9}, {3.922119530556295*^9, 
  3.9221195391854763`*^9}},ExpressionUUID->"3b5c7d96-f407-4175-a36b-\
70a68849c994"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wp", "=", "MachinePrecision"}]], "Code",
 CellChangeTimes->{{3.922103160457723*^9, 3.92210316679283*^9}, {
  3.922105345251906*^9, 3.922105345607581*^9}, {3.922112318849591*^9, 
  3.922112319042243*^9}, {3.922112373609179*^9, 3.9221123739972477`*^9}, {
  3.922122888786578*^9, 3.922122890855698*^9}},
 CellLabel->
  "In[507]:=",ExpressionUUID->"449ee415-9749-497e-9f30-59a880abade1"],

Cell[BoxData["MachinePrecision"], "Output",
 CellChangeTimes->{3.922103167729281*^9, 3.922105355598194*^9, 
  3.922112329925974*^9, 3.922112375593453*^9, 3.92212289135865*^9, 
  3.922211700111459*^9, 3.9223757816321793`*^9},
 CellLabel->
  "Out[507]=",ExpressionUUID->"0661305a-8618-4bbd-a5cb-23f706295e35"]
}, Open  ]],

Cell["Lennard-Jones potential, \[Sigma] = \[Epsilon] = 1", "Text",
 CellChangeTimes->{{3.922106974481771*^9, 3.9221069784197206`*^9}, {
  3.922107015725737*^9, 
  3.922107027451703*^9}},ExpressionUUID->"9a762c31-5374-40b5-be1f-\
200e16b19914"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uLJ", "[", "r_", "]"}], ":=", 
  RowBox[{"4", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"-", "12"}]], " ", "-", " ", 
     SuperscriptBox["r", 
      RowBox[{"-", "6"}]]}], ")"}]}]}], "\n", 
 RowBox[{"LJplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"uLJ", "[", "r", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<r\>\"", ",", "\"\<u(r)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Green", ",", "Dashed"}], "}"}]}]}], "]"}]}]}], "Code",
 CellChangeTimes->{{3.922106990845879*^9, 3.922107010595488*^9}, {
  3.922107204890545*^9, 3.922107210832079*^9}},
 CellLabel->
  "In[508]:=",ExpressionUUID->"87194c35-81e1-44c5-83d4-7ac94719265f"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"uLJ", "[", "r", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "Automatic"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\<\"r\"\>", ",", "\<\"u(r)\"\>"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", "Dashed"}], "}"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.9221072119247093`*^9, 3.922211700333174*^9, 
  3.922375782157468*^9},
 CellLabel->
  "Out[509]=",ExpressionUUID->"76648d72-e1a9-47ee-9ff4-f1df315673f4"]
}, Open  ]],

Cell["\<\
Unnormalized Gaussian function, to be used as descriptors, using  r0  from \
rminG to rmaxG and standard deviations over the same range
Don\[CloseCurlyQuote]t rescale based on integrals from rmin,rmax, but use \
rminG,rmaxG to ensure functions are nonzero in scaling range\
\>", "Text",
 CellChangeTimes->{{3.922119478528193*^9, 3.922119493416862*^9}, {
  3.9221271582957783`*^9, 3.922127194546308*^9}, {3.9221905596080837`*^9, 
  3.9221906166157417`*^9}},ExpressionUUID->"b958213a-f532-43f0-b69e-\
26c60017b2fd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"r_", ",", "r0_", ",", "\[Sigma]_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"r", "-", "r0"}], ")"}], "2"], 
     SuperscriptBox["\[Sigma]", "2"]]}], "]"}]}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{"rminG", ",", "rmaxG"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"gaussUmean", "=", 
   FractionBox[
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"gauss", "[", 
       RowBox[{"r", ",", "r0", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}]}], "]"}], 
    RowBox[{"rmaxG", "-", "rminG"}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"gaussUstdDev", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"gauss", "[", 
           RowBox[{"r", ",", "r0", ",", "\[Sigma]"}], "]"}], "-", 
          "gaussUmean"}], ")"}], "2"], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}]}], "]"}], "]"}]}], 
   ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"gaussU", "[", 
   RowBox[{"r_", ",", "r0_", ",", "\[Sigma]_"}], "]"}], ":=", 
  RowBox[{"Release", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"r", ",", "r0", ",", "\[Sigma]"}], "]"}], "-", "gaussUmean"}], 
    "gaussUstdDev"], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"gaussU", "[", 
     RowBox[{"r", ",", "r0", ",", "\[Sigma]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\n", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"gaussU", "[", 
      RowBox[{"r", ",", "r0", ",", "\[Sigma]"}], "]"}], "2"], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Code",
 CellChangeTimes->{{3.9221194969156427`*^9, 3.922119504889126*^9}, {
   3.92212720508497*^9, 3.922127222359229*^9}, {3.922127394447166*^9, 
   3.922127402546926*^9}, {3.922188434739624*^9, 3.922188629872362*^9}, {
   3.922188688288602*^9, 3.9221887873502197`*^9}, {3.922188829831347*^9, 
   3.922189092500637*^9}, {3.922189134464294*^9, 3.922189231902514*^9}, {
   3.922189349454679*^9, 3.922189367745618*^9}, 3.922189402059383*^9, {
   3.922189492009025*^9, 3.9221894995144167`*^9}, {3.922190524012978*^9, 
   3.922190553238929*^9}, {3.92221394188743*^9, 3.922213958565939*^9}},
 CellLabel->
  "In[510]:=",ExpressionUUID->"3dab6a2a-3768-4e20-99d3-4e982fdd22a0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.922188461690983*^9, {3.92218850951237*^9, 3.922188519667602*^9}, {
   3.922188550662906*^9, 3.922188631741132*^9}, {3.922188696253348*^9, 
   3.922188734410053*^9}, 3.922188788390381*^9, {3.9221888312338333`*^9, 
   3.92218883783453*^9}, 3.922189048792447*^9, {3.922189082594199*^9, 
   3.922189093178827*^9}, 3.922189142844441*^9, {3.922189178079356*^9, 
   3.922189193217972*^9}, 3.922189235263892*^9, {3.922189484216505*^9, 
   3.922189501245158*^9}, 3.922190556118922*^9, 3.9221906190573883`*^9, {
   3.922211701572191*^9, 3.922211702790984*^9}, 3.9222139692974443`*^9, 
   3.9223757857585697`*^9},
 CellLabel->
  "Out[515]=",ExpressionUUID->"03bf7523-0e2d-4cc6-9b2b-3a4bcc852985"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.922188461690983*^9, {3.92218850951237*^9, 3.922188519667602*^9}, {
   3.922188550662906*^9, 3.922188631741132*^9}, {3.922188696253348*^9, 
   3.922188734410053*^9}, 3.922188788390381*^9, {3.9221888312338333`*^9, 
   3.92218883783453*^9}, 3.922189048792447*^9, {3.922189082594199*^9, 
   3.922189093178827*^9}, 3.922189142844441*^9, {3.922189178079356*^9, 
   3.922189193217972*^9}, 3.922189235263892*^9, {3.922189484216505*^9, 
   3.922189501245158*^9}, 3.922190556118922*^9, 3.9221906190573883`*^9, {
   3.922211701572191*^9, 3.922211702790984*^9}, 3.9222139692974443`*^9, 
   3.922375787005233*^9},
 CellLabel->
  "Out[516]=",ExpressionUUID->"dd5d4189-f9e7-4003-b765-fd5cacef2098"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Routine to generate data and descriptor functions",
  FontWeight->"Bold"],
 "\nA set of Gaussian \[OpenCurlyDoubleQuote]descriptor functions\
\[CloseCurlyDoubleQuote] are defined, with all combinations of nMuSig means \
ranging from rminG to rmaxG, and nG standard deviations over the same range.  \
\nHence, total number of descriptor functions is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["nG", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "36a63966-b91b-4763-840a-3bc8f84dc1f9"],
 ".\n\nTraining, validation, and test data are given by selecting points \
uniformly at random in range from rmin to rmax (which is inside (rminG, \
rmaxG) range)\nGenerate values with precision specified by wp"
}], "Text",
 CellChangeTimes->{{3.9221070426155977`*^9, 3.922107107892906*^9}, {
   3.922107239699999*^9, 3.922107282379614*^9}, 3.92212717652547*^9, {
   3.922127319680326*^9, 3.922127334856503*^9}, {3.922127422773905*^9, 
   3.922127466450252*^9}, {3.9221276310565166`*^9, 3.922127723551547*^9}, {
   3.922189455357285*^9, 
   3.922189461162937*^9}},ExpressionUUID->"60803014-f32d-4fda-96f8-\
cb987c21117c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"standardize", "[", "data_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"mean", ",", "stdev"}], "}"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{"mean", "=", 
      RowBox[{"Mean", "[", "data", "]"}]}], ";", "\n", "\t", 
     RowBox[{"stdev", "=", 
      RowBox[{"StandardDeviation", "[", "data", "]"}]}], ";", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{"mean", ",", "stdev", ",", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"data", "-", "mean"}], ")"}], "stdev"]}], "}"}]}]}], "\n", 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"generate", "[", 
    RowBox[{
    "nMuSig_", ",", " ", "nTrain_", ",", "nValidate_", ",", "nTest_"}], "]"}],
    ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\n", "\t", 
     RowBox[{
      RowBox[{"rminG", "=", 
       RowBox[{"2", "/", "10"}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"rmaxG", "=", "5"}], ";", "\n", "\n", "\t", 
      RowBox[{"rmin", "=", 
       RowBox[{"9", "/", "10"}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"rmax", "=", "3"}], ";", "\n", "\n", "\t", 
      RowBox[{"nG", " ", "=", " ", "nMuSig"}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"nX", " ", "=", " ", 
       SuperscriptBox["nG", "2"]}], ";", "\n", "\n", "\t", 
      RowBox[{"R0", "=", 
       RowBox[{"Subdivide", "[", 
        RowBox[{"rminG", ",", "rmaxG", ",", 
         RowBox[{"nG", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"S0", "=", 
       RowBox[{"Subdivide", "[", 
        RowBox[{"rminG", ",", "rmaxG", ",", 
         RowBox[{"nG", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"functionList", "[", "r_", "]"}], "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"gaussU", "[", 
           RowBox[{"r", ",", "R", ",", "S"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"R", ",", "R0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S", ",", "S0"}], "}"}]}], "]"}], "]"}]}], ";", "\n", "\t",
       "\n", "\t", 
      RowBox[{"rTrain", "=", 
       RowBox[{"RandomReal", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"rmin", ",", "rmax"}], "}"}], ",", "nTrain", ",", 
         RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rValidate", "=", 
       RowBox[{"RandomReal", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"rmin", ",", "rmax"}], "}"}], ",", "nValidate", ",", 
         RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rTest", "=", 
       RowBox[{"RandomReal", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"rmin", ",", "rmax"}], "}"}], ",", "nTest", ",", 
         RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\n", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"yTrainMean", ",", "yTrainStdev", ",", "yTrain"}], "}"}], "=", 
       RowBox[{"standardize", "[", 
        RowBox[{"uLJ", "[", "rTrain", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"yValidate", "=", 
       RowBox[{"uLJ", "[", "rValidate", "]"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"yTest", "=", 
       RowBox[{"uLJ", "[", "rTest", "]"}]}], ";", "\n", "\t", "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Collect", " ", "training", " ", "data", " ", "into", " ", "one", " ", 
        "array", " ", "for", " ", "use", " ", "by", " ", 
        RowBox[{"Mathematica", "'"}], "s", " ", "Fit", " ", "function"}], " ",
        "*)"}], "\n", "\t", 
      RowBox[{"dataTrain", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"rTrain", ",", "yTrain"}], "}"}], "]"}]}], ";", "\n", "\t", 
      "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Construct", " ", "design", " ", 
         RowBox[{"matrix", ".", "  ", "Each"}], " ", "column", " ", 
         "represents", " ", "a", " ", "different", " ", "descriptor"}], ",", 
        " ", 
        RowBox[{"each", " ", "row", " ", "is", " ", "a", " ", "data", " ", 
         RowBox[{"value", ".", "  ", "\n", "\t", "Size"}], " ", "of", " ", 
         "matrix", " ", "is", " ", "nTrain", " ", "x", " ", 
         FormBox[
          SuperscriptBox["nG", "2"],
          TraditionalForm]}]}], " ", "*)"}], "\n", "\t", 
      RowBox[{"X", "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"functionList", "[", "rTrain", "]"}]}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "evaluate", " ", "each", " ", "descriptor", " ", "function", " ", 
        "for", " ", "each", " ", "training", " ", "value", " ", "of", " ", 
        "r"}], " ", "*)"}], "\n", "\n", "\t", "printParams"}]}], "\n", 
    "]"}]}], "\n"}], "\n", 
 RowBox[{"printParams", " ", ":=", " ", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<nTrain: \>\"", ",", 
    RowBox[{"Length", "[", "yTrain", "]"}], ",", "\"\<, nValidate: \>\"", ",", 
    RowBox[{"Length", "[", "yValidate", "]"}], ",", "\"\<, nTest: \>\"", ",", 
    
    RowBox[{"Length", "[", "yTest", "]"}], ",", "\"\<\\nnGaussians: \>\"", 
    ",", 
    RowBox[{"Length", "[", 
     RowBox[{"functionList", "[", "x", "]"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Code",
 CellChangeTimes->{{3.921767249495019*^9, 3.921767262437169*^9}, {
   3.921767399901505*^9, 3.921767410139071*^9}, {3.9217674735129013`*^9, 
   3.9217675049548817`*^9}, {3.9217675520619397`*^9, 3.921767643321748*^9}, {
   3.921767749892702*^9, 3.921767776125701*^9}, {3.921767974166905*^9, 
   3.921768063581156*^9}, {3.921768098957837*^9, 3.921768160583704*^9}, {
   3.921768262778734*^9, 3.921768341298634*^9}, {3.921768428585559*^9, 
   3.921768437556791*^9}, {3.921768471453003*^9, 3.9217684870577183`*^9}, {
   3.921768518637587*^9, 3.921768552150243*^9}, {3.9217685862083817`*^9, 
   3.921768665916349*^9}, {3.921768733711749*^9, 3.921768756150484*^9}, {
   3.921768892973608*^9, 3.921768893138657*^9}, {3.921768958212615*^9, 
   3.921768965873961*^9}, {3.921769049851117*^9, 3.921769080859728*^9}, {
   3.9217691379790983`*^9, 3.921769138125409*^9}, {3.921769565220479*^9, 
   3.921769565511252*^9}, 3.921769600561656*^9, {3.92176963614723*^9, 
   3.921769636815024*^9}, {3.921769679466683*^9, 3.92176971842272*^9}, {
   3.921769980720483*^9, 3.92177003393289*^9}, {3.921770116329375*^9, 
   3.921770135563398*^9}, {3.921770171589291*^9, 3.921770171898361*^9}, {
   3.92177089023641*^9, 3.921770890997641*^9}, 3.921771022820215*^9, {
   3.921771129554091*^9, 3.921771129926375*^9}, 3.921771299681567*^9, {
   3.92178523016527*^9, 3.921785282630772*^9}, {3.9217853319176908`*^9, 
   3.921785344719543*^9}, {3.921785375433103*^9, 3.921785422986459*^9}, {
   3.9217854580272818`*^9, 3.921785458617261*^9}, {3.921785502275107*^9, 
   3.921785504502082*^9}, {3.921785590411439*^9, 3.921785590747122*^9}, {
   3.921785620946396*^9, 3.921785628408018*^9}, {3.921853957698045*^9, 
   3.921853984791742*^9}, {3.921854066723813*^9, 3.921854068596257*^9}, {
   3.921854479801734*^9, 3.921854484940096*^9}, {3.922095204880315*^9, 
   3.922095231192441*^9}, 3.9220953009855337`*^9, {3.9220953484083643`*^9, 
   3.922095349381573*^9}, {3.922095519249373*^9, 3.9220955404308643`*^9}, {
   3.922096232196516*^9, 3.922096239965008*^9}, {3.922096850697114*^9, 
   3.922096854959112*^9}, {3.922102011527937*^9, 3.922102022752664*^9}, {
   3.922102063165558*^9, 3.92210207773489*^9}, {3.922102164755661*^9, 
   3.922102183899877*^9}, {3.9221022654147997`*^9, 3.922102314659083*^9}, {
   3.9221023568097067`*^9, 3.922102388390471*^9}, {3.922102423453776*^9, 
   3.922102493578825*^9}, {3.922102523658333*^9, 3.922102524595885*^9}, {
   3.922102684462058*^9, 3.922102709185595*^9}, {3.922103118796483*^9, 
   3.922103127294109*^9}, 3.922105342035008*^9, {3.92210566135441*^9, 
   3.922105663216909*^9}, {3.92210578020595*^9, 3.922105784425244*^9}, {
   3.922105838679043*^9, 3.922105861894049*^9}, {3.9221059405789633`*^9, 
   3.922105979041681*^9}, {3.922106940961219*^9, 3.92210695009711*^9}, 
   3.922106985995311*^9, 3.922107032346763*^9, {3.922107118085547*^9, 
   3.922107167175012*^9}, {3.922107304962692*^9, 3.922107342867562*^9}, {
   3.922107381502935*^9, 3.92210738165908*^9}, {3.922107787072102*^9, 
   3.922107794294764*^9}, {3.922112351976295*^9, 3.922112352141512*^9}, {
   3.922113049675775*^9, 3.922113049841988*^9}, {3.922113081165963*^9, 
   3.922113081709364*^9}, {3.9221133552448273`*^9, 3.922113355402982*^9}, {
   3.922114010196486*^9, 3.92211401051313*^9}, {3.922117322783635*^9, 
   3.922117333651284*^9}, {3.922117364487043*^9, 3.922117547808544*^9}, {
   3.922117720716032*^9, 3.922117725290547*^9}, {3.922118421758105*^9, 
   3.922118427858367*^9}, 3.922119464634965*^9, {3.922120360847546*^9, 
   3.92212036169675*^9}, {3.922124708580836*^9, 3.922124709815744*^9}, {
   3.922125297464758*^9, 3.92212529794582*^9}, {3.922125759396271*^9, 
   3.922125760461957*^9}, {3.922127203044351*^9, 3.922127303151713*^9}, {
   3.922127360946864*^9, 3.922127390936178*^9}, {3.922127472187161*^9, 
   3.922127485422274*^9}, {3.9221275224328547`*^9, 3.922127546876564*^9}, {
   3.9221276134698544`*^9, 3.92212762096129*^9}, {3.922127793481163*^9, 
   3.9221278060138073`*^9}, {3.922127899789584*^9, 3.922128089049699*^9}, {
   3.922134640424175*^9, 3.922134642621953*^9}, 3.922189408789647*^9, {
   3.922189442907759*^9, 3.92218944350229*^9}, {3.9221895197158337`*^9, 
   3.9221895298272943`*^9}, {3.9221922858607473`*^9, 3.922192342809507*^9}, {
   3.922211744968351*^9, 3.922211829091385*^9}, {3.922211921328425*^9, 
   3.922211923246855*^9}, {3.922212075419894*^9, 3.922212122560829*^9}, {
   3.922212246940691*^9, 3.9222122490533*^9}, {3.922212995263153*^9, 
   3.9222130502816887`*^9}, {3.922214019093809*^9, 3.922214022940164*^9}},
 CellLabel->
  "In[523]:=",ExpressionUUID->"1fc4fead-e35e-4041-b6ee-28b0d9ccffe0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nT", "=", "750"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"generate", "[", 
   RowBox[{"10", ",", " ", "nT", ",", 
    RowBox[{"Round", "[", 
     RowBox[{"nT", "/", "3"}], "]"}], ",", "250"}], "]"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"Look", " ", "at", " ", "data"}], " ", "*)"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "note", " ", "how", " ", "to", " ", "recover", " ", "original", " ", 
    "data", " ", "from", " ", "standardized", " ", "values"}], " ", 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"dataPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{"rTrain", ",", 
        RowBox[{
         RowBox[{"yTrain", "*", "yTrainStdev"}], "+", "yTrainMean"}]}], 
       "}"}]}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.2"}], ",", ".2"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"dataPlot", ",", "LJplot"}], "]"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922108053560368*^9, 3.922108100473284*^9}, {
   3.922111896698964*^9, 3.9221119003793497`*^9}, {3.922112705314228*^9, 
   3.92211270543927*^9}, {3.92211279074078*^9, 3.922112791324767*^9}, {
   3.922113345194603*^9, 3.922113368871005*^9}, {3.922113984409155*^9, 
   3.922114013540566*^9}, {3.922117860027944*^9, 3.922117861414617*^9}, {
   3.922123231361436*^9, 3.922123233757242*^9}, {3.922124717956887*^9, 
   3.922124718337698*^9}, {3.922125062653253*^9, 3.9221250637007847`*^9}, {
   3.9221253015077057`*^9, 3.922125301770901*^9}, {3.922125750757746*^9, 
   3.922125751289844*^9}, {3.922126630479169*^9, 3.922126630950957*^9}, 
   3.922127357721752*^9, {3.92212758716308*^9, 3.922127604289287*^9}, {
   3.922127735571537*^9, 3.922127791178904*^9}, {3.9221923697767487`*^9, 
   3.922192372060285*^9}, {3.9222121373028927`*^9, 3.922212212230146*^9}, {
   3.922212264341276*^9, 3.922212298708218*^9}},
 CellLabel->
  "In[526]:=",ExpressionUUID->"4eb19f65-833f-4e8b-9808-37d43ec6f9cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "100"}],
  SequenceForm[
  "nTrain: ", 750, ", nValidate: ", 250, ", nTest: ", 250, "\nnGaussians: ", 
   100],
  Editable->False]], "Print",
 CellChangeTimes->{{3.92212798493204*^9, 3.922127994217233*^9}, {
   3.922128082078931*^9, 3.922128091342815*^9}, 3.922134691657514*^9, {
   3.922192315978547*^9, 3.922192372417354*^9}, {3.922212129718073*^9, 
   3.92221221314981*^9}, {3.92221225352282*^9, 3.92221229936902*^9}, 
   3.922375791638241*^9},
 CellLabel->
  "During evaluation of \
In[526]:=",ExpressionUUID->"7a72eda6-b2f5-4427-a3a0-375fd33f35d1"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    InterpretationBox[{
      TagBox[
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.0055000000000000005`], AbsoluteThickness[2], 
         PointBox[CompressedData["
1:eJwVmHc81f8fxe+97iUjJKEllUppSIuk91tJSJI0lIQIDau+RmY2WdmEkFmy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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ],
       {"WolframDynamicHighlight", <|
        "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
      StyleBox[
       DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
         Slot["HighlightElements"], 
         Slot["LayoutOptions"], 
         Slot["Meta"], 
         Charting`HighlightActionFunction["DynamicHighlight", {{
            Annotation[{
              Directive[
               PointSize[0.0055000000000000005`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Point[CompressedData["
1:eJwVmHc81f8fxe+97iUjJKEllUppSIuk91tJSJI0lIQIDau+RmY2WdmEkFmy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               "]]}, "Charting`Private`Tag#1"]}}, <|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
           "LayoutOptions" -> <|
            "PanelPlotLayout" -> <||>, 
             "PlotRange" -> {{0.8598959561871841, 2.989129331521271}, {-1.2, 
              0.2}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0.8598959561871841, 0}, 
             "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
             "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                PointSize[0.0055000000000000005`], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> ListPlot, "GroupHighlight" -> False|>|>]]& )[<|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.8598959561871841, 2.989129331521271}, {-1.2, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.8598959561871841, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[0.0055000000000000005`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListPlot, "GroupHighlight" -> False|>|>],
        ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
         4.503599627370496*^15, -4.503599627370496*^15}}],
       Selectable->False]},
     Annotation[{{
        Annotation[{
          Directive[
           PointSize[0.0055000000000000005`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Point[CompressedData["
1:eJwVmHc81f8fxe+97iUjJKEllUppSIuk91tJSJI0lIQIDau+RmY2WdmEkFmy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           "]]}, "Charting`Private`Tag#1"]}}, <|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
       "LayoutOptions" -> <|
        "PanelPlotLayout" -> <||>, 
         "PlotRange" -> {{0.8598959561871841, 2.989129331521271}, {-1.2, 
          0.2}}, "Frame" -> {{False, False}, {False, False}}, 
         "AxesOrigin" -> {0.8598959561871841, 0}, 
         "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
         "DefaultStyle" -> {
           Directive[
            PointSize[0.0055000000000000005`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         ListPlot, "GroupHighlight" -> False|>|>, 
      "DynamicHighlight"]], {{}, {}}}, 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.8598959561871841, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.8598959561871841, 2.989129331521271}, {-1.2, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9221277729484186`*^9, 3.9221278093138037`*^9, {3.922127985080914*^9, 
   3.922127994354991*^9}, {3.922128082227607*^9, 3.9221280915015993`*^9}, 
   3.92213469190515*^9, {3.9221923161637683`*^9, 3.922192372631043*^9}, {
   3.922212129965209*^9, 3.9222122133585567`*^9}, {3.9222122536439333`*^9, 
   3.92221229950268*^9}, 3.922375791917758*^9},
 CellLabel->
  "Out[529]=",ExpressionUUID->"f6649820-ba36-4f18-a7a0-4de4659b60d6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ordinary least squares (OLS)", "Section",
 CellChangeTimes->{{3.922106922343667*^9, 3.922106926434952*^9}, {
  3.922213178210814*^9, 
  3.9222131794550133`*^9}},ExpressionUUID->"1ecec569-c719-4c5b-a58d-\
b38e56023403"],

Cell[CellGroupData[{

Cell["Direct implementation", "Subsection",
 CellChangeTimes->{{3.922126982387587*^9, 
  3.922126985207913*^9}},ExpressionUUID->"0a33d9a9-249e-4d2b-8ba4-\
9267eba4d7e9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wp", "=", "700"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"generate", "[", 
  RowBox[{"5", ",", "300", ",", "100", ",", "100"}], "]"}]}], "Input",
 CellChangeTimes->{{3.922185200940734*^9, 3.922185212373685*^9}, {
  3.922185307104663*^9, 3.922185307598446*^9}, {3.922185404114911*^9, 
  3.922185404546729*^9}, {3.9221855202880077`*^9, 3.922185521249258*^9}, {
  3.922185562750361*^9, 3.922185622079401*^9}, {3.922190759182759*^9, 
  3.922190762695455*^9}, {3.922190793612718*^9, 3.922190793722234*^9}, {
  3.922192455021052*^9, 3.922192455284052*^9}, {3.9221928157563*^9, 
  3.922192816331373*^9}, {3.922192968512174*^9, 3.922192970497777*^9}, {
  3.922212377404715*^9, 3.9222123829645147`*^9}, {3.92237581204218*^9, 
  3.922375816838634*^9}, {3.92237586839747*^9, 3.92237586851475*^9}, {
  3.9223759236755533`*^9, 3.922375951895029*^9}, {3.9223760391651077`*^9, 
  3.922376041888954*^9}, {3.922376101379498*^9, 3.92237610231196*^9}},
 CellLabel->
  "In[595]:=",ExpressionUUID->"4deff788-0de7-4c0b-abe4-226632fdbf71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "300", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 300, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.9221852137068768`*^9, 3.922185247347394*^9, 3.9221853092753553`*^9, 
   3.922185342781028*^9, 3.922185407784771*^9, {3.922185513221671*^9, 
   3.9221855282402477`*^9}, {3.922185564540565*^9, 3.922185623326832*^9}, 
   3.922189758262225*^9, 3.922189812677332*^9, 3.922190764254816*^9, 
   3.922190794535063*^9, 3.922192455802403*^9, 3.922192970964295*^9, 
   3.92221233155907*^9, 3.922212383563914*^9, {3.922375800053192*^9, 
   3.9223758187418003`*^9}, 3.9223758690027933`*^9, {3.922375924239726*^9, 
   3.922375953186246*^9}, 3.922376042377442*^9, {3.922376073471327*^9, 
   3.92237610335284*^9}},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"97919744-7f5d-498e-895b-09af8727bef2"]
}, Open  ]],

Cell["\<\
Solve for the coefficients.  This works ok for small nG, but precision of \
inverse becomes a severe problem as nG becomes larger (check Messages window)\
\
\>", "Text",
 CellChangeTimes->{{3.9221120694757566`*^9, 
  3.922112154074354*^9}},ExpressionUUID->"3d704d37-c02b-415f-af17-\
b13072b45150"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\n", 
 RowBox[{
  RowBox[{"wOLS", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], " ", "]"}], ".", 
    RowBox[{"Transpose", "[", "X", "]"}], ".", "yTrain"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wOLS", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "show", " ", "first", " ", "value", " ", "to", " ", "get", " ", "an", " ", 
    "idea", " ", "of", " ", "the", " ", "scale"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"wOLS", "//", "TableForm"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "delete", " ", "semicolon", " ", "to", " ", "look", " ", "at", " ", 
    "entire", " ", "set", " ", "of", " ", "coefficients"}], " ", 
   "*)"}]}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922112009820245*^9, 3.922112061687259*^9}, {
   3.922128243639861*^9, 3.92212824682576*^9}, 3.922134646967078*^9},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[597]:=",ExpressionUUID->"3abb3b64-82ae-4894-a13f-96b2c6f5f8ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "300", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 300, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922128247804377*^9, {3.922185228184998*^9, 3.922185251806963*^9}, 
   3.922185316132362*^9, 3.922185362590807*^9, 3.922185417684789*^9, 
   3.922185532833423*^9, {3.922185569269746*^9, 3.9221856281689873`*^9}, 
   3.922189762963738*^9, 3.922190736280771*^9, 3.922190769877452*^9, 
   3.922190799917993*^9, 3.922192415619134*^9, 3.9221924599230347`*^9, 
   3.922192975660076*^9, 3.922212339857153*^9, 3.922212387985971*^9, 
   3.9223758821725407`*^9, {3.922375926578432*^9, 3.922375955749342*^9}, 
   3.922376075710804*^9, 3.922376106944955*^9},
 CellLabel->
  "During evaluation of \
In[597]:=",ExpressionUUID->"068a7057-35e4-494e-89c5-7165129306ed"],

Cell[BoxData["11310.\
880411154181545573993268222486216028439765712140953017907606200879885086383871\
909016985249891387771829482675511494014075015151626726380516601691967639509656\
841849049976760639309123748662190898706757791588431082777860653447313329232534\
629460232336283427950046173324924805477063272801455271006830254745664368236957\
586982662615048613584563725181678887176191083914186139634158218882763950427620\
869092863874116180393830657422391157850239056148664709890493146376479642558785\
003329202610005666058557614327271086078968481212531200794512093308472536289656\
548720654579737256343787870239526107156036485667676952485538014145050676600573\
8817116622174591186503569258145307188574995844073`665.0371593336256"], \
"Output",
 CellChangeTimes->{
  3.922112174552804*^9, 3.92211223518738*^9, {3.9221123444711943`*^9, 
   3.922112360731555*^9}, 3.922112391201676*^9, 3.922112584041546*^9, 
   3.922112720361119*^9, 3.922113058471287*^9, 3.922113104062892*^9, 
   3.922113429085133*^9, 3.922114226450934*^9, 3.9221176974240522`*^9, 
   3.922117886315708*^9, 3.922124848126985*^9, {3.922125584487656*^9, 
   3.922125589304105*^9}, 3.922128247906486*^9, {3.922185228345593*^9, 
   3.922185253084902*^9}, 3.922185321520919*^9, 3.922185373313716*^9, 
   3.922185418337515*^9, 3.92218553313235*^9, {3.92218556956712*^9, 
   3.922185628261559*^9}, 3.9221897630607233`*^9, 3.92219073636091*^9, {
   3.922190770404973*^9, 3.922190800047357*^9}, 3.922192415732386*^9, 
   3.922192460481002*^9, 3.922192975748876*^9, 3.922212339957123*^9, 
   3.922212388186473*^9, 3.922375882283298*^9, {3.922375926690422*^9, 
   3.922375955867298*^9}, 3.922376075853078*^9, 3.9223761076416817`*^9},
 CellLabel->
  "Out[599]=",ExpressionUUID->"fb5ac1c4-80d5-489c-abc5-864591e2fd31"]
}, Open  ]],

Cell["\<\
We can check our calculated values by comparing to the Mma result (defined \
below, and must be run first).  The values returned here should all be very \
small in magnitude\
\>", "Text",
 CellChangeTimes->{{3.922125363569248*^9, 3.9221253703503323`*^9}, {
  3.9221851513838043`*^9, 
  3.922185160893948*^9}},ExpressionUUID->"cd72045f-e24e-4622-8744-\
d92506318a92"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"mmaOLSParams", "-", "wOLS"}], ")"}], "/", "wOLS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Max", "[", 
  RowBox[{"Abs", "@", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9220953593170643`*^9, 3.922095361661772*^9}, {
  3.9220955455601263`*^9, 3.92209558088525*^9}, {3.922096165732329*^9, 
  3.922096199663069*^9}, {3.922096258624627*^9, 3.922096282695972*^9}, {
  3.922096872283916*^9, 3.922096873401413*^9}, {3.922096942440813*^9, 
  3.922096972992654*^9}, {3.9221023299413357`*^9, 3.922102343281678*^9}, {
  3.922102409349251*^9, 3.92210244166972*^9}, {3.9221179703066*^9, 
  3.922118032597668*^9}, {3.922118597195464*^9, 3.922118605914727*^9}, {
  3.922125563467914*^9, 3.922125595051173*^9}, {3.922126861475213*^9, 
  3.922126861863465*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[571]:=",ExpressionUUID->"510dd3c1-7640-4524-8088-c40e9ea08bee"],

Cell[BoxData["0``52.217890442699364"], "Output",
 CellChangeTimes->{{3.9220955592649193`*^9, 3.92209558160323*^9}, {
   3.922096172841996*^9, 3.922096200002633*^9}, {3.922096248315278*^9, 
   3.922096284202034*^9}, 3.9220964013198338`*^9, {3.922096874572583*^9, 
   3.9220968986657543`*^9}, 3.922096975846239*^9, 3.922102015478693*^9, {
   3.922102054636106*^9, 3.9221020841921864`*^9}, 3.922102191463673*^9, 
   3.9221022719291677`*^9, {3.922102306132493*^9, 3.922102455253792*^9}, 
   3.922102502296405*^9, 3.922102538894618*^9, 3.922103089869755*^9, 
   3.922105329244422*^9, 3.9221053702470083`*^9, 3.922112307080475*^9, {
   3.922112347653823*^9, 3.9221123963890743`*^9}, 3.922112587939476*^9, 
   3.9221127368786993`*^9, 3.922113063127006*^9, 3.922113106352426*^9, {
   3.92211341047514*^9, 3.9221134347984033`*^9}, 3.9221177095368958`*^9, 
   3.922117891816196*^9, 3.922117979851305*^9, {3.922118024242224*^9, 
   3.922118034938551*^9}, 3.92211860773638*^9, 3.922124853465139*^9, {
   3.922125570276675*^9, 3.922125595542831*^9}, 3.922128258303672*^9, 
   3.922185630749312*^9, 3.922189765823537*^9, {3.9223759166020947`*^9, 
   3.922375928788439*^9}, 3.92237596924165*^9},
 CellLabel->
  "Out[572]=",ExpressionUUID->"3389e324-b154-4e91-a927-ff0205f40e0d"]
}, Open  ]],

Cell["\<\
This plot compares the fitted PES to the correct LJ potential
We also compute a rms error using the test set\
\>", "Text",
 CellChangeTimes->{{3.922112634977207*^9, 3.9221126789996843`*^9}, {
  3.922112767833311*^9, 3.9221127724802523`*^9}, {3.922128263313904*^9, 
  3.922128264796142*^9}},ExpressionUUID->"68e3c5b8-c6ae-4dff-a056-\
6962078a599a"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MSEOLSTest", "=", 
   RowBox[{"Mean", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"wOLS", ".", 
        RowBox[{"functionList", "[", "rTest", "]"}]}], "-", "yTest"}], ")"}], 
     "2"], "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OLSplot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"wOLS", ".", 
        RowBox[{"functionList", "[", "r", "]"}]}], "*", "yTrainStdev"}], "+", 
      "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"OLSplot", ",", "LJplot"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9217687936291533`*^9, 3.9217688327658987`*^9}, {
   3.921768864444922*^9, 3.921768870848134*^9}, {3.921769486805279*^9, 
   3.921769542793608*^9}, {3.921770940634282*^9, 3.92177094183883*^9}, {
   3.9220952593893003`*^9, 3.922095259496469*^9}, {3.922096300918138*^9, 
   3.922096301503976*^9}, {3.922096529892295*^9, 3.922096530718207*^9}, {
   3.922102592447061*^9, 3.922102645533327*^9}, {3.922112668774447*^9, 
   3.922112669746542*^9}, {3.922117955780716*^9, 3.922117956061253*^9}, {
   3.92211810997902*^9, 3.922118129719873*^9}, {3.922118204296968*^9, 
   3.9221182981780653`*^9}, {3.922119102061995*^9, 3.922119119963013*^9}, {
   3.922124884589457*^9, 3.922124907555897*^9}, {3.922125131572928*^9, 
   3.922125132154565*^9}, {3.9221256104339037`*^9, 3.922125614874242*^9}, {
   3.922128268354906*^9, 3.922128284006213*^9}, 3.9221346478000946`*^9, {
   3.92219243393917*^9, 3.922192436511813*^9}, {3.922192487262466*^9, 
   3.92219250516111*^9}, {3.922212363960239*^9, 3.922212368917573*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[601]:=",ExpressionUUID->"7337113a-f989-40b3-8498-c51cfeae7378"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "300", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 300, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922128281743685*^9, 3.9221282850695057`*^9}, 
   3.922185270607353*^9, 3.922185325614871*^9, 3.922185429284698*^9, 
   3.922185469291533*^9, 3.922185536248465*^9, {3.922185574034398*^9, 
   3.922185635850866*^9}, 3.922189770919334*^9, 3.922190742246014*^9, 
   3.922190773444817*^9, 3.922190803692759*^9, {3.922192423607463*^9, 
   3.922192506079637*^9}, 3.922192979737613*^9, {3.922212354793503*^9, 
   3.922212392001762*^9}, 3.9223759829780807`*^9, 3.9223760562590847`*^9, {
   3.922376091072422*^9, 3.9223761123570137`*^9}},
 CellLabel->
  "During evaluation of \
In[601]:=",ExpressionUUID->"7527d1ec-14f4-4e8f-aa1c-eda06a6cac6c"],

Cell[BoxData["0.\
063729283096629574466853479570160697066204586029296562867225742089372442027457\
468519589141600044843659924091391447095120066208274042224848571922665817178823\
481424543456183346673343755477588015327706027444893581764050198193770729850007\
368013561173167502242186890423786083282491015276734828077210895342186444574918\
943912447832944181205457085103138233018893302802177710631133659139613966494412\
939055922179565115373358363544565779447763161563498693966022808667725465147564\
439701347849648235840372363683565712234070426016707193745464764934935114308307\
446694040837178465855554892384611026774695996075702399522931422558932665630381\
771224744538774670343304233503`641.5956605216659"], "Output",
 CellChangeTimes->{
  3.922124921668788*^9, 3.9221251363025007`*^9, {3.922125602668584*^9, 
   3.922125616117119*^9}, {3.922128281828669*^9, 3.9221282851195517`*^9}, 
   3.922185270708957*^9, 3.92218532569972*^9, 3.922185429365223*^9, 
   3.922185469379488*^9, 3.9221855363262663`*^9, {3.922185574119816*^9, 
   3.92218563594674*^9}, 3.922189771013205*^9, 3.922190742319968*^9, 
   3.922190773535296*^9, 3.922190803784694*^9, {3.922192423691759*^9, 
   3.922192506180066*^9}, 3.922192979842789*^9, {3.922212355026453*^9, 
   3.922212392085457*^9}, 3.922375983097837*^9, {3.9223760651942244`*^9, 
   3.922376112465489*^9}},
 CellLabel->
  "Out[602]=",ExpressionUUID->"3b5b5658-e01a-4ada-9b27-d09375d8a1b3"],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVVgk01dsXvqZ7X3+SBgqllDQZQopK+1dKmSoJ9TKU93iVRKnrFipjERki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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVVgk01dsXvqZ7X3+SBgqllDQZQopK+1dKmSoJ9TKU93iVRKnrFipjERki
QpQ0aKCQIbKVSKbM1TNLhOv+BkKE/31nrbPO+tY5e+397e87Zx1lR7cDTqIs
FqtGOP9bXf3lTUeKSYi//d/4CBG41E20m4R1T+708ExyYa/f5pzDfSS8Yhre
GrCzQHKX1dQLPglqs2arZSY9h6CKkOsOY8Lzheadc1TioWhgwtKeTUGxslaY
VUMKZv10ci9QpCBjfHqPmV8JzrMZnv+PEgXDg8d68reXonveldx5yhScU101
HDhZhhpeCdMnVCnYaOEyct6+Ah+z6kIXaVFg+EjU6MmZWkyS3Jp23ogCBdHO
yncXm3Hq1EczZWMKHhfrjteu/4y2NdZUlSkFBtEexZd6PqN85JlNKhYUdPxQ
L6nf+RWj5R6V1h+hYMFJJX2pgRYMVp7XrXmGggKXIUe2cycus45dXONBgWRp
sbFkeifmhSy2OcWloMKN7SP/sxN/DKtWPfaioDtzk5jtlS40KtuSoxxEgUas
ZC5e70ZxF6eQ+QkUSIelrlfi9WBi8sD7l3coMK/9fa7tZQ/qNLrN7LtLQdQ3
i/lVAz3oaHDxXOgDCgKOnZIh/vyOb+eE20u8oMA57nJOkWYvXsrO0x57T0Gm
maNdd04fyvUbuMZ8oCD1b4KJ6OnD50tKHulUUHDg+Ldt4XN/YGtQ9WL3TxQo
Pq908jvxA7cc7mb3f6XAK889/fzcfqwP+2f71VYK/M+962vU78eT7/heKzso
UJK0U4s61o/x68aoYz0UzKqQfqqe0Y/jU5It/wqEfM/HHVxoOIAR2pGyF2gK
KPu8thjnAVz9j9z+hSMUNDd/SLscPIA2tctKLX9R4LFDzSahegBzUnQzqsRo
4OUt36a0bxA9djv4Fy2iIWWZ7bZkPT52T54NjVGkQX6vXFO5FR/3vwiKOaVE
g8GC/GUOZ/moIZ/+SEGFhkOm2c++pPHxx8DvSq4mDS/Ddp7UmDeE1skyTeba
NJgrTSXy1w5hqaVKu4ouDV/mMbkqhkOYUmhK1W+m4V/fuwN/nB1C2xvxCzSN
aLhd4KlR9XEIK3akL2Eb05Ccf+t5QPsQ6o+9VW0zpSF3Q7hGCTOEckf79a5b
0KBV4jbyWV6AdVp6dn22NHhrN/ZddRQg0WvqXORAwyvlFQOxHgJMj3dwi3Gk
wbStTkI/QIChYld9DY/TUH55Y7VOqgCNmpoeJHvQUFwm+1yzQ4DZwf3pXC4N
LfsvPODzBbhi21Su+QUaQty3d++cECDrkUrF5CUaJLMf/K6cT6LbEb2Gel8a
xjfjlqmlJLbPMWtNC6DhfbCJX806Egt4HgKbEBraEireW+0gca361TGNMBoK
7Pf+IW1OYlxXPIsdQcPmII/ukzYkck3ezcuOoUE5x+GDnAuJ6xfP3SRzjwa4
2JJidYPEpFoVou++MF+mJ8viFomzA/WMix7SoO6nfeXXHRIHhhyOnHom3F/m
NGL1jMRDKR5/G2bQkMST7JfMIvGD9VVXhUwaOjq2sjzySUzF9MvluTScdnHl
HSolcd65d9eSX9NwJqmq5EsFib6rmyO5b2j4X2EgW7qWRKq1P968WOiH2zqa
vxpJtI+cuq9SItSHaVmT8JXE6l1zn0+W0vDaf7RjpI3ErRMqOfXlNIjPOqfH
6SZR/i+z8is1NOw72+VwuJ/Es9GhZqvqaLgf9O20E5/EitKq2uoGGpbGpdps
JElcMSZlda5Z6JfcxVVVNIneq82/KnylIVPL03vNCImNh8Ps3rbQEK66cKH5
KInq16u7/mmn4ZFC4h69cRKDCmc7S3fRkOXZWzD4S6jPkPlA9jcanMUWKxyf
JHHj0hunj/TSoGny7H/pv0kM31/DiPTTYDt9UKdoisQfvtKejweFfjBV1bs9
TSKRtXdyr4CGO8uuFsCMUL+eG5d/UjSUndC3zxRiWvaTWOKwEO+yR1qITXbP
ubZjlIbL6y56TwtxCm+fVP84DcHsC1pfhXgiLTwifJKGwj2ZPD8htmz5tGDj
NA1LaP7AhDDfMymZ260sBgyv/bXUUIjFt+1f4i/GwKF55U+PCOuzdYu4t4bN
QN3obpVdwvpf3a1dWfsHA3RbuCJLyE+6XuYJV1IYH/BpeZiQv7OYhcYSaQbk
At585I+RWLQhMrNEhgEF2YSkpcL+LXSu23hyPgMG7zZpqAr76x47t0BGjoF+
2Z9iIgyJ5eUWkLuIgQdbK9JeCPVRnogssVNkwCxp92PdIRIvrqvfLa7EwA/X
+KCIARLX3Tiw32IFA1f048c/9pAYgFGNYysZWKtcdzOti8RWqv5Q0moGfqqP
LznWTuINS8tjg+oMKPuHzRz+TGJvwM3vkesZkJwzapnYQCLkNJzQ02HgRadx
ZN4noR8XHTwbqMdA6nhi5pUPJO4xiR5dt4UBKU/3YPUSEu95NV6sN2AgWaRd
I6eIxAPtB/2XGjKwYfHLN7avSMy+bxWdb86AUbF7pOQ9EqWaYhYd3c/AvcyB
6/cTSHRiNyeyLRmQ+Tu+V0F43+ROWD+wPMRA2oYwt7QQEnkaNjlDjgy0HIzk
Wpwl0SD/0BdlHgPW+pazV20l8dTJVetEvBjoyvouZ7yBxETFUZ9OHwZ2BYCh
mRqJkz43VyT7M/Asl/V1TJHE/B01pxeHM+D/Sd2X+iVA3SpDiYUPhfEy3YMf
XghQvUNDW6qRAfdMVnO9lABtI6YCBpsZOGrnYfddRPi+ba/6XPGVAU1xv9Pf
R4dw8P4Jn+AOBipy2j0yOocw7XhqOXuQgbZDYqUeWUO4kpF3EBEdhqstt46x
rIdwiYRE6KjmMNhFXaldEMnHoODK8+Xaw7D29ZHMewF8FMyOcojXHQa/zrXz
V/L4WCS3VGfblmFAy9+qMg58PLpa/99Ao2FQl6kw8VHjY6qp62pZu2G4pBW0
vqN0ENWimt7rhAyDSPXTYZGRAdy89OGUe88wiP35uEDTqB+bPJw3V4SOwM2q
79dD1vSiWlGZgo3hT2iJfqH7WvwbsgyNyt4N/YTeJPmMJcL/wdxbrzUbo0eh
rO/IpROmrdjRXrNV3mQMyLV3yodlv+BaR1FZg+ExKPQ6sKa1oBG1W5oiop+M
w6KjkiayD+vQc3lSRaT9LzBUjztprFWD+qmBn1zZE6B8xHcnsaoCcxVn83wK
J2BbQnXQZ7cyzKrOGnRxnoSdiuHd4ZdK0OX8hOgNpd/gnm8Tbf+xGI8O6n6x
avgNPoPHPu6a9wYbEiJ4v72mYPJn8yuuVz6K7rhe2Kw9DavexxWHquZg+vIH
leFt07Av9HRKs1cWxtZlxQkCZkBK8q+bz/ReotKWlwHEEhYxUDm7cs6GdMxY
G7f81xkW4flJwWpF+RNUkt0XVVnNIoq9b8+4RT7CZ86sLmqVCFEeOLXn3+ZU
vGC1PUbCW4Qo9S8cc01KQRU4oLjhswhxoqtYPMP/Ls4uY9gH1ESJsl++Tstj
76Bsdljdu8uixLkdLlUNd+JxMnHc1fxfUaIj+jR3a1ksLlsx7PZBQ4yQFY1M
SXGLwRWpbwyPhIgRTwPCiSDtm+j0bqFPe4cYcfNrUYj14Ugs3X0qJltHnMh1
idyuzQtHsfKIy6k3xAkdTHMZ+TMUr3zf+cn/mzgxoyfxMOV9MLZMlVPeIEHc
7Q5/T+68ilY+u+ny2xLExtmWdxTlAlE63spGXCBB7Mx7fGe+oT8+eKkTftiY
TQS3G8zt8/bFi8731JKS2AT1+flf7qwreNpvVpouwybcojMWLXbwQeL29rFe
Mw7RWSNilVZ5ES3MZz29eo9D0Aqzcoru8rB9pVGoyH0OUfs2WTYkloenpv1c
vVI5ROwGS5vDN3gYlPFb0+0Rh3DYHXpGzJuHr+dS2dbPOcTHwIBbgTY8XN7c
XLQyn0MkrlTy2zaHhyP2qfUltRwi/mRBwhlfT/Td1JVlUM8hxILs27J4nigt
oxST28Ah6rSa6n+5eeLqt7E2T5s5RPGtEX6EvSfarrjeGtXKIbLyXkXxt3hi
ad+Z3mM/OMQwLbvXcYyLB4rTP7T0c4jIGVX6m4CLnXGDj60GOUTRa1v2yV4u
Thg7uRgLOMS3U9e++TdxUePZIWr9CIfYpqF1gM7iYkFATN2TnxxiplnT6fZT
Lu6xq89UGeMQyU0PGozuc9FR2uz8ogkOoXVc/GhmFBfJ3mvWUZMcQj/web17
CBe9sXST1BSHKLwQbKLrx8VZcaLyQdMcYqVq3vjMBS7ecoeJmRkOUdG+c27d
GS7+HxJI+Bc=
               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVVgk01dsXvqZ7X3+SBgqllDQZQopK+1dKmSoJ9TKU93iVRKnrFipjERki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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922124921668788*^9, 3.9221251363025007`*^9, {3.922125602668584*^9, 
   3.922125616117119*^9}, {3.922128281828669*^9, 3.9221282851195517`*^9}, 
   3.922185270708957*^9, 3.92218532569972*^9, 3.922185429365223*^9, 
   3.922185469379488*^9, 3.9221855363262663`*^9, {3.922185574119816*^9, 
   3.92218563594674*^9}, 3.922189771013205*^9, 3.922190742319968*^9, 
   3.922190773535296*^9, 3.922190803784694*^9, {3.922192423691759*^9, 
   3.922192506180066*^9}, 3.922192979842789*^9, {3.922212355026453*^9, 
   3.922212392085457*^9}, 3.922375983097837*^9, {3.9223760651942244`*^9, 
   3.922376091179335*^9}, 3.922376125453431*^9},
 CellLabel->
  "Out[604]=",ExpressionUUID->"78d05b80-bebc-4005-98ce-14071ca2f9d9"]
}, Open  ]],

Cell["Plot predicted vs actual", "Text",
 CellChangeTimes->{{3.922192927363875*^9, 
  3.9221929336275873`*^9}},ExpressionUUID->"01e3f48d-798c-475e-bcd1-\
47d470fb9c5b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yTrain", ",", 
      RowBox[{"X", ".", "wOLS"}]}], "}"}], "]"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Actual\>\"", ",", "\"\<Predicted\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.922192774043182*^9, 3.922192800192538*^9}, {
  3.922192865475978*^9, 3.922192866407288*^9}, {3.922192937572435*^9, 
  3.922192952452139*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[3336]:=",ExpressionUUID->"d2342067-00a4-4ade-afce-b3bbe24557f3"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.009166666666666668], AbsoluteThickness[2], PointBox[CompressedData["

1:eJwV0nk8FHgYBnDlQ7vRZlVLKMkKOZZylm2mcmcUalyhwpaEXNndRqPNElLb
QdGKSDl2CpnBMF5nEbkjuQnjDEOJyv7eP57P9//neRRO+dl6rhYSEvIgQcWl
hV2CVjiwl0FhoEEa9lLhtEbgmD2yRDNWNi9ulOSAxejiwibijWLbYK9sNkzI
J9afIcbrJMdyBPlg8bzKooAYX3XT/aABD2Y8yg+j7inzTz7N5kPW2/BVi0QF
E/uQQ/7v4WeR6UtotaxMSKjlHNBC6g+hlNqtgu4INtC0xYK7iF56vvoKohyw
6rGz3U5MEa5xzXIoAnEj99lMYq5OBGvpfj5sTrjegW6YMG/cJ9sAxz82L6JW
CU+rLH1agC2Y5qBXXChqRjLl4LRNXQl9kCS5MhJeAk/FzIRHialJw0zLk2zI
82x3RZe8p2WZSR8gynH02yXiGqOQ3XozI+Aoa+KMqvveDOJr9ICYiX8E2nVX
wjV5ohLmNc8Go7Ls1j7P1hI4fqS5Hf3u4S7ulQs8aJEdS0XLnLcINjf2gppe
0yMZ4pdkq6MDgnLI1Dano3t0b0e+Yq2jXr0fHodWOE7VcO1KofXx5TzUtdSi
OqqVA+2m3haofvG3w7efvILU3cpKqFMLY4ousUhpPZtbgVoFLAXa9r2F2Pqh
SFRaSKXc05v0G5Oigfbo/tj/rKgAwoyttXKJh7PXULPs2CCtKOeaTTSmqe6U
EnAh0EEkFHVMVrDxIru+u+0Wg/bnu4rTqiehd7XHuBUx+qCF5MQtLrhP9Dqg
9xVbF94JjUDcIn9jF3Gs2Xmm5+8BaEmmmfYSE9+VSUykv4ITYX2Aqj3YUT6X
lw+0+c/+AuJMzpHsBHonmAcYVKG+UVeK/jsxDPx6+SaUruY7lJ0wACWhog1o
SEbxlpH9o5Q3csrXUYlEb5tB0QLQFj5zDX1u7hDwoIoNyvEVLLTbNskoL3CW
wtzJskNvlQ4euPu6CRQ1hI+iGnPNXyJ1pyjxqWl2V4kv9BWOHeCT/50LzqQS
pdLXtu39cz11qbZByIgozFgQC9xVBIWlvBsBRKPtC5Wm1hyItA/ORNnxx86X
GPLAJtDrODpQPNKhOciB7Vmq19Acq8gn0hObqIxSnYfoqraoAQd/DlzmBexF
pShdhqLDxfBHn7U7Km/DMAnoJL8KTFNHL+xp2HPSvR/UdsSqozkh9oo90S+g
rrB9uZuoclqPwfo0CP3iNr7oubomgV1MGdAbyqZQ6afKbk2kdxE7S/Fm4tUW
loroPS7Ybrl+Ho2gx8s+8uUCU6GGjiqOKcbus/8ALKux5V+JKkOXu5atyyCE
NvIGnao+8FuGPBem2GEX0dXS3PTztVyQf2n6EU1Lm7bvneyFl3dGbNFUn46a
OPc5+Lru5ABqH+60Xr11EKKTFlbUiMzxE0PDdiJU7ZVTcajZ1zy5aHoHlOjo
yKC+k7kj0fJl4BdEGUDHpGvyOYxK+Gb7uQ6911lQcdOmDqRaljJRlke7vnhM
Iax1DF2PJroyfHa4TFIMpX+qRbubmCuaGnPw2JCp/QtxSVMn10KqCDqoxlpo
Se0/hXdyikDiWcFfaF/j8/2MfydBjb+ggMqEael/8uDB7FTGNvSMkpxZa3Ib
LNJjlFCXntKAYZkiOLRPbu490dSHpuWmwYElnl8Jquu05lrJxUoQfbM7DTVM
2mA0btEC/JwJLXS8z81HWSBO3ego5YfyFN1S+Fn5sJUneXqUGMSa1/k9qhAM
Ftp+QO/NVToLfV8Id5g2qquIwsdEVHvZfBhQUrJC797KffiFwwEn486eZaKB
emi6nOhbqHv5moX+D2cHf4I=
         "]]},
       Annotation[#, "Charting`Private`Tag#1"]& ],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{
           Annotation[{
             Directive[
              PointSize[0.009166666666666668], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Point[CompressedData["
1:eJwV0nk8FHgYBnDlQ7vRZlVLKMkKOZZylm2mcmcUalyhwpaEXNndRqPNElLb
QdGKSDl2CpnBMF5nEbkjuQnjDEOJyv7eP57P9//neRRO+dl6rhYSEvIgQcWl
hV2CVjiwl0FhoEEa9lLhtEbgmD2yRDNWNi9ulOSAxejiwibijWLbYK9sNkzI
J9afIcbrJMdyBPlg8bzKooAYX3XT/aABD2Y8yg+j7inzTz7N5kPW2/BVi0QF
E/uQQ/7v4WeR6UtotaxMSKjlHNBC6g+hlNqtgu4INtC0xYK7iF56vvoKohyw
6rGz3U5MEa5xzXIoAnEj99lMYq5OBGvpfj5sTrjegW6YMG/cJ9sAxz82L6JW
CU+rLH1agC2Y5qBXXChqRjLl4LRNXQl9kCS5MhJeAk/FzIRHialJw0zLk2zI
82x3RZe8p2WZSR8gynH02yXiGqOQ3XozI+Aoa+KMqvveDOJr9ICYiX8E2nVX
wjV5ohLmNc8Go7Ls1j7P1hI4fqS5Hf3u4S7ulQs8aJEdS0XLnLcINjf2gppe
0yMZ4pdkq6MDgnLI1Dano3t0b0e+Yq2jXr0fHodWOE7VcO1KofXx5TzUtdSi
OqqVA+2m3haofvG3w7efvILU3cpKqFMLY4ousUhpPZtbgVoFLAXa9r2F2Pqh
SFRaSKXc05v0G5Oigfbo/tj/rKgAwoyttXKJh7PXULPs2CCtKOeaTTSmqe6U
EnAh0EEkFHVMVrDxIru+u+0Wg/bnu4rTqiehd7XHuBUx+qCF5MQtLrhP9Dqg
9xVbF94JjUDcIn9jF3Gs2Xmm5+8BaEmmmfYSE9+VSUykv4ITYX2Aqj3YUT6X
lw+0+c/+AuJMzpHsBHonmAcYVKG+UVeK/jsxDPx6+SaUruY7lJ0wACWhog1o
SEbxlpH9o5Q3csrXUYlEb5tB0QLQFj5zDX1u7hDwoIoNyvEVLLTbNskoL3CW
wtzJskNvlQ4euPu6CRQ1hI+iGnPNXyJ1pyjxqWl2V4kv9BWOHeCT/50LzqQS
pdLXtu39cz11qbZByIgozFgQC9xVBIWlvBsBRKPtC5Wm1hyItA/ORNnxx86X
GPLAJtDrODpQPNKhOciB7Vmq19Acq8gn0hObqIxSnYfoqraoAQd/DlzmBexF
pShdhqLDxfBHn7U7Km/DMAnoJL8KTFNHL+xp2HPSvR/UdsSqozkh9oo90S+g
rrB9uZuoclqPwfo0CP3iNr7oubomgV1MGdAbyqZQ6afKbk2kdxE7S/Fm4tUW
loroPS7Ybrl+Ho2gx8s+8uUCU6GGjiqOKcbus/8ALKux5V+JKkOXu5atyyCE
NvIGnao+8FuGPBem2GEX0dXS3PTztVyQf2n6EU1Lm7bvneyFl3dGbNFUn46a
OPc5+Lru5ABqH+60Xr11EKKTFlbUiMzxE0PDdiJU7ZVTcajZ1zy5aHoHlOjo
yKC+k7kj0fJl4BdEGUDHpGvyOYxK+Gb7uQ6911lQcdOmDqRaljJRlke7vnhM
Iax1DF2PJroyfHa4TFIMpX+qRbubmCuaGnPw2JCp/QtxSVMn10KqCDqoxlpo
Se0/hXdyikDiWcFfaF/j8/2MfydBjb+ggMqEael/8uDB7FTGNvSMkpxZa3Ib
LNJjlFCXntKAYZkiOLRPbu490dSHpuWmwYElnl8Jquu05lrJxUoQfbM7DTVM
2mA0btEC/JwJLXS8z81HWSBO3ego5YfyFN1S+Fn5sJUneXqUGMSa1/k9qhAM
Ftp+QO/NVToLfV8Id5g2qquIwsdEVHvZfBhQUrJC797KffiFwwEn486eZaKB
emi6nOhbqHv5moX+D2cHf4I=
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-1.149312767541098, 
             0.5202015446355487}, {-1.1493128589507926`, 0.5202014280910009}},
             "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
            "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
            GoldenRatio^(-1), "DefaultStyle" -> {
              Directive[
               PointSize[0.009166666666666668], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-1.149312767541098, 
            0.5202015446355487}, {-1.1493128589507926`, 0.5202014280910009}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[0.009166666666666668], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{
       Annotation[{
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Point[CompressedData["
1:eJwV0nk8FHgYBnDlQ7vRZlVLKMkKOZZylm2mcmcUalyhwpaEXNndRqPNElLb
QdGKSDl2CpnBMF5nEbkjuQnjDEOJyv7eP57P9//neRRO+dl6rhYSEvIgQcWl
hV2CVjiwl0FhoEEa9lLhtEbgmD2yRDNWNi9ulOSAxejiwibijWLbYK9sNkzI
J9afIcbrJMdyBPlg8bzKooAYX3XT/aABD2Y8yg+j7inzTz7N5kPW2/BVi0QF
E/uQQ/7v4WeR6UtotaxMSKjlHNBC6g+hlNqtgu4INtC0xYK7iF56vvoKohyw
6rGz3U5MEa5xzXIoAnEj99lMYq5OBGvpfj5sTrjegW6YMG/cJ9sAxz82L6JW
CU+rLH1agC2Y5qBXXChqRjLl4LRNXQl9kCS5MhJeAk/FzIRHialJw0zLk2zI
82x3RZe8p2WZSR8gynH02yXiGqOQ3XozI+Aoa+KMqvveDOJr9ICYiX8E2nVX
wjV5ohLmNc8Go7Ls1j7P1hI4fqS5Hf3u4S7ulQs8aJEdS0XLnLcINjf2gppe
0yMZ4pdkq6MDgnLI1Dano3t0b0e+Yq2jXr0fHodWOE7VcO1KofXx5TzUtdSi
OqqVA+2m3haofvG3w7efvILU3cpKqFMLY4ousUhpPZtbgVoFLAXa9r2F2Pqh
SFRaSKXc05v0G5Oigfbo/tj/rKgAwoyttXKJh7PXULPs2CCtKOeaTTSmqe6U
EnAh0EEkFHVMVrDxIru+u+0Wg/bnu4rTqiehd7XHuBUx+qCF5MQtLrhP9Dqg
9xVbF94JjUDcIn9jF3Gs2Xmm5+8BaEmmmfYSE9+VSUykv4ITYX2Aqj3YUT6X
lw+0+c/+AuJMzpHsBHonmAcYVKG+UVeK/jsxDPx6+SaUruY7lJ0wACWhog1o
SEbxlpH9o5Q3csrXUYlEb5tB0QLQFj5zDX1u7hDwoIoNyvEVLLTbNskoL3CW
wtzJskNvlQ4euPu6CRQ1hI+iGnPNXyJ1pyjxqWl2V4kv9BWOHeCT/50LzqQS
pdLXtu39cz11qbZByIgozFgQC9xVBIWlvBsBRKPtC5Wm1hyItA/ORNnxx86X
GPLAJtDrODpQPNKhOciB7Vmq19Acq8gn0hObqIxSnYfoqraoAQd/DlzmBexF
pShdhqLDxfBHn7U7Km/DMAnoJL8KTFNHL+xp2HPSvR/UdsSqozkh9oo90S+g
rrB9uZuoclqPwfo0CP3iNr7oubomgV1MGdAbyqZQ6afKbk2kdxE7S/Fm4tUW
loroPS7Ybrl+Ho2gx8s+8uUCU6GGjiqOKcbus/8ALKux5V+JKkOXu5atyyCE
NvIGnao+8FuGPBem2GEX0dXS3PTztVyQf2n6EU1Lm7bvneyFl3dGbNFUn46a
OPc5+Lru5ABqH+60Xr11EKKTFlbUiMzxE0PDdiJU7ZVTcajZ1zy5aHoHlOjo
yKC+k7kj0fJl4BdEGUDHpGvyOYxK+Gb7uQ6911lQcdOmDqRaljJRlke7vnhM
Iax1DF2PJroyfHa4TFIMpX+qRbubmCuaGnPw2JCp/QtxSVMn10KqCDqoxlpo
Se0/hXdyikDiWcFfaF/j8/2MfydBjb+ggMqEael/8uDB7FTGNvSMkpxZa3Ib
LNJjlFCXntKAYZkiOLRPbu490dSHpuWmwYElnl8Jquu05lrJxUoQfbM7DTVM
2mA0btEC/JwJLXS8z81HWSBO3ego5YfyFN1S+Fn5sJUneXqUGMSa1/k9qhAM
Ftp+QO/NVToLfV8Id5g2qquIwsdEVHvZfBhQUrJC797KffiFwwEn486eZaKB
emi6nOhbqHv5moX+D2cHf4I=
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-1.149312767541098, 
         0.5202015446355487}, {-1.1493128589507926`, 0.5202014280910009}}, 
        "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.009166666666666668], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\"Actual\"", HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"Predicted\"", HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.149312767541098, 0.5202015446355487}, {-1.1493128589507926`,
    0.5202014280910009}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.922192802593913*^9, 3.922192867166475*^9, 
  3.922192952886853*^9, 3.9221929836691933`*^9, 3.922212401945425*^9},
 CellLabel->
  "Out[3336]=",ExpressionUUID->"3de9594c-0698-4f87-ba66-a39a639b1304"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematica Fit function", "Subsection",
 CellChangeTimes->{{3.922184781175786*^9, 
  3.922184789759697*^9}},ExpressionUUID->"6a09cccf-4668-4b7c-bc21-\
f471f4eb208c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wp", "=", "MachinePrecision"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"generate", "[", 
  RowBox[{"5", ",", "100", ",", "100", ",", "100"}], "]"}]}], "Input",
 CellChangeTimes->{{3.922190878734888*^9, 3.922190888270816*^9}, {
  3.92221246273843*^9, 3.9222124639073668`*^9}, {3.9222127364667263`*^9, 
  3.922212736783622*^9}, {3.922213154360429*^9, 3.922213157306918*^9}},
 CellLabel->
  "In[605]:=",ExpressionUUID->"0aaa9d2a-5ed6-470a-9b6c-ed30742fc436"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.922190889676152*^9, 3.9222124647353363`*^9, 
  3.92221273713693*^9, 3.922212771655518*^9, 3.922213116961068*^9, 
  3.922213157822643*^9, 3.922376135672085*^9},
 CellLabel->
  "During evaluation of \
In[605]:=",ExpressionUUID->"884cb999-21ea-4f5f-87a1-d6c6a3b26b06"]
}, Open  ]],

Cell["\<\
Mathematica\[CloseCurlyQuote]s Fit function can provide the coefficients \
without hitting the precision issue.  \
\>", "Text",
 CellChangeTimes->{{3.922112250329123*^9, 3.922112304073114*^9}, 
   3.922125359528693*^9},ExpressionUUID->"17281b20-9a2f-42ff-b13b-\
a84329301fcd"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmaOLSParams", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     "\"\<BestFitParameters\>\""}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9220953593170643`*^9, 3.922095361661772*^9}, {
   3.9220955455601263`*^9, 3.92209558088525*^9}, {3.922096165732329*^9, 
   3.922096199663069*^9}, {3.922096258624627*^9, 3.922096282695972*^9}, {
   3.922096872283916*^9, 3.922096873401413*^9}, {3.922096942440813*^9, 
   3.922096972992654*^9}, {3.9221023299413357`*^9, 3.922102343281678*^9}, {
   3.922102409349251*^9, 3.92210244166972*^9}, {3.9221179703066*^9, 
   3.922118032597668*^9}, {3.922118597195464*^9, 3.922118605914727*^9}, {
   3.922125341522593*^9, 3.9221253422251883`*^9}, {3.922126858350656*^9, 
   3.922126858744463*^9}, {3.92212783081793*^9, 3.922127895313778*^9}, {
   3.922128110308608*^9, 3.922128114019526*^9}, 3.922134643666542*^9, {
   3.922190817508275*^9, 3.922190821112405*^9}, 3.922190873066674*^9},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[607]:=",ExpressionUUID->"3427c13f-c2f9-4d7d-be26-34a0bd935d8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.92212811499697*^9, 3.922190823258825*^9, 
  3.922190892731052*^9, 3.922212472500938*^9, 3.922212739310595*^9, 
  3.922212775038521*^9, 3.922213119423583*^9, 3.922213159788813*^9, 
  3.92237591185056*^9, 3.922375964658533*^9, 3.922376049680369*^9, 
  3.922376137568713*^9},
 CellLabel->
  "During evaluation of \
In[607]:=",ExpressionUUID->"a6dc728b-22a9-47a1-842c-3c6d9b3eb50c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mmaOLSFit", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9220953593170643`*^9, 3.922095361661772*^9}, {
  3.9220955455601263`*^9, 3.92209558088525*^9}, {3.922096165732329*^9, 
  3.922096199663069*^9}, {3.922096258624627*^9, 3.922096282695972*^9}, {
  3.922096872283916*^9, 3.922096873401413*^9}, {3.922096942440813*^9, 
  3.922096972992654*^9}, {3.9221023299413357`*^9, 3.922102343281678*^9}, {
  3.922102409349251*^9, 3.92210244166972*^9}, {3.9221179703066*^9, 
  3.922118032597668*^9}, {3.922118597195464*^9, 3.922118605914727*^9}, {
  3.922125346537491*^9, 3.92212534816343*^9}, {3.922126851702137*^9, 
  3.922126852202723*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[609]:=",ExpressionUUID->"47c68847-3877-4279-a323-8987345e637d"],

Cell["\<\
This plot compares the fitted PES to the correct LJ potential
We also compute a rms error using the test set\
\>", "Text",
 CellChangeTimes->{{3.922112634977207*^9, 3.9221126789996843`*^9}, {
  3.922112767833311*^9, 
  3.9221127724802523`*^9}},ExpressionUUID->"55811c6a-95f6-4cb6-8b16-\
d597fdbdc53e"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MSEOLSMmaTest", "=", 
   RowBox[{"Mean", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"mmaOLSFit", " ", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "->", "rTest"}], "}"}]}], ")"}], "-", "yTest"}], ")"}],
      "2"], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<MSE: \>\"", ",", "MSEOLSMmaTest"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmaplot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"mmaOLSFit", " ", "yTrainStdev"}], "+", "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", "Black", "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"mmaplot", ",", "LJplot"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9217687936291533`*^9, 3.9217688327658987`*^9}, {
   3.921768864444922*^9, 3.921768870848134*^9}, {3.921769486805279*^9, 
   3.921769542793608*^9}, {3.921770940634282*^9, 3.92177094183883*^9}, {
   3.9220952593893003`*^9, 3.922095259496469*^9}, {3.922096300918138*^9, 
   3.922096301503976*^9}, {3.922096529892295*^9, 3.922096530718207*^9}, {
   3.922102592447061*^9, 3.922102645533327*^9}, {3.922112668774447*^9, 
   3.922112669746542*^9}, {3.922117955780716*^9, 3.922117956061253*^9}, {
   3.92211810997902*^9, 3.922118129719873*^9}, {3.922118204296968*^9, 
   3.9221182981780653`*^9}, {3.922119102061995*^9, 3.922119119963013*^9}, {
   3.922124884589457*^9, 3.922124929586571*^9}, {3.922125141517346*^9, 
   3.922125142041055*^9}, {3.92212539032815*^9, 3.922125395874145*^9}, {
   3.922126872766236*^9, 3.9221268768181553`*^9}, {3.9221281317996073`*^9, 
   3.922128181664841*^9}, 3.922134644487029*^9, {3.922212491063163*^9, 
   3.92221250007848*^9}, {3.9222125896544523`*^9, 3.922212596925364*^9}, {
   3.922376159299271*^9, 3.922376159844234*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[615]:=",ExpressionUUID->"f3cac34a-b41d-4d06-b426-81569ca25e39"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{{3.9221281368883867`*^9, 3.922128151242673*^9}, 
   3.922128183678666*^9, 3.922128568388955*^9, 3.9221908305089493`*^9, 
   3.922190899019239*^9, {3.922212476163994*^9, 3.922212501185522*^9}, {
   3.922212573748032*^9, 3.9222125976365833`*^9}, 3.922212743142713*^9, 
   3.922212781640225*^9, 3.9222131234434133`*^9, 3.9222131635478077`*^9, {
   3.922376145203857*^9, 3.922376160705966*^9}},
 CellLabel->
  "During evaluation of \
In[615]:=",ExpressionUUID->"8ff99ac9-2fc1-43c3-aa9e-ff36664188da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE: \"\>", "\[InvisibleSpace]", "3.2637233014827896`*^-6"}],
  SequenceForm["MSE: ", 3.2637233014827896`*^-6],
  Editable->False]], "Print",
 CellChangeTimes->{{3.9221281368883867`*^9, 3.922128151242673*^9}, 
   3.922128183678666*^9, 3.922128568388955*^9, 3.9221908305089493`*^9, 
   3.922190899019239*^9, {3.922212476163994*^9, 3.922212501185522*^9}, {
   3.922212573748032*^9, 3.9222125976365833`*^9}, 3.922212743142713*^9, 
   3.922212781640225*^9, 3.9222131234434133`*^9, 3.9222131635478077`*^9, {
   3.922376145203857*^9, 3.922376160820072*^9}},
 CellLabel->
  "During evaluation of \
In[615]:=",ExpressionUUID->"f7adf1a9-c0e6-4396-8b24-eb15080aa1ba"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], 
          LineBox[CompressedData["
1:eJwVVnc8ld8f57ruzcpIaNgq34pKC6VzUlkhpaSBUiGUZF2y995kZUVJJaGM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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               GrayLevel[0]], 
              Line[CompressedData["
1:eJwVVnc8ld8f57ruzcpIaNgq34pKC6VzUlkhpaSBUiGUZF2y995kZUVJJaGM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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               GrayLevel[0]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              GrayLevel[0]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           GrayLevel[0]], 
          Line[CompressedData["
1:eJwVVnc8ld8f57ruzcpIaNgq34pKC6VzUlkhpaSBUiGUZF2y995kZUVJJaGM
1McIkR2SZDRk3yFZ4ff87h/3vt6v5zmf817nuY+0ud2ZGyQ2NjYu4uv/v+Jy
CWrHq+koJfn/n0YUDZJ2pO90NPDtVvgnz1Kk76v6+sJvOvJNWdj86WAx4jlx
brlwko6+mJdGqPx7jgKbQsPM5uho5cF3od6GFPRufNHQlMJANw7TEiA5G4pn
b9x5s4mBrhnhTZXetSB0fmadpQQDZR024m84Wgd3yrxLhaQZaME+7uyh5XpQ
vJe6cnMrA4moGhg5XWuCPLaOcLE9DJRaQAu67dIO6TyHnzhpEOufaZJ/BPbA
sm2jrrQ2A22em9d9rfYZLrcaMZpPMpCW6K2TW1ifYUOM/UG50ww0dFRBetHw
C8SLPK7rvMRAyxKk5+v/fYUQaaHvu+wZ6FEso+Kp/RBIGd3f3OrAQOJBb6sW
y4egLHTzeVtnBvIbzJkyZB+G0ZmtzXn3GAgNrpzfEjEMGvWHXksHMlBk5HhJ
XPJ3INvcCF2XykBLc3Z3CoJ+QlrG+PuXDxhI3a+vPK36J+ztsls9lclACR22
HuWLP8Fczc0xPJeBRLX5j/hZ/4Jq/ihTzsL/+5ESlIBHwLOkTGnuPbH/xvM/
/T/8BpExtVsJDQzke7v+xvG/v+G5eO3jvU0MRNVg5z8tOwr9gS2b77Qx0Nnu
kMHL90bh0IXvlLEvDOTFIxtrLTsGnRGWR4P6Gei3c1fLx5NjYF0zeW/LIAMd
dI3sDXEYg5Qdc4yrPxmoxiEvXbJ6DOaXeb72TTMQm/s+o4mz4xCtFLPelclA
u2LSGk1o4yBvKWIg+oeB+jUzc1VTx+F8u1Sd4QID/deef3z/4Di8zt7/opmD
iaKx+64bVybAQdPM750YE105r9E4qzUJ35fuhidsYqJOv3d88zcmwaAwMMFW
gomO5C6cuOE7CYobCh5vlGOijTb/KQaXT8Lo+L+PzrsInHWPW1J6CowyBLr1
lJgIGmKc8lSmoM5QbkBuPxM92mby+NnpKciuPMnoVGWiNTonkmS9p+ByZIrw
Lg0mGnhWaLzSMwVN6gXiFG0m8j2Q1eM2MQUqc9Vbv51kotzK4zNuq1MgcmVM
Oew0E81y5cgJbJ2Gjj3KJr8vM5Fj0sz317emAY+ctHhnxkR1NS9dfT2noSDF
zC7BnImyqkP0ByKnIZwjyOeYFROZfOP5olswDRrd3bkZDkw0bnZfa+voNJSE
jBU4OxP8S4oOp8xOg+yR5VI9Vya6rWyG80h0YHss17TkyUSeDbvMkzbRwe6S
8qdOHyYqV5m09NxGhwF+3f4n/kxksy5lK2kvHd7QHKbPhzKRFIvtAUOLDtsV
guYUI5go3ueJz0VDOiQNp7BRopmoV/rod2sTOjjr1AiVJDCRzs+FFbc7dNi9
WfCgQBYTrSKmi3csHdLb5fDvh0wUO2daq5BCB74AZe13j5jIWmFsODCLDuNT
ZpdsnzGRnCw5QuMFHYyzHa4fe8FE4iuKAs9f0aHBKOjWxiImYm+LPln3hg45
UOD1oZSJIrklc/ga6CDkWBOcUcFEBS5ldaiZDj7yPTHOb5moVc6tZVsHHRj9
Yyl6VUyk57lh+n03HUxjlh/K1RL5KOn/FeujQ8sJwedLdUzUI1gwKzdAh8OL
cq87PxD+vtQNHhumw4Zruh+8W5nIQYgmljNKh7vx4brbOpjoUtt8q9UEHZrq
mttbPjGRhN4D25kpOsjO8Z5z7GGiRalWrWMMOrjL633Z+IWJivsVXl5g0aHr
QoRJ9Vcm0oziXa/8hw4KYS3DlgNEn8eXUwdm6RBYyWexdpjg95DppDtH5DOl
N17yg4kaDN6V+8/T4YBk5O1LI4TfZS7koAU6RBm0stjHCD4N458NF+kw6rPW
JW+CiUgLw/smCIyL9Zf0p5nIkvN0+qklIr+fkV6zDCYyvXSB6UVg5vo2jrQZ
JlJUnjHwJLCOJn+w+l8m6ue0/6pN4GzaKd6xeSYa1eOq/knMW3wSFR21xEQa
O7qT9Ahs+LVN+MAKE6U2xqn8n88zXoHkfjYWElnhEo4h+JKPGIj7cbAQd/ti
jA2h57JddNZ/FBb6IdjaKvqXDq8y27e0r2Ghq8dAM4HwY22nQL4zDwutfWqq
+pvwy4LjtKL4Whbab7xRlYdJh3f7YopqBVjosIuAKAedDqIWHQes17EQu3XR
ZPskHe7cF3wjIMJCKdX2/fbjdPjw4TQqFWMhSl5K0uhvOkgvxtSabGKhj6Kl
//b/ooPbjk5NsgQLSeTH/rrwnQ47Is8YnJZloQfTP49s66eDP8R2zW1hoWSF
3KiOXjr0MzqN0+VZSLo3ZPIs0adIQ8OrEwoEjvz6ZrSFDiP+cb9idrOQf9UX
7YVGOqDXn24q72Uhy9XsHz/qiD6Knb0boMxCk6vPGvTe0kFLJ/7vjkMsVBi1
Dj6W0SHrXpdbpxoLRfFoGm0tocOZgbN+ksdYKJU5jB3z6VDy8Fx8uR4LcZaf
M3BPoANvd4LYFQMWktQ3/TgZRYcblJ40iiEL1Z3pkzwSSgeRm0a5hsYspFVs
tcfXkw40xfOvp8xZyOYGCGfeoINauXGvNI2FfjWu6w9TpIOt9bYd7PdYSJbn
EX/cVjqkbfrrMeTBQj0f97i5S9BhySNONsOPhTz9LDbP8dGhXL319uYoFrrk
12eTOjEN+5uPcYo+YiGhO6afVrOmQWFQUYm3i4VcmjUeTy0Tz8/oZf+JHhZy
yp5Jo85MQfjR5s9NX1jo5Zs3GfyjUzDx8KZHyCALDUWarYx3TMETq5wPlAkW
Uh2diBrKmYItrA1m7KQZpJUkrz+vOQXinJzhf3fNoDgBkXM1/pMQGPLR6YPS
DNKfWXljR5uEab5Ys5T9M0ig5QxL2HYS3olI7j1yaAbx/akLPW44CVfkVfoC
NGbQB3PtZHXpScg5eUt+vckMklJ/kT30ZgJ2xna/3xs6g14PiEu2T46DquSj
5Ts/Z9CMlMU8PjEG3Q4Wqk3hf9CURFd9h9II7HxXv/H8sVkU/7jzwmvBH8B2
TKO+ZmoW2e2U+ZtxewgEEyt2dcX/RfOrRo00nX4YHGg9vEFnDrlxvtDUY++F
yWe7mt/qzqGu0a1LKcT7x6Jb9CXzU3PIpj84+c+PzyAsesbt6dk5JK2T6FBd
/xm0TnWXqpnNod2HXY42hn+GIviqZO44h6KnOGsTN34G/8xR+afpBL6oL7pJ
rQe2m5PWq83MoU8HFLQX0rpgbSHz7sa/c8hWP9TfI6oLWMtD7XPzc0hFt1uW
x7cLKpIhvGhlDoVkzLw4btkFJzvcyfLc8+jfla7mXUpdYIvnZoSk51ELW3zS
UOMnKJCY7BzVn0cxx8RF/Ng+gdLX7uj4/Hnkc4F9xCekA079qwy4/nweffxY
wojy7ABb8Ry3fYXzaOJJndsjhw54ZHb3etereVQ+WrB30qQDNv5cqyxcPY+8
s7mte5U6gGNKczDu8zxiqB7fdXCgHbpWyhXiyAuoanZutlm1HVxk0ptiTBfQ
4b9tapzCreBZ9VJ1z9UFJN6UsF2YoxUCTevy268toIutV1h7WC0QnzIZyn9z
ARVqXLOKaG+BQqFDJyMcFtDp2zUvGiNaYJTU+zE4eAFJf9qfbM7dAsY/BFu8
ihaQv5VZ/COeZlDJCWi7RVlE7pUVohY7m6B0Ex/No3IRNbRc3hESWw/FLcUT
NhZLKJrPJkMmvxZsnBZJkRL/UD+/De+531VwZWJ/77lP/5A6+5TQC+G38Ck1
mvbv3jIS4QXLhxrlYBuYOfzZcxlVvbxV6niwHMj2hTrFPstodMmw6ph8ORzQ
aN9sHbSM7MZuxAlyl0MSg7/6c+wySsiPt1RoLQPTE1FcxU+WkdwL5VBP4zIY
n45Iufl5GUX8GPE0cyoFknpYZY/SCtobWTr0uO0VBDxpyPTZv4Kq5nY8X619
BWsEyQE7lQn8dPDetbJXwDfkruertoLKWGJdqlmvQMzz9oCC1gqqUBdnM3V4
BQoVp9kCTFZQ/XOagPGGV2CsJHZ8b/AKcgy9cZDdtgQKZHI/Rn1bQQde3She
2V4M1iZfNBSGVtDPi2T9fOli2JLEV9P0fQWpOljcNxcrhjQ+5zLO0RX0jPJn
yxBnMYTNa+TeY60gblm7S1rDRWDVOuppSV1FTbwnA68nF4GM204ltGcV9YX7
iq7lL4L7HcVJ0/6r6M7rdLu1a1/C9nDn7++DVtGcAOnaG86XUKmhsjM1dBWJ
kjfEeC0Xwvc370AzehWVmWRLCE0Vws5HjSOZqatIZGb7TefmQqhyG9xnWLSK
bur7JLqHF8K4LE9H6eAqYhVRRVcECkHi0Et/LM6GJ38tlj44UwAvtifJLNiz
4cbRGncR9BQk1p+K/djChkNChiymZPPgmQXbMGMbOx7MUp7VVsoF13NHEzjd
2TFFns528n42SCVfOHXXgx3vyj+sfTs8G+r77bkGPdlxW9C+hRc+2SB8Pduj
zIcd53X+3Khmmw0FdzksbILY8doPQYo+R7PhZ1TdgY5Ydlz8gHlmz1QW6Ddp
96Y9YccbjgzsvqydBbN85rFcT9nxZ9nH/11DWZB22k3X+Rk71r5gN2q2PwvG
evOrTr1gx1wn8g76S2eB/2+eJ6RX7LjpgFuw5GImlJNbXa2q2HG2xfeBt88y
QQ6d2bTvMzvuqB6T2ySWCbiaLS64lx0bpC9EFPBnwqVjL7i/fWHHYnL59BPU
TIjV5F0M6GfH1ppdO3ZPZQC7QX3v52F27DgRIXXhaQYMXFFNvDfJjv2bterN
t2dAkq+MYC07CXeMm6vR9qVDCbkjWJSDhONXTKQebkmHtkAvNlsyCe8jRQyP
iKQDJayfLkwl4QlNHh3XhQfgFJfYasFLwsHrtfvewgM4k8Mdzi1Kwrt1t/bu
O/UA+OpZlDM7Sbiq5UJqpVsa1O8Rb8pQIOGuq93HD91OA88HmhFTiiTcdyJb
b+pqGkw7pq0L2UPC1psF21W106BVVkOq6gAJF0r5ddWLpUGUT7KK4lESPr/c
fbG6IhUE1bAttxEJr5Ifxxhzp0JTnvUu4/Mk/E6k24C5mgK+wgmsXGMS5hOy
L3SaTQHWxBjt6CUSVkov2ftiKAU6U+ICaFdIWAiuUT+WpkDc/Ej6iDUJf1GM
2s12MwXWl0R01HiRMK9QAvlEdzKUma0u7fQh4fzA/cOvPibDZR77rfd9SVhe
1vbBwZpkyDE/e88mgIQ1snMsTF8kg5Lgpi3CYSQc+I/Bfjk0GfRv59FuJJLw
2oitV+rVkyFYvlZyzXMSXvJRiC6rTIKltPlben0k/Kd0Mefkx/sgJTtj16DI
ge2cdFXk5RNBTk8d9u/mwInmo086pRJB3iVmbc4eDqxsfOxrwIZE2P1x13Pv
fRz46ytdx8/ciYAdbMdVVDmwV8WiHNdUAlyt/XX92QkO3Hb5Val7YQJkX+u9
EHOZAx+KPMaXoZQAsjlvj10K5cBT+vx8MtLxkMb70OBlGAcOdeYSfScWDyJO
wSbUCA7sUisif1QgHtZoGLoUR3HgU1cD95qsxsHk79F8ngQObGlyNkj6WxyU
7BAWqszgwDtLOtXC78fB8WLroc2vOPAWx21Jdmvi4EaNqMfAIAdu7lS8vzAQ
A27Crt0KwxxYKv2b5PvuGIi26FPw+M6BW2029Yc0x8Ab7gcDm35x4HPqaYPz
5TEgaCiDL4xz4KYjz03ZE2Lg7Y+dHF1/OHD9RYX5VZ0YWM+pHtLIRcbcnbZd
+8uiYfv5h8NiPGQcuTnTn/1FNOAnZFUrXjKWLfluNZ0bDTZ6DeMUfjIO4JB5
+i0uGqoTdHWPC5Nx/k6z+9120XBr63l+kCDj41WHeiLlo6FO0zahZC8Zb7cv
K9pwOArqvwifk9pPxvPSel7h/xHY5q1w+AEyvl49+iNONAo+RK2Nv6ZCxjqy
mf/tmImE5s+FsUKIjElWpBL8NBK6LGej7uiQ8RFhWlyEZCT8DPIM3XmVjNN/
pmeQxCLg14ZtOknmZGwlFCpEWRMBI0/buMjXyTitk7vcbT4cRtukQr5akLG8
GOVH3JdwmBStDQq1JeMi+7+0hrRw+POYGjDqQsZNBSYPp7aFA8eHaK+cSDIW
GpWsSz0dBrSktn9zUWT8p/ZLUt+JMJi2Wut2MoaMO7flVhuqhkEfV7gjK46M
3x0WmZWSDYOik0E3cTIZK53QJoX9DQXzNg/D/odk/F5A/832rFDozahs35VL
xs7POmu6E0NB/86Snt8jMq4cUrX+ER4KqoKuWtufkLHyhCT/W1ooCBk6qtEK
yFjfVrDA5HQo1PRYbxMuJ+Nw9/VSh6ihoPz4SY5lBRkXbiitUF0JgQKXUek3
b8hYdfWxiONsCKSIWWw2f0fGA8d36pX/CIG7F68KFtaScZ+gF4jUhID0wPml
k62EXk3orvQJAe9fx9v8fhD8Q8sU+NeGwPfZpuKZn2Q8WffydTklBI5RTidd
GyHjaXWpW96rwUDZZnL12BgZlznucDZmBkO4ldMMiU74u2NWrLI7GO5P5Ir6
LpKx6TqZ9KXMYChgUq54C3Jii9g116tQMAiQIo4zhDgxK6mwblElGOyF1v13
RZgTb22pPrhnXzDs2yvJQqKcWOjj6Z54+WAodzzov7qZE6uvefhfomAwvJ+z
zPOU58TWbH9UHv4Mgq/LHxjuiBPzKhToz4cEQe9ck9QI5sTve3tj1f2DoIfZ
bHBKnRPTOqvWOXkGQeev9kLpE5xYn9+lWs4hCJpaeu/U6xD8umnGg5eCoOLB
KIPfiBPvThASOLQzCJLU1jCzbTnxdNXE2fG6QEg8yC3Ne5sTn827WrYDAiF+
D+9pJztivRN3oV1ZIERvEXipeZcTr/1Hk8vMD4QgPjH7SRdOPLpO5JxhZCA4
f9vG3O/HiSvC9TdkGwbCOQ9N5odkTkzi+XdufVcAfHg1OLAhlROrHrpFlW4O
ANVpl2brNE4caeAdZvY+AKTM8h7zZnDicPOMYL2SAJjEXKYGOZyYEvTD6F1c
APiTPzZ9LiDur2goohkEQFGYfs5ILSe+fEVollTrD2tTzp0nT3PipOmFCOk4
P7AV2v/Mns6JzS/XTsQG+8HHUGH2QQaRR92LqC2efhB871N++QwnzjMaWJi0
8gN2k9Mrtxc4cf/RiJd7kR/8kdTL/UKm4ApzHb/wCV/oyz0+U7CJgke3S6Ta
afuCsoSc1mZxCtanRCpEI1+4n8jxIESCgle018RN7veFs0E1GtelKfj25ftm
6TK+0GKFUzZso+Dmb4ndGv98oGrH4aP+ShQ86bzx16MiH8h9uTfqgjYFW22y
TVq/0wdoVk+yCnQoeGC64fJXOR/QlZQs4dClYNN+b2EPcR9ghXN/ea5PwZcX
wOESvw9gq2EZ0lkK1gqofts+4w19ElGv800p2Neff8ChyhsKusmNq2YUnPQ3
Bp+r8AafcLevZ69S8EaHJJ9bJd4gv3iDbfUaBY8U8ix75XmDU/dhHcObFCyx
P6gtJ8YbBMLHvy05UPD1UtNBG0tv+KF+hWHgRME7fXfvczT3htcL3aRHzgQO
eS5WbuINJpbV2wxcKVj+mbGI7FlvyFdPss/xJPRNKXL9PuoNngt8/gteBN8u
ntPH1LzhdKFfor4PBZe4OS5KqXjDvLjdm3k/ChbbalWfsNsbTiyc4NQLoWAp
eZKstpQ3iBW+Ec0OpWBhktKS1mZvmLTYs30ujIIF+GUVe8S8IbZr86msSAo2
sJgPkRD0hqEXM0mzcRScl2h4LZfkDW4WWTvT0ymY7Vcqy7LdC8YpcaGTGUS+
/11w+dDkBRcf+4+qZlFwtEd7tu57L1AZtcz5/JDgO6ener/MC+ZvKm4WfELB
tGz71r4sL3C59YbHv5iC52PjmBudvWCE7/nNzhIK7v2orqNj7wVGBekNUq8p
+MOz15foNl5wgO7j97aMggv/k1mNuOoFf+9oLf19S+y3KT1bSM8LHB27x29+
oODde1y/jMh4wU/hBq2yRgpmZNBPJYh7wdlXZY8oHym4Km8BnxTzgr1/U80f
thD8r+8UiuTzApaLeV9/JwXf+R37xGPOE+zv0RtPfaPgdq/N3sUNnjC0aXhb
+gCRR0zenhvVnmBQ2RkwOUj42/O9eb7CE3Yvvzoa8p1YL0ELlC3wBIane3nN
bwo2NjaOPhPrCbd9uZ7sZxF+XOajvTznCY3m6rczZwj9eR/of3U9Qe7Yvb08
s0QeH5SHXY55wleOqbdDcwS2Dn4/uNsTtALaO8OWCT5OVorRXJ7w8AZX0t8V
oi8n0PLEigesnFA3ucpGxYWMjN6iPx7wilLy+wAHFfe2CdBfDHiATPD9f8Nr
qFjepGslv9ADPKzaq3W5ifv9/H515XhArxZXUCkPcX1fY1dUkgdEcd0TjFhL
xcaNpRb9Xh7wL9R0q7IwFbOlHJ2NOOkBnyO2GERKUvEa3WTupV53ULptun5B
ioqrGqpVxhrdIVL/ft81GSr+wEN7lV/hDsf5uW6obKHi0bkU/98p7lAUPen6
czsV07z93nFcdIfwuOKHqgeomFHHQT7bcQ9w8tG5EV0qvpK5tvv4MzcQKBNw
U9En1vcnVHxNcYOhnsF/Yaeo2NvX9r1PiBv4CHuS9pwh9FQWNFhaukFNVAXf
vfNULBaPtA/IukFsQUh0izEVa00vyBQIuYF5i/E6qYtUnPmI94oQyQ04eObE
6i4T+ph//qoMu8LxwL1y/ObE/OAySYUsVxDOJT2+eo2YVxo4pRbjCj9rO/4r
uU7c739qfruvKwSw39l1wZKK5xdUmoauuUK9+zPVh7ZULNV/ikt7hyskpt57
O3uL8JfdSb9B3BUsKnSwlh2hf/vtCjEBV6DOj56Ysqfi4CZXxpe/NNBy2HL6
oAsVC8wEpNAaaCAW++dTCI3gEy+dcLySBqOFtUb9roTfg9KbTr2kQcj01cs+
7lQcLWK0dDKdBhf59gx+8qDiMi9ebuN4GmzfyWa+1YuYf19LsjKMBk030y0/
+hB+7vK1Ub1Hg5TgW+PifkTeTlzUaw40sH58+NYdf2K9eOstcVsaqNbzMGoC
qNhA0uqO2g0a8Pzqu7s+iNgvzHUq14wG/Rz5s5bBVKysWGfteoEGz2RcaRUh
BP8JjgNZZ2ngflRriTeM2P9ejFz4KRroXhH1NAsn/BQs45Y6SYPNXiNsRRHE
er6u4ApNGkw+eOVHjiL2q/JPFDhOg8pKf8r5aKJP/0LsNI/SIOKrYciTGALb
CThOH6GB6aIM779Yws+Vz+c2q9FAcQMrUj+eivM0C7uLDtFg5WC1YFYC0a/X
eoJUArcaRcfPJBL95e6eaFWlQbqTmahGEpHPOsYdPuK6XbxiSlIyoW/j47CH
BMbFy5snUgh/iDeqNcR8gc7mDLU0Iu/sHaL3iP2HGKky0Q+IfGZ1OjCmQSG/
Te73dEJfXKJojToNvBVV5fdnEv3rmu84rEGD03pcT4OyiL6+G9xarE2DgS0a
4ewPCX5bjyfk6NHAdsX31r0cwj8NNbX8MzRY6AH92dz/97nc8dt5GgS++LfL
7jHBZ+0Rwa8mNFgXrCI4lkdg357wC9dpkHnFmWWeT8VWay/yF1rToEKQUWL0
nPCDY2/gOxoNNMd3JrYXUDGuuxx0xJsGXTU3XXQKCf8KrHo/BtFg2uGHypFi
Iq+oXSbbk2gg09Pzbks5FQ9VVSaxl9HgRcG6zIwKoh+drw/cBRocDjLw2VBJ
+Enhyg2tp0GjWYR53FtC78LuK6ktNDBSbjrGB1R8J3KP6d9PNPghQN0SVEXo
lxhSZe+jwZ2xYxT2GsLPuyNpUwNEXtXev91qCf/ZZ//1fKdBWMrbD3/eE/2o
jEvNHiHOg8Pik9v1RF7vzl69O0qDRycPho02UPHu9FH5w+M02CvnaGveSMzz
2XezcYwGVf8K9fqbiPP+y7e57TcN9LqnFI2aCX90+y7H/qRB3/PtAu0thL4/
ftk/B2lgGWjJ1G4j/Jk7XqPZS4M/pjmdte0Ejr7A29JGA5+Dw8VqncTziXpg
kus9DdYKSCSUfiL87TH2Jb+mQeroRec93cS88y6U8lwayFffP/+0h8j3to54
cQwNXiV3KW/pJfp9w7GQSpw/9buCGzO+EP7xTJdKXKFBm47+kthX4vnRZ295
l+jPZdmw/th+Iv8vSry+UjQYW2p4yztAxUnRynfjF13AuYucEThI8BsWdJBo
dwGO50e92YYJvIZ9X3WmC0QHeF51+048r06cKLls6wLipm/U//wg/NcroPop
uUD+gXnZ27+I/4uJa23fWc6gzL+fc3SE8Df2n03hM2eo+20/cnWU0HtyTtrr
ijOcqSpo+DpGXHeyFgvkc4ahpIm8cxNEXjbewT+KnOCWvXxo2yTRxyzan0QD
J1jUvmGjPU3k92f7vNqIIwTJZOvW0gk9G9LOP3NwBOGlAQU1JnGe902W9s05
gOIzY8buP8T1R7vrkr/fhTf+CR35s4RfRuwNN7XugpZJZ5HcHME358J/vA/t
oXs/f3z6PNGvP+fe87DugPlaXSexRaIP+bvjhvbdAfpIsFHsEqH/5WiZe/dt
cIe6g7zLxPmSeczi3XoLuJJIGwJXiPk9Vyo5L9hA4h20uLpKzMuO8Sy2uwn/
A68tYB4=
           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           GrayLevel[0]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.921854379719285*^9, 3.921854600962284*^9, {3.922095249110588*^9, 
   3.9220952660026083`*^9}, 3.922095684367561*^9, 3.922096296320888*^9, 
   3.922096415892999*^9, {3.9220965253798037`*^9, 3.922096537311225*^9}, 
   3.922096861059251*^9, 3.9220969268340197`*^9, {3.9221025856722307`*^9, 
   3.922102631753288*^9}, 3.92210266820599*^9, 3.922105377297548*^9, 
   3.922112654816471*^9, 3.922112688835435*^9, 3.92211274544245*^9, 
   3.922112801212978*^9, 3.922113069067492*^9, 3.9221131128806543`*^9, 
   3.922113398458463*^9, 3.922113440741046*^9, 3.922117714066482*^9, {
   3.92211787058836*^9, 3.92211789607117*^9}, 3.922118131873796*^9, {
   3.922118247172189*^9, 3.922118298835394*^9}, {3.922124925076356*^9, 
   3.922124930392727*^9}, 3.922125145306385*^9, {3.9221253843743477`*^9, 
   3.922125398329878*^9}, 3.922125633673955*^9, 3.922125792223668*^9, 
   3.92212614553662*^9, 3.922126756089397*^9, {3.9221281370078*^9, 
   3.922128151316674*^9}, 3.9221281838634777`*^9, 3.922128568586461*^9, 
   3.922190830742669*^9, 3.9221908993593683`*^9, {3.922212476404984*^9, 
   3.922212501437051*^9}, {3.922212573977461*^9, 3.922212597857647*^9}, 
   3.922212743384413*^9, 3.922212781884246*^9, 3.922213123665017*^9, 
   3.922213163766214*^9, {3.922376145494557*^9, 3.9223761610046062`*^9}},
 CellLabel->
  "Out[619]=",ExpressionUUID->"4e075dd1-d1e0-4761-b178-a4fb0676f193"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"mmaOLSParams", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Abs", "[", "#", "]"}], ">", 
       SuperscriptBox["10", 
        RowBox[{"-", "7"}]]}], ")"}], "&"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", 
  RowBox[{"Abs", "@", "mmaOLSParams"}], "]"}]}], "Input",
 CellChangeTimes->{{3.922122500442021*^9, 3.922122553337991*^9}, {
   3.922123070011699*^9, 3.922123070324998*^9}, {3.922125463949711*^9, 
   3.922125467667141*^9}, {3.922125537173141*^9, 3.922125538859332*^9}, {
   3.9221269070084248`*^9, 3.92212691168083*^9}, {3.922128204129221*^9, 
   3.922128205272566*^9}, 3.922134645319104*^9},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[620]:=",ExpressionUUID->"81ba87eb-c6c9-4a12-8f86-0d92d68f03c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128206346868*^9, 3.92219084509625*^9, 
  3.922212521163567*^9, 3.922212750776075*^9, 3.922213127290664*^9, 
  3.922213166210259*^9, 3.922376170450118*^9},
 CellLabel->
  "During evaluation of \
In[620]:=",ExpressionUUID->"e4a3ede6-b66e-4ce9-88cb-6ae5d251e303"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.92212545110802*^9, 
   3.92212546825169*^9}, 3.922125539688526*^9, 3.92212565102081*^9, 
   3.922125797816332*^9, 3.922128206432444*^9, 3.922190845201551*^9, 
   3.922212521261957*^9, 3.922212750865664*^9, 3.922213127381621*^9, 
   3.922213166303309*^9, 3.922376170569045*^9},
 CellLabel->
  "Out[622]=",ExpressionUUID->"a81b67a0-2778-433b-9b03-0669213fc293"],

Cell[BoxData["4.217140109826238`*^8"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.92212545110802*^9, 
   3.92212546825169*^9}, 3.922125539688526*^9, 3.92212565102081*^9, 
   3.922125797816332*^9, 3.922128206432444*^9, 3.922190845201551*^9, 
   3.922212521261957*^9, 3.922212750865664*^9, 3.922213127381621*^9, 
   3.922213166303309*^9, 3.9223761706481647`*^9},
 CellLabel->
  "Out[623]=",ExpressionUUID->"25d6a2a7-ac82-453b-b6d4-8f6c93b4a3c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"yTrain", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"X", ".", "mmaOLSParams"}], " ", "yTrainStdev"}], "+", 
       "yTrainMean"}]}], "}"}], "]"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Actual\>\"", ",", "\"\<Predicted\>\""}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "->", "14"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.922192774043182*^9, 3.922192800192538*^9}, {
  3.922192865475978*^9, 3.922192866407288*^9}, {3.922192937572435*^9, 
  3.922192952452139*^9}, {3.922212552167778*^9, 3.922212555543439*^9}, {
  3.922213141244128*^9, 3.922213143821607*^9}, {3.9223762083820877`*^9, 
  3.922376218889764*^9}},
 Background->RGBColor[1, 0.9, 0.8],
 CellLabel->
  "In[625]:=",ExpressionUUID->"bbc96b7b-0c89-4c16-9f7c-698245ec32a6"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.009166666666666668], AbsoluteThickness[2], PointBox[CompressedData["

1:eJwdk3s4E3ocxrUS50RWJ0o0i4l0QTkq1G9lqFCEikp0c0/mtiKmJisq1KYk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         "]]},
       Annotation[#, "Charting`Private`Tag#1"]& ],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{
           Annotation[{
             Directive[
              PointSize[0.009166666666666668], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Point[CompressedData["
1:eJwdk3s4E3ocxrUS50RWJ0o0i4l0QTkq1G9lqFCEikp0c0/mtiKmJisq1KYk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              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-1.2109515915218791`, 
             0.6170360819844698}, {-0.9897360656684804, 0.442381213695171}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
            "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
            GoldenRatio^(-1), "DefaultStyle" -> {
              Directive[
               PointSize[0.009166666666666668], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-1.2109515915218791`, 
            0.6170360819844698}, {-0.9897360656684804, 0.442381213695171}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[0.009166666666666668], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{
       Annotation[{
         Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Point[CompressedData["
1:eJwdk3s4E3ocxrUS50RWJ0o0i4l0QTkq1G9lqFCEikp0c0/mtiKmJisq1KYk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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-1.2109515915218791`, 
         0.6170360819844698}, {-0.9897360656684804, 0.442381213695171}}, 
        "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.009166666666666668], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\"Actual\"", HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"Predicted\"", HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  BaseStyle->14,
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.2109515915218791`, 
   0.6170360819844698}, {-0.9897360656684804, 0.442381213695171}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922192802593913*^9, 3.922192867166475*^9, 3.922192952886853*^9, 
   3.9221929836691933`*^9, {3.922212532969882*^9, 3.922212556607738*^9}, 
   3.922212622397669*^9, 3.922212696999492*^9, 3.922212757012082*^9, {
   3.922213132075009*^9, 3.9222131684880533`*^9}, 3.9223761816055937`*^9, 
   3.922376220096326*^9},
 CellLabel->
  "Out[625]=",ExpressionUUID->"d4700a12-b7ce-41d9-bdff-f74e9ccae251"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ridge regression", "Section",
 CellChangeTimes->{{3.922108230321486*^9, 
  3.922108232959588*^9}},ExpressionUUID->"d94d888e-ec2a-43c0-931f-\
f217936de121"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ridgeLambda", "=", 
    SuperscriptBox["10", 
     RowBox[{
      RowBox[{"-", "9"}], " ", "2"}]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"weight", " ", "of", " ", "regularization", " ", "term"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.922122829349701*^9, 3.922122848737938*^9}, {
  3.922123012687141*^9, 3.922123013389862*^9}, {3.922125991755205*^9, 
  3.9221259935062523`*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3440]:=",ExpressionUUID->"1c98e6f1-af0f-4f5a-bcc0-6dfd58a894e5"],

Cell[CellGroupData[{

Cell["Mathematica Fit function", "Subsection",
 CellChangeTimes->{{3.922126425033379*^9, 
  3.9221264291936493`*^9}},ExpressionUUID->"2a3133d3-f718-4076-a504-\
7d2b056ec1fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wp", "=", "MachinePrecision"}], ";"}]], "Input",
 CellChangeTimes->{{3.9222124412437687`*^9, 3.92221244752201*^9}},
 CellLabel->
  "In[3338]:=",ExpressionUUID->"ce7a7d34-f866-445e-aa9a-d78bcf57ea8d"],

Cell["Fit function from Mma Fit with Ridge regularization", "Text",
 CellChangeTimes->{{3.92212206085918*^9, 
  3.922122076579733*^9}},ExpressionUUID->"31b900d5-1050-4e85-be95-\
6b52e0deb81b"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\n", 
 RowBox[{
  RowBox[{"mmaFitRidge", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Tikhonov\>\"", ",", "ridgeLambda"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, {
   3.922120424797739*^9, 3.922120447099926*^9}, 3.922120706798108*^9, {
   3.92212830740444*^9, 3.922128310335128*^9}, 3.922134648997183*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3441]:=",ExpressionUUID->"e3723530-37e6-4744-b85a-ae4515ebc664"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128311034256*^9, 3.922213192525547*^9},
 CellLabel->
  "During evaluation of \
In[3441]:=",ExpressionUUID->"660116db-7860-499b-9719-11114c59e244"]
}, Open  ]],

Cell["Coefficients from Mma Fit", "Text",
 CellChangeTimes->{{3.9221220461160088`*^9, 
  3.922122054900242*^9}},ExpressionUUID->"fa4765c9-c3f0-4795-abe5-\
dda6d9cd4aec"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\n", 
 RowBox[{
  RowBox[{"mmaParamsRidge", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     "\"\<BestFitParameters\>\"", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Tikhonov\>\"", ",", "ridgeLambda"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, 
   3.922120424797739*^9, {3.922120457049314*^9, 3.922120466507172*^9}, {
   3.92212070907828*^9, 3.9221207184858937`*^9}, {3.922121718833121*^9, 
   3.92212171976037*^9}, {3.922125507532485*^9, 3.9221255130820503`*^9}, {
   3.922128314495399*^9, 3.922128326619739*^9}, 3.9221346497994227`*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3443]:=",ExpressionUUID->"99e00cf2-6fca-4405-a048-13c3f163d6aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128317559909*^9, 3.922128347842922*^9, 
  3.9222131971544247`*^9},
 CellLabel->
  "During evaluation of \
In[3443]:=",ExpressionUUID->"5c0a0382-724d-44ae-9cff-32812350d099"]
}, Open  ]],

Cell["Count how many coefficients have magnitude above a threshold", "Text",
 CellChangeTimes->{{3.9221226346627607`*^9, 3.922122644968471*^9}, {
  3.9221265529849358`*^9, 
  3.922126561915202*^9}},ExpressionUUID->"64874937-abc5-405c-ae1f-\
9eafc9048092"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Length", "[", "mmaParamsRidge", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"mmaParamsRidge", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Abs", "[", "#", "]"}], ">", 
       SuperscriptBox["10", 
        RowBox[{"-", "7"}]]}], ")"}], "&"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", 
  RowBox[{"Abs", "@", "mmaParamsRidge"}], "]"}]}], "Input",
 CellChangeTimes->{{3.922122500442021*^9, 3.922122553337991*^9}, {
  3.922123070011699*^9, 3.922123070324998*^9}, {3.922125518779883*^9, 
  3.9221255313495493`*^9}, {3.9221283314183197`*^9, 3.922128338757143*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3445]:=",ExpressionUUID->"e1a5b057-c311-4c96-bb6a-910d65381e37"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.922213200300407*^9},
 CellLabel->
  "Out[3445]=",ExpressionUUID->"a1ceca30-7996-40fd-b8bf-ab0adf8e309c"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.9222132003648787`*^9},
 CellLabel->
  "Out[3447]=",ExpressionUUID->"a35df2be-1b37-4a77-8f39-74e9129047aa"],

Cell[BoxData["4.03288193090547`*^6"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.92221320044561*^9},
 CellLabel->
  "Out[3448]=",ExpressionUUID->"7e29495c-d5fd-4142-805e-d4630ca4cfcd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MeanRidgeMmaTest", "=", 
   RowBox[{"Mean", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "->", "rTest"}], "}"}]}], ")"}], "-", "yTest"}], ")"}],
      "2"], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<MSE error: \>\"", ",", "MeanRidgeMmaTest"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ridgeMmaPlot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"ridgeMmaPlot", ",", "LJplot"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9217687936291533`*^9, 3.9217688327658987`*^9}, {
   3.921768864444922*^9, 3.921768870848134*^9}, {3.921769486805279*^9, 
   3.921769542793608*^9}, {3.921770940634282*^9, 3.92177094183883*^9}, {
   3.9220952593893003`*^9, 3.922095259496469*^9}, {3.922096300918138*^9, 
   3.922096301503976*^9}, {3.922096529892295*^9, 3.922096530718207*^9}, {
   3.922102592447061*^9, 3.922102645533327*^9}, {3.922112668774447*^9, 
   3.922112669746542*^9}, {3.922113273091929*^9, 3.922113279521315*^9}, {
   3.9221190633074493`*^9, 3.922119078179054*^9}, {3.922119127356476*^9, 
   3.9221191312846127`*^9}, {3.92211919570715*^9, 3.922119196419444*^9}, {
   3.922121506969965*^9, 3.92212160524834*^9}, {3.922121643794643*^9, 
   3.922121646650465*^9}, {3.922125240798301*^9, 3.92212524639273*^9}, 
   3.922125723549638*^9, {3.922128369111349*^9, 3.922128424159648*^9}, 
   3.922134650736749*^9, {3.922213218065336*^9, 3.922213238309901*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3454]:=",ExpressionUUID->"bbfa349b-70c7-4143-8ee3-6acd79f2c2f1"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922128417419879*^9, 3.922128425510849*^9}, 
   3.922213210445242*^9, 3.9222132413216867`*^9},
 CellLabel->
  "During evaluation of \
In[3454]:=",ExpressionUUID->"abe4f38f-ddb8-4f1c-b946-465e5f5af172"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE error: \"\>", "\[InvisibleSpace]", 
   "0.00037318508294156773`"}],
  SequenceForm["MSE error: ", 0.00037318508294156773`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922128417419879*^9, 3.922128425510849*^9}, 
   3.922213210445242*^9, 3.922213241399157*^9},
 CellLabel->
  "During evaluation of \
In[3454]:=",ExpressionUUID->"8bba4347-b227-4c69-9c62-3b3353d365a1"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVV3c8lX8Udo1bESFKZYZSiVAZje8b7ZRVNERUSPYeGde41yw72SQiZFUq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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVV3c8lX8Udo1bESFKZYZSiVAZje8b7ZRVNERUSPYeGde41yw72SQiZFUq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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVV3c8lX8Udo1bESFKZYZSiVAZje8b7ZRVNERUSPYeGde41yw72SQiZFUq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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR
IZkaNKgQaXCnMg+Z6U1Ckumc5zwPEpLf8/tjr70+a6917eu+7r332ipO7oed
hVksVgsz/n9OjbUtUzpAwi+z9pNC1/vAzczZt8aeBP2WuV9uGfVC8XWvmWuR
JDiy/lFSqOgAjnXU7u+xJBBh/nUp/u2gp5BzdUciCU8b+vdI67VBblqXwnAG
CW9N03QfPG2G7Jx9m/cWkbDCMm37t9w6iEFld+FeZt07wN1nfxEcuLSt8OgP
hovOxW0Tz4f5e6xmno6QwEpPOvIo7TGEVUdcdZhg+MXDk+LqyVAyNGVpLy6A
t4Fu2keaMzF/3Nnj1VIBCMLVJ00vvUcZm9FFfy9nmBXCLd5Zhh4vLhTJqAiA
cJRwDZ0uRx3/lD+nVzJcaLLVx74a77MaI+U3MHrKGcU55xowbf6OHB9jAUgF
P/lV6teGM65VZir7BOBx49TyhvXtaFdvLag1FUDSSER3YF87KsSe26JuwegF
xXY07v6E8XL3yppsBZB+QxHmD33GKyoyvevOCUA+ZG6vmEs3rrBOXFbvJYDs
ghNV83K78UXEMhtXjgDuuzrOyI9348Doytr7/oz/qpRQ2ws9aFy+vVAlTADd
YqWAV3tR9IxzxKIUAbRYvqlT4vZh6u2hD89uMfvZgOyXZ324scV99mC6AGqF
OgtrhvrQycDPO/KOADoGOl7Cse9YujDaXuwp4ze30b1kXT/+W/BCd+KDAD6M
Z27pLfyBcoMGZxMqGD292oaYvh/4WOn9vY3VAmD5oUq09AB2htUt8/gogCMt
FhaXTg/g9qO94oOfBJDqtP+hj/QgNl37e2d4J6M3Z3CgZesg/vNuxF/jqwD0
yqs3xJ0YxGStCcGJPgGMJI+90H4yiL9m5n/+jy+A+HdjnkuMhjBGN1b2PCWA
y1wZ1g2XIdT8W+7QkjEBXBiRagi6MoQ2DSvKLCcF4DauGppSN4SFmZue1IpQ
cKPhpt/yg8PoZeIQXCJPwQ7xV9dv649g77RnZMJSCuaZ2GlXWY3goadhCa7L
KWiQqfB38BxBHYXce4rqFBQqjkp8yhnBgaHfNZx1FJTst2vWkeGh9W2pVnNd
Co7ZT7B5a3hYZqnepb6JgszuR+oaRjzMfG0qaNpGQdxPn2NzPXloF5W8eJ0x
BadEfmTWVvGweleukvg+Ci50t6mGdvFw60Tpyi+mFCzX+zf7Pc1DOcdB/asW
FKxUsDnTocDHxg36x3/YUVD7VcnhshMfiX5TlxIHChT36p1I8uJjbrKDe4IT
BdyGiICtIXyMFAm/aHSKAvXGnl162Xw0bm29c9uLgt3jhsrrv/Kx4MpgLodD
getZPzneCB/VDGeKzM9TcF961mLPFB9Z99Srp/+lwON55OnaRSS62+o3N12k
wM1t8b0ZZRK7Fpp15oQw+emOD9drkfiK68W3iaDgaXPHGutdJK7RDp/QuUaB
xBpXV0lzEpN6klniMRREyV/dfcaGRM7+dzIFCRQ4hq/VWHKGxPXLpLdIZVDg
+WbdhFUUiWkN6sSPLAqMDY0OW9wgcUGo/r6SuxTk0c4fJ2+ROMRzsHV9xPgL
NzC0fkTikUyvv4yeMPmkqK6XyCexwjr8rGIeo1cQtturmMRszA2qLKJgTud0
4ZEyEmW8312+/ZKC33fdZjuqSbyo2RbLeUOB4UNdkGwgUdA5mGz+lsn3+re/
JltItI+dyVJ/T0E6GW6X8onEuj3Sj6fLKFh/MGnh+BcSd0ypFzZVMn4IcWd2
L4kKJ80qL9RT8OCmSdjRQRI94yPNVjUy52fkZJzzCInVZbUNdc0U0GYG3M0k
iWoTElbebRRccqsdrKVIDNA0/6T4iYK7hgaJq8dIbDl67XjpZ6b+wFEd858k
al+t6/m7i4ID5tHH9X+RGPZ6gYtkDwUBeVTd8CTTH575UME3pj8SO1efmiZx
s3KUm20/BaqBPLnc3yRGH6qnhQYpcDF7vqNkhsSBi5K+94cpSN2SY3jzD4lE
/oHpA3wKhl6tR5hl+tcXFTQuYPKzlHTIY5iS/SiSOkrBmjsn31AM7zdZeHnX
Two2P33u+4fhTO5BicFfFNR8E6z+xPBUTnRM9DQF/bpn3S4xbPn54+LNfyi4
rkh/mWL2eyQhdbOTRYNr2suFRgyLGh5SChahwXnb+Zu2jD8795iM1eI0xFbb
LtzD+H+e3qDRMIeGu6cWirKY+iSbpB5w5tOwmnlhrjH1u4hY6ChJ0rDBcsPj
kQkSS/Ri895L0VBplBSkzOS3xKVx8z+LaOicrZRYyeTrkSj9SkqOhp2eGt0s
msTKSgsokqchUf1O8FOmPypTse+PL6Vhe0dH0CYeiX5aTSaiy2kAOb5tzBCJ
WlGHD1mo0bDlWFJVVR+JIRjXMqFBg1p/kVNOD4mdgqYjaZo0qA60DDl2kRhl
aXliWJuG7lVBlUfbSewPuf49dj0NDSvZS1ObSYTC5tP6G2moKrps/eIjcx7l
/+cZqk+DGfuk94UKEvfuj/+ptZ0GEYeYfdrvSczwb/FrMqDhXKML73kJiYe7
/hesbERD+qWt5+2ek1iQZRVfbE7Dt+E8k/kZJEq0Jsg7HqJBqFR4Z1YKic7i
baniljTcJ5KSFZn7Jnfa+o7lERoc08JUciJI5OrYFPKcaJDR2qVh4UmiQfGR
DhUuDXsj3F6s3EGi6z+rtIT8aZgT01i6V4/E1KU/A7sDmTxaFvBN15I4HXhd
7XYwDd7jlcETS0ks3lXvtiyahmqHF2sFk3zcVGsktuQuDUomYykVT/mo/VVH
V6KFhqySqaQmCT7axcyEDLfRYJ9HqXwXYt63nbXt1Z9o8D8eqff9Jw+Hs04H
XvnK5PdQzuBJNw9zTmVXig/ToHC2J94rn4catIKDkPAoBE3GAsuah0piYpE/
141CeQ1Rszh2BMOu1PhU6o7CypHa3IyQEeQviHNI3jQKupN7pTW4I1gip7zR
cPsoxP9w0ZRyGEFHza3/hRqPQvZAzOHAtSOYbXpWU/b4KGQe/2L0tWwY18a1
ftgYMQoi4dvkhceGcJvy3RmPvlHYrzXnxzrjQWz1ctlWHTkGjhaaoRGr+3Ft
SbmijdE4iKq6yr8U/YYsI+Pyd7xxMCs9U6jE/A+kb7xc1xL/EzrN1hSdNu3E
r131OxT2T8AqitM6KtuBa5yEZQ1GJ4BfYjO/81UL6n5ujYl/8AvaTPO2y95t
RF/VtOpY+0kQub8sdt+GetyaHfrxrPgU/NHm/UWsqsaipQu4ga+nwC5B2b3d
vRzz6/KHz7hMw1HluJfR/77HMz5TwlHLf8OGXna8fdVbdBze1GHV/BtSDYfn
Gcu8weaUGO5v/xmof37tM8e/GIV3XX3dpvsHwgyLUiJXFmKu6p2a6C9/oFLT
1LnNPx8TG/OT+CGzwPJp5jzSf4bLtz8LIZRYhHcJDC7Uy8Una5JUJ8+xiC11
TTFqlQ9wuezBuJo6FpH3IsbYI/YePnJh9QhWCRHHKvpu/9eWjeetdiaIBQgR
bY8PK7ulZaI6HF6q1y5EpN5xj8gNTscF5bT44bXCRN1FVtyKxFsoW3Ct8V2Q
MNET2i/afCsZp1N/nTX/T5jg23KyDMsTcYXaqHuFjgiBNSpw1z0B1bLfGNlG
iBBOi7T2huteR+d3SwK7vooQ15znlVoejcUyE9eEgo2ihNtiR2otNxpFKmOC
sqNEifgNBZ6TxyLxwvfdH4O/iRI38/Zff/ThCn6eqRQEgBiRML3Hgr87HK0C
TajKm2LE58l0bSm5UJRMtrIR5YsRi61cWmWNgvHOs43RR/eJE+3p3g9/B1xE
P5eMtWlp4sTR9nmHfFkX0O3S3JxNtDhx5kAyPdchEImbOyf6zdhEpFjW3jc1
fmhhPvdheAabKHap2BqXzsUuDeNIoSw24a3mx7dL5KLrn0tn/bPZRPfssrta
UVwMe/J7nfs9NlHVtU2u1Z+LL6UFBdaP2YRaiek7Gxsuqra1lWgUs4m2DOFY
xYVcHLPPbnrfwCY6fAr8L1/0xYtbevINmtiEuXJD+UeuL0pKLU8oamYTH8K1
2hU9fFGzNNHmYRubSD6hS7y290U7taudcZ1sItX0yazWDl8s+3Gu/8QAm2j2
3nzzzQQHD7/Nrfg8yCZWTTnZEiQHu5OG71sNswl7r8tl5f0cnNrnfGYfn01s
KIqO6GrloM6jI4L1Y2xCVubina0FHHwVktD4YJxNaNY5+Hx6yMG9x5vy1CfY
xCvxsa6ALA46SZr5yE+xCadWbW59HAfJ/svWcdNs4pvJgeyACA4GYNkWiRk2
EUornNS5xMG5ScIKYX/YRGFuQ9638xy84QFTs7NMvWb5sannOPh/or4eSA==

               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922122682178133*^9, 3.922122941845788*^9, 3.922123081009536*^9, 
   3.922123260310014*^9, 3.922124789105058*^9, {3.922125699592486*^9, 
   3.922125725291663*^9}, 3.922126570520119*^9, 3.922126671781057*^9, 
   3.9221283632512503`*^9, {3.922128417493479*^9, 3.922128425732784*^9}, 
   3.9222132106453*^9, 3.9222132415453587`*^9},
 CellLabel->
  "Out[3458]=",ExpressionUUID->"784d2969-25e6-4eb9-8514-cebd7ecf8c60"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"MSEValidation", "[", "lambda_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "myfit", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"myfit", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"lambda", "==", "0"}], ",", "\n", "\t", 
        RowBox[{"Fit", "[", 
         RowBox[{"dataTrain", ",", 
          RowBox[{"functionList", "[", "x", "]"}], ",", "x"}], "]"}], ",", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{"Fit", "[", 
         RowBox[{"dataTrain", ",", 
          RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
          RowBox[{"FitRegularization", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<Tikhonov\>\"", ",", "lambda"}], "}"}]}]}], "]"}]}], 
       "\n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Mean", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"myfit", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
           
           RowBox[{"{", 
            RowBox[{"x", "->", "rValidate"}], "}"}]}], ")"}], "-", 
         "yValidate"}], ")"}], "2"], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Code",
 CellChangeTimes->{{3.922119243261956*^9, 3.922119332512197*^9}, {
  3.92212525537693*^9, 3.922125255924914*^9}, {3.922128778511451*^9, 
  3.922128827656794*^9}, {3.922128881019218*^9, 3.922128882189539*^9}, {
  3.922213278209119*^9, 3.922213344413516*^9}},
 CellLabel->
  "In[520]:=",ExpressionUUID->"d71516d4-549d-4298-89d5-715941d1cff5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generate", "[", 
  RowBox[{"10", ",", "100", ",", "100", ",", "100"}], "]"}]], "Input",
 CellChangeTimes->{{3.9221285037247887`*^9, 3.922128525946734*^9}},
 CellLabel->
  "In[2128]:=",ExpressionUUID->"978652c0-74b9-4a66-b525-1fe86fd4e670"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "100"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   100],
  Editable->False]], "Print",
 CellChangeTimes->{{3.9221285128473988`*^9, 3.92212852663913*^9}, 
   3.922134796723916*^9},
 CellLabel->
  "During evaluation of \
In[2128]:=",ExpressionUUID->"8876470b-cc03-4b99-a2e0-e582d5d4c221"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<MSE for OLS: \>\"", ",", 
    RowBox[{"MSEValidation", "[", "0", "]"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"MSEValidation", "[", 
      SuperscriptBox["10", "expon"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"-", "30"}], ",", 
     RowBox[{"-", "5"}], ",", "1"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListLogPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.922120284354642*^9, 3.922120335897293*^9}, {
   3.922123103389437*^9, 3.9221231376329813`*^9}, {3.922125033012699*^9, 
   3.922125033518644*^9}, {3.922128473111985*^9, 3.922128480389758*^9}, {
   3.92212861879235*^9, 3.922128636604733*^9}, {3.922128672660734*^9, 
   3.922128737170776*^9}, {3.922128856502161*^9, 3.922128898289894*^9}, {
   3.9221289290226183`*^9, 3.922128930922021*^9}, 3.922134651501492*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3461]:=",ExpressionUUID->"c90f095b-00c1-41d7-855f-01e1a59bcaf9"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   25],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128481720935*^9, 3.922128531682762*^9, 
  3.9221287394922953`*^9, 3.922128902511836*^9, 3.922128933153825*^9, 
  3.922134757233074*^9, 3.92213479931756*^9, 3.922134978493159*^9, 
  3.9222133612882147`*^9},
 CellLabel->
  "During evaluation of \
In[3461]:=",ExpressionUUID->"65855a46-dee9-483c-a3c4-56900890f00d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE for OLS: \"\>", "\[InvisibleSpace]", 
   "0.00004376958144699152`"}],
  SequenceForm["MSE for OLS: ", 0.00004376958144699152],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128481720935*^9, 3.922128531682762*^9, 
  3.9221287394922953`*^9, 3.922128902511836*^9, 3.922128933153825*^9, 
  3.922134757233074*^9, 3.92213479931756*^9, 3.922134978493159*^9, 
  3.9222133613825274`*^9},
 CellLabel->
  "During evaluation of \
In[3461]:=",ExpressionUUID->"a5a2c6bc-077f-4166-89da-d995a7e8505d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "30"}], ",", "0.00004384106666766309`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "29"}], ",", "0.00004384184229082656`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "28"}], ",", "0.00004384146162914866`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27"}], ",", "0.000043842620487619216`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26"}], ",", "0.00004385934986853847`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25"}], ",", "0.000044028220015358965`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24"}], ",", "0.000045546933500693555`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23"}], ",", "0.00005276180282643476`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22"}], ",", "0.00006011488230554639`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21"}], ",", "0.00007080946213216704`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20"}], ",", "0.00012392207928332697`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19"}], ",", "0.00020396495707142057`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18"}], ",", "0.0004215571865210882`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17"}], ",", "0.000829191513644608`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16"}], ",", "0.001134344101678477`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15"}], ",", "0.0015295212588533704`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14"}], ",", "0.0016456963287848217`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13"}], ",", "0.0015126503589881215`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0.0006935798767733742`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11"}], ",", "0.002413386987795344`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0.015290709129171349`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0.07026633915908274`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0.09666220974584912`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7"}], ",", "0.1083307685830807`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0.11402851755263761`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "0.10916079792596657`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.9221203249673862`*^9, 3.922120345425477*^9}, {
   3.922123109081856*^9, 3.922123139341893*^9}, 3.922123276837272*^9, 
   3.922124805423234*^9, 3.922125034222176*^9, 3.922125277851454*^9, 
   3.922125735843158*^9, 3.922125865970783*^9, 3.922126731444713*^9, 
   3.922128481951581*^9, 3.922128531773082*^9, 3.922128739641801*^9, 
   3.922128902665716*^9, 3.922128933312818*^9, 3.922134757481391*^9, 
   3.922134799472696*^9, 3.922134978667449*^9, 3.922213361548727*^9},
 CellLabel->
  "Out[3463]=",ExpressionUUID->"48815ae3-36f7-4876-9a3e-7386ae575b25"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.012833333333333334`], AbsoluteThickness[2], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQF2B0wtX898LKhyAMK3PZDw19PjIZxvc2BCwsLs
R3C+9YGDxpu/3IPzrQ684276vAbOtzywzljGaSs/jG9xQP+innvEP2Uo3/xA
9culz/g2w/hmB4Kmfv7oWADjmx4I2O5+I0cGxjc5cPtKF/fDv4pQvvGBrfJ+
dQf+KUD5RgccHcO7hcTkoXzDA/EGKo7hiTJQvsGBiPp+lTIFaShf70Bf+jGH
5HeSUL7OgfvrFzDkLIbxtQ5se9x8Yd9PGF/jQI7KQW0zCVkoX+1AnuCHibHS
ElC+yoG8YrGp13cIQPlKBzp7twsn27FC+QoH/pdEiFpsZILyZQ7wbHm37cJx
Rihf4kC4igLvtTgYX+TANdvF7/V2MB4AAL+cfDU=
         "]]},
       Annotation[#, "Charting`Private`Tag#1"]& ],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{
           Annotation[{
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Point[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQF2B0wtX898LKhyAMK3PZDw19PjIZxvc2BCwsLs
R3C+9YGDxpu/3IPzrQ684276vAbOtzywzljGaSs/jG9xQP+innvEP2Uo3/xA
9culz/g2w/hmB4Kmfv7oWADjmx4I2O5+I0cGxjc5cPtKF/fDv4pQvvGBrfJ+
dQf+KUD5RgccHcO7hcTkoXzDA/EGKo7hiTJQvsGBiPp+lTIFaShf70Bf+jGH
5HeSUL7OgfvrFzDkLIbxtQ5se9x8Yd9PGF/jQI7KQW0zCVkoX+1AnuCHibHS
ElC+yoG8YrGp13cIQPlKBzp7twsn27FC+QoH/pdEiFpsZILyZQ7wbHm37cJx
Rihf4kC4igLvtTgYX+TANdvF7/V2MB4AAL+cfDU=
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-30., 
               0}, {-10.650313483658339`, -2.1713067079004236`}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, -10.650313483658339`}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[0.012833333333333334`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
            "Primitives" -> {}, "GCFlag" -> False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLogPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-30., 
              0}, {-10.650313483658339`, -2.1713067079004236`}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, -10.650313483658339`}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
           "Primitives" -> {}, "GCFlag" -> False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLogPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{
       Annotation[{
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Point[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQF2B0wtX898LKhyAMK3PZDw19PjIZxvc2BCwsLs
R3C+9YGDxpu/3IPzrQ684276vAbOtzywzljGaSs/jG9xQP+innvEP2Uo3/xA
9culz/g2w/hmB4Kmfv7oWADjmx4I2O5+I0cGxjc5cPtKF/fDv4pQvvGBrfJ+
dQf+KUD5RgccHcO7hcTkoXzDA/EGKo7hiTJQvsGBiPp+lTIFaShf70Bf+jGH
5HeSUL7OgfvrFzDkLIbxtQ5se9x8Yd9PGF/jQI7KQW0zCVkoX+1AnuCHibHS
ElC+yoG8YrGp13cIQPlKBzp7twsn27FC+QoH/pdEiFpsZILyZQ7wbHm37cJx
Rihf4kC4igLvtTgYX+TANdvF7/V2MB4AAL+cfDU=
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-30., 
           0}, {-10.650313483658339`, -2.1713067079004236`}}, 
        "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0, -10.650313483658339`}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
        "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLogPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -10.650313483658339`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{-30., 0}, {-10.650313483658339`, -2.1713067079004236`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0]}, {
    Automatic, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.010\"", ShowStringCharacters -> False], 
          0.01`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.100\"", ShowStringCharacters -> False], 
          0.1`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-13.122363377404328`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-12.716898269296165`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-12.429216196844383`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-12.206072645530174`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-12.02375108873622, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-11.86960040890896, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-11.736069016284437`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-11.618285980628055`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.819778284410283`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.41431317630212, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.126631103850338`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.903487552536127, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.721165995742174, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.567015315914915, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.433483923290392, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.315700887634009, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0., 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{{3.9221203249673862`*^9, 3.922120345425477*^9}, {
   3.922123109081856*^9, 3.922123139341893*^9}, 3.922123276837272*^9, 
   3.922124805423234*^9, 3.922125034222176*^9, 3.922125277851454*^9, 
   3.922125735843158*^9, 3.922125865970783*^9, 3.922126731444713*^9, 
   3.922128481951581*^9, 3.922128531773082*^9, 3.922128739641801*^9, 
   3.922128902665716*^9, 3.922128933312818*^9, 3.922134757481391*^9, 
   3.922134799472696*^9, 3.922134978667449*^9, 3.922213361667396*^9},
 CellLabel->
  "Out[3464]=",ExpressionUUID->"d08b05be-5081-4a80-9498-3acd66ff8749"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  RowBox[{"\"\<MSE for OLS: \>\"", ",", 
   RowBox[{"MSEValidation", "[", "0", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"MSEValidation", "[", 
      SuperscriptBox["10", "expon"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"-", "20"}], ",", 
     RowBox[{"-", "15"}], ",", ".1"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListLogPlot", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.922125902471346*^9, 3.922125909056583*^9}, {
   3.922134728262684*^9, 3.922134729874917*^9}, {3.922134821964272*^9, 
   3.922134826077703*^9}, 3.922134969485002*^9},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3465]:=",ExpressionUUID->"ffcacb68-5c46-4934-ba53-a2d9fbf2afd5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE for OLS: \"\>", "\[InvisibleSpace]", 
   "0.00004376958144699152`"}],
  SequenceForm["MSE for OLS: ", 0.00004376958144699152],
  Editable->False]], "Print",
 CellChangeTimes->{3.92213499600707*^9, 3.922213407055539*^9},
 CellLabel->
  "During evaluation of \
In[3465]:=",ExpressionUUID->"2f3e7a22-4eb8-4d76-b7aa-8a192df10c77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.`"}], ",", "0.00012392207928332697`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.9`"}], ",", "0.00013201677325690527`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.8`"}], ",", "0.00014015610028124173`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.7`"}], ",", "0.00014821327550242517`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.6`"}], ",", "0.00015611180698223034`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.5`"}], ",", "0.00016383689252464005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.4`"}], ",", "0.0001714419101545938`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.3`"}], ",", "0.00017904635226763434`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.2`"}], ",", "0.00018683246764296724`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.1`"}], ",", "0.00019504061123906457`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.`"}], ",", "0.00020396495707142057`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.9`"}], ",", "0.00021395104261001479`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.8`"}], ",", "0.00022539328962645262`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.7`"}], ",", "0.00023873048525578883`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.6`"}], ",", "0.00025443616935117574`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.5`"}], ",", "0.00027299970533477025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.4`"}], ",", "0.00029489433391946383`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.3`"}], ",", "0.0003205276969871099`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.2`"}], ",", "0.00035017785691113246`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.1`"}], ",", "0.0003839195990182483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.`"}], ",", "0.0004215571865210882`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.9`"}], ",", "0.0004625840393084707`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.8`"}], ",", "0.000506189803089712`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.7`"}], ",", "0.0005513261201925117`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.6`"}], ",", "0.0005968241211753503`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.5`"}], ",", "0.000641539765397079`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.4`"}], ",", "0.0006844930177321148`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.3`"}], ",", "0.0007249713209224966`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.2`"}], ",", "0.0007625814399113399`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.1`"}], ",", "0.0007972507985760631`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.`"}], ",", "0.000829191513644608`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.9`"}], ",", "0.0008588431968889853`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.8`"}], ",", "0.000886810600127011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.7`"}], ",", "0.000913804326973108`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.6`"}], ",", "0.0009405882179389759`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.5`"}], ",", "0.0009679319720639346`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.4`"}], ",", "0.0009965651831883857`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.3`"}], ",", "0.0010271287187832334`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.2`"}], ",", "0.0010601212887586461`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.1`"}], ",", "0.0010958431988589783`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.`"}], ",", "0.001134344101678477`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.899999999999999`"}], ",", "0.0011753869193879191`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.8`"}], ",", "0.001218441780445174`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.7`"}], ",", "0.0012627208921893315`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.6`"}], ",", "0.0013072560193318325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.5`"}], ",", "0.0013510071209949825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.399999999999999`"}], ",", "0.00139298046207009`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.3`"}], ",", "0.0014323306414373682`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.2`"}], ",", "0.001468427388524087`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.1`"}], ",", "0.0015008795573554514`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.`"}], ",", "0.0015295212588533704`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922125911493369*^9, 3.922126736499876*^9, 3.922134738584321*^9, {
   3.922134806961907*^9, 3.922134826809543*^9}, 3.922134996172888*^9, 
   3.9222134071876907`*^9},
 CellLabel->
  "Out[3466]=",ExpressionUUID->"d3da2549-880d-465d-b870-c34265c9b99e"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.011000000000000001`], AbsoluteThickness[2], PointBox[CompressedData["
1:eJw1zm1IU1Ecx/FVmESYZpq5e+fupUWQuftw8k2htVmJ+MSmMAlDLWYGPUBt
WciWGGSppeEwku1FkWAwVDQzReSXRBQZpEimYVnQQAXfSGmiK2f//eBw3hy+
5yOeuWy1b9ZoNGz9hO7/O4Qv43Xbv6+JKA8twOCpXy2smhbxYSQ0huWdNZ7J
IREstB6Gp9bco0eeiGh9FBrDVl/BUlutiI1cNcOJyoHC+UvUK2fwVt2RumzU
y2Hw5V55XGmiHmN492c21Z9MvUSGlMjI3vZ46mkYevV5bgQF8qmoLb5RlhkQ
yKfCEXXL0/peIJ+KmlGvM7lDIJ8Kxc6nNdwTyKfCXfAtyn2eeuUqVpw91qCJ
ejkqfu51ZVgSqMdUlA5IwW3jevKpeOaYnfzk1JNPhclkq4/drSefgl1TAffy
iyTyKSgTr7b3n0oin4IDv80d5i1J5FNw0md7Gd2tI58Cb/7n/XEVOvIp6Muy
WPr26ci3/n7wl/RjjiefgojSTn9CH08+BWNxz9F0lyefghLZYLKV8eSTcdzz
8HVxGk8+GaXT9UUNPPV6ZHy1RCxOrHHkk3E61TFjnuHIJ8PrKnk7N8yRT0b0
/N+mmDaOfDJyFrL7xdsc+WTo4xeHX9mplyijObNCO5ZBPY2MopuNhmsChw3O
iIQsf+3HmFUt/S+hekdN7OEJLf0nIeVgfrO/W0t9CaODLZnGRi31JDinulzX
L2qpZ0RdSzpnyAv3jPBkt7l8SrhnhG4lfUnYE+4ZccH1oHNoU7hnxP1zb46d
XUjEPxe0bVc=
         "]]},
       Annotation[#, "Charting`Private`Tag#1"]& ],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{
           Annotation[{
             Directive[
              PointSize[0.011000000000000001`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Point[CompressedData["
1:eJw1zm1IU1Ecx/FVmESYZpq5e+fupUWQuftw8k2htVmJ+MSmMAlDLWYGPUBt
WciWGGSppeEwku1FkWAwVDQzReSXRBQZpEimYVnQQAXfSGmiK2f//eBw3hy+
5yOeuWy1b9ZoNGz9hO7/O4Qv43Xbv6+JKA8twOCpXy2smhbxYSQ0huWdNZ7J
IREstB6Gp9bco0eeiGh9FBrDVl/BUlutiI1cNcOJyoHC+UvUK2fwVt2RumzU
y2Hw5V55XGmiHmN492c21Z9MvUSGlMjI3vZ46mkYevV5bgQF8qmoLb5RlhkQ
yKfCEXXL0/peIJ+KmlGvM7lDIJ8Kxc6nNdwTyKfCXfAtyn2eeuUqVpw91qCJ
ejkqfu51ZVgSqMdUlA5IwW3jevKpeOaYnfzk1JNPhclkq4/drSefgl1TAffy
iyTyKSgTr7b3n0oin4IDv80d5i1J5FNw0md7Gd2tI58Cb/7n/XEVOvIp6Muy
WPr26ci3/n7wl/RjjiefgojSTn9CH08+BWNxz9F0lyefghLZYLKV8eSTcdzz
8HVxGk8+GaXT9UUNPPV6ZHy1RCxOrHHkk3E61TFjnuHIJ8PrKnk7N8yRT0b0
/N+mmDaOfDJyFrL7xdsc+WTo4xeHX9mplyijObNCO5ZBPY2MopuNhmsChw3O
iIQsf+3HmFUt/S+hekdN7OEJLf0nIeVgfrO/W0t9CaODLZnGRi31JDinulzX
L2qpZ0RdSzpnyAv3jPBkt7l8SrhnhG4lfUnYE+4ZccH1oHNoU7hnxP1zb46d
XUjEPxe0bVc=
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-20., -15.}, {-9.19251856152846, \
-6.482800495252276}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {-14.895833333333368`, -9.19251856152846}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[0.011000000000000001`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
            "Primitives" -> {}, "GCFlag" -> False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLogPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-20., -15.}, {-9.19251856152846, \
-6.482800495252276}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {-14.895833333333368`, -9.19251856152846}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.011000000000000001`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
           "Primitives" -> {}, "GCFlag" -> False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLogPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{
       Annotation[{
         Directive[
          PointSize[0.011000000000000001`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Point[CompressedData["
1:eJw1zm1IU1Ecx/FVmESYZpq5e+fupUWQuftw8k2htVmJ+MSmMAlDLWYGPUBt
WciWGGSppeEwku1FkWAwVDQzReSXRBQZpEimYVnQQAXfSGmiK2f//eBw3hy+
5yOeuWy1b9ZoNGz9hO7/O4Qv43Xbv6+JKA8twOCpXy2smhbxYSQ0huWdNZ7J
IREstB6Gp9bco0eeiGh9FBrDVl/BUlutiI1cNcOJyoHC+UvUK2fwVt2RumzU
y2Hw5V55XGmiHmN492c21Z9MvUSGlMjI3vZ46mkYevV5bgQF8qmoLb5RlhkQ
yKfCEXXL0/peIJ+KmlGvM7lDIJ8Kxc6nNdwTyKfCXfAtyn2eeuUqVpw91qCJ
ejkqfu51ZVgSqMdUlA5IwW3jevKpeOaYnfzk1JNPhclkq4/drSefgl1TAffy
iyTyKSgTr7b3n0oin4IDv80d5i1J5FNw0md7Gd2tI58Cb/7n/XEVOvIp6Muy
WPr26ci3/n7wl/RjjiefgojSTn9CH08+BWNxz9F0lyefghLZYLKV8eSTcdzz
8HVxGk8+GaXT9UUNPPV6ZHy1RCxOrHHkk3E61TFjnuHIJ8PrKnk7N8yRT0b0
/N+mmDaOfDJyFrL7xdsc+WTo4xeHX9mplyijObNCO5ZBPY2MopuNhmsChw3O
iIQsf+3HmFUt/S+hekdN7OEJLf0nIeVgfrO/W0t9CaODLZnGRi31JDinulzX
L2qpZ0RdSzpnyAv3jPBkt7l8SrhnhG4lfUnYE+4ZccH1oHNoU7hnxP1zb46d
XUjEPxe0bVc=
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-20., -15.}, {-9.19251856152846, \
-6.482800495252276}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {-14.895833333333368`, -9.19251856152846}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.011000000000000001`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
        "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLogPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-14.895833333333368`, -9.19251856152846},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{-20., -15.}, {-9.19251856152846, -6.482800495252276}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0]}, {
    Automatic, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
          TemplateBox[{"10", 
            RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
       0.}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "2", 
          TemplateBox[{"10", 
            RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
       0.}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
          TemplateBox[{"10", 
            RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
       0.}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}}, {-10.819778284410283`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.41431317630212, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.126631103850338`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.903487552536127, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.721165995742174, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.567015315914915, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.433483923290392, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.315700887634009, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.804875263868018, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.502290170873972, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{
  3.922125911493369*^9, 3.922126736499876*^9, 3.922134738584321*^9, {
   3.922134806961907*^9, 3.922134826809543*^9}, 3.922134996172888*^9, 
   3.922213407289119*^9},
 CellLabel->
  "Out[3467]=",ExpressionUUID->"3f64f5a5-4447-43a4-aef6-874a7442a5fe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mmaFitRidge", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Tikhonov\>\"", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "16.3"}]]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ridgeMmaPlot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"ridgeMmaPlot", ",", "LJplot"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MeanRidgeMmaTest", "=", 
  RowBox[{"Mean", "[", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
        RowBox[{"{", 
         RowBox[{"x", "->", "rTest"}], "}"}]}], ")"}], "-", "yTest"}], ")"}], 
    "2"], "]"}]}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, {
   3.922120424797739*^9, 3.922120447099926*^9}, 3.922120706798108*^9, {
   3.922126066787107*^9, 3.9221260886688433`*^9}, {3.9221267944673038`*^9, 
   3.92212679639928*^9}, {3.922213420027276*^9, 3.922213430180112*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3472]:=",ExpressionUUID->"0c066f68-58e5-4bc9-8211-f743bc6f2a44"],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVVnc81f8Xdl2rbBGVkCgtShGtzweFSlZSIuKrUiJ7dC9Z99p7j7JDIbNE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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVVnc81f8Xdl2rbBGVkCgtShGtzweFSlZSIuKrUiJ7dC9Z99p7j7JDIbNE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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVVnc81f8Xdl2rbBGVkCgtShGtzweFSlZSIuKrUiJ7dC9Z99p7j7JDIbNE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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922126090720031*^9, 3.922126798535335*^9, {3.922213425684782*^9, 
   3.922213431739367*^9}},
 CellLabel->
  "Out[3474]=",ExpressionUUID->"259a0c39-14b3-472e-ae53-1d31c10682e7"],

Cell[BoxData["0.0008847878769068614`"], "Output",
 CellChangeTimes->{
  3.922126090720031*^9, 3.922126798535335*^9, {3.922213425684782*^9, 
   3.922213431902917*^9}},
 CellLabel->
  "Out[3475]=",ExpressionUUID->"47111b3f-b3cc-4eeb-8fd7-bfd7d3507350"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Direct implementation", "Subsection",
 CellChangeTimes->{{3.9221264058303556`*^9, 
  3.922126412159643*^9}},ExpressionUUID->"0bb42eaa-94fb-48b5-a3ef-\
5e38d8220984"],

Cell["\<\
Do the same as OLS, but add a regularization as sum of squares of \
coefficients (Ridge, or Tikhonov)\
\>", "Text",
 CellChangeTimes->{{3.92211315672416*^9, 3.922113207025154*^9}, {
  3.922122084678237*^9, 
  3.922122096788471*^9}},ExpressionUUID->"f633b059-a9e7-4556-bb7c-\
f182ed0445ed"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wRidge", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}], " ", "+", " ", 
      RowBox[{"ridgeLambda", " ", 
       RowBox[{"IdentityMatrix", "[", "nX", "]"}]}]}], "]"}], ".", 
    RowBox[{"Transpose", "[", "X", "]"}], ".", "yTrain"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"wRidge", "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wRidge", "//", "TableForm"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.92210788675423*^9, 3.922108006158895*^9, {3.9221132135167418`*^9, 
   3.9221132250739613`*^9}, {3.922113255744605*^9, 3.922113265037793*^9}, {
   3.922113316426984*^9, 3.922113322892029*^9}, {3.922113460881918*^9, 
   3.922113519657382*^9}, {3.922113867314147*^9, 3.922113868623129*^9}, 
   3.922122825142274*^9},
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"82f19390-acc6-4eec-82c7-93c1f0424b29"],

Cell[BoxData["0.0009971341106750102`"], "Output",
 CellChangeTimes->{
  3.9221132302548*^9, 3.922113269211413*^9, 3.9221133241019163`*^9, {
   3.922113447392271*^9, 3.922113520550416*^9}, {3.92211384586154*^9, 
   3.922113869414439*^9}, 3.922114347588614*^9, 3.922118355605751*^9, 
   3.922118433034772*^9},
 CellLabel->
  "Out[1539]=",ExpressionUUID->"90095aa4-5704-4323-b3d8-e4f1c38d1be3"]
}, Open  ]],

Cell["\<\
Compare coefficients from explicit regression formula to those given from Mma \
Fit\
\>", "Text",
 CellChangeTimes->{{3.922122023862116*^9, 
  3.922122041047311*^9}},ExpressionUUID->"1384368d-8026-4d97-83b6-\
6f90a740c49a"],

Cell[CellGroupData[{

Cell[BoxData[{"wRidge", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mmaParamsRidge", "-", "wRidge"}], ")"}], "/", 
  "wRidge"}], "\[IndentingNewLine]", 
 RowBox[{"Max", "[", 
  RowBox[{"Abs", "[", "%", "]"}], "]"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, 
   3.922120424797739*^9, {3.922120457049314*^9, 3.922120466507172*^9}, {
   3.92212070907828*^9, 3.9221207184858937`*^9}, 3.922121728275892*^9, {
   3.9222134611118593`*^9, 3.922213462129657*^9}},
 Background->RGBColor[
  0.87, 0.94, 1],ExpressionUUID->"17578c4a-803b-4deb-921f-36f6d47c4c11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.0009971341106750102`", ",", "0.16142224233998728`", ",", 
   "1.4284707596692254`", ",", "1.7640617704112507`", ",", 
   "1.8227781513075942`", ",", 
   RowBox[{"-", "0.3238974208565572`"}], ",", 
   RowBox[{"-", "4.6423920111891555`"}], ",", 
   RowBox[{"-", "0.6939191960503872`"}], ",", "0.5454039477802615`", ",", 
   "1.0738843187542564`", ",", 
   RowBox[{"-", "0.2978658264980564`"}], ",", "2.415930970610398`", ",", 
   RowBox[{"-", "1.0572571022043968`"}], ",", 
   RowBox[{"-", "0.33984494600725773`"}], ",", "0.36859563846960347`", ",", 
   "9.174706580534974`*^-7", ",", 
   RowBox[{"-", "2.101661173076333`"}], ",", 
   RowBox[{"-", "0.756654962563115`"}], ",", 
   RowBox[{"-", "0.6581260193410438`"}], ",", 
   RowBox[{"-", "0.11991560846721645`"}], ",", "1.6014906478290826`*^-43", 
   ",", "0.43632078601212665`", ",", 
   RowBox[{"-", "0.3919487898928463`"}], ",", 
   RowBox[{"-", "0.5662437420710595`"}], ",", 
   RowBox[{"-", "0.34343518426980124`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.922113831359782*^9, 3.922113876043737*^9}, {
   3.9221139112180643`*^9, 3.922113938520488*^9}, {3.922118440614805*^9, 
   3.92211846584625*^9}, 3.922118505774642*^9, {3.922118546299719*^9, 
   3.922118588206772*^9}, 3.922119149633638*^9, 3.922119187783099*^9},
 CellLabel->
  "Out[1596]=",ExpressionUUID->"4c88185f-5d78-4a44-b7a4-f711cfd9d6df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2.6095639353905246`*^-15"}], ",", 
   RowBox[{"-", "3.4947604878358925`*^-12"}], ",", "1.926861228358671`*^-12", 
   ",", 
   RowBox[{"-", "1.0996109666686205`*^-12"}], ",", 
   RowBox[{"-", "1.0088849357064639`*^-12"}], ",", 
   RowBox[{"-", "5.261518718774677`*^-14"}], ",", "5.41433149482675`*^-14", 
   ",", 
   RowBox[{"-", "7.126093902324303`*^-13"}], ",", "1.5294666919397517`*^-11", 
   ",", 
   RowBox[{"-", "1.5968670497258994`*^-12"}], ",", "5.31134379761141`*^-14", 
   ",", "3.020113491070921`*^-13", ",", "1.6278611221295802`*^-12", ",", 
   "2.153835296758345`*^-12", ",", 
   RowBox[{"-", "1.0875705970937222`*^-11"}], ",", "9.451528200273264`*^-14", 
   ",", 
   RowBox[{"-", "2.4426731252556035`*^-13"}], ",", 
   RowBox[{"-", "1.7777537757490576`*^-12"}], ",", "2.183076757253827`*^-12", 
   ",", "1.311991983794686`*^-11", ",", "7.62231536325225`*^-14", ",", 
   "5.865097776226187`*^-13", ",", 
   RowBox[{"-", "4.931507216544352`*^-13"}], ",", 
   RowBox[{"-", "1.285422090992241`*^-12"}], ",", 
   RowBox[{"-", "7.944360997308079`*^-12"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.922113831359782*^9, 3.922113876043737*^9}, {
   3.9221139112180643`*^9, 3.922113938520488*^9}, {3.922118440614805*^9, 
   3.92211846584625*^9}, 3.922118505774642*^9, {3.922118546299719*^9, 
   3.922118588206772*^9}, 3.922119149633638*^9, 3.922119187867351*^9},
 CellLabel->
  "Out[1597]=",ExpressionUUID->"9be1f712-436a-4177-af9c-eb30080e3747"],

Cell[BoxData["1.5294666919397517`*^-11"], "Output",
 CellChangeTimes->{{3.922113831359782*^9, 3.922113876043737*^9}, {
   3.9221139112180643`*^9, 3.922113938520488*^9}, {3.922118440614805*^9, 
   3.92211846584625*^9}, 3.922118505774642*^9, {3.922118546299719*^9, 
   3.922118588206772*^9}, 3.922119149633638*^9, 3.922119187921019*^9},
 CellLabel->
  "Out[1598]=",ExpressionUUID->"9817e094-e247-4b43-9eba-0efc71e0269e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ridgePlot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"wRidge", ".", 
        RowBox[{"functionList", "[", "r", "]"}]}], "*", "yTrainStdev"}], "+", 
      "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"ridgePlot", ",", "LJplot"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MSERidgeTest", "=", 
  RowBox[{"Mean", "[", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"wRidge", ".", 
        RowBox[{"functionList", "[", "rTest", "]"}]}], "*", "yTrainStdev"}], 
      "+", "yTrainMean", "-", "yTest"}], ")"}], "2"], "]"}]}]}], "Input",
 CellChangeTimes->{{3.9217687936291533`*^9, 3.9217688327658987`*^9}, {
  3.921768864444922*^9, 3.921768870848134*^9}, {3.921769486805279*^9, 
  3.921769542793608*^9}, {3.921770940634282*^9, 3.92177094183883*^9}, {
  3.9220952593893003`*^9, 3.922095259496469*^9}, {3.922096300918138*^9, 
  3.922096301503976*^9}, {3.922096529892295*^9, 3.922096530718207*^9}, {
  3.922102592447061*^9, 3.922102645533327*^9}, {3.922112668774447*^9, 
  3.922112669746542*^9}, {3.922113273091929*^9, 3.922113279521315*^9}, {
  3.9221190633074493`*^9, 3.922119078179054*^9}, {3.922119127356476*^9, 
  3.9221191312846127`*^9}, {3.92211919570715*^9, 3.922119196419444*^9}, {
  3.922121506969965*^9, 3.922121528348578*^9}, {3.922125169135148*^9, 
  3.922125171700205*^9}, {3.922125216056072*^9, 3.922125229358795*^9}, {
  3.922125694303045*^9, 3.92212569578808*^9}, {3.9222134751159477`*^9, 
  3.922213493372943*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3479]:=",ExpressionUUID->"de48d650-ae75-4e17-9b51-ce104c50ae2b"],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVVXc8le0bN57nHERGeqNXRlFWJNl03yGh7FUabySjZJRSdpmHw5FwzmnI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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVVXc8le0bN57nHERGeqNXRlFWJNl03yGh7FUabySjZJRSdpmHw5FwzmnI
ltRx0rJvUUYoCWWUUaRlRMOofvfv/HM+38913dd33NfzPAqegY5H+Xh4eKR5
eXj+/++cKCKb8IkfXmb//9cG6t6p8/fM88PAf15ctpNuBatJU1qbIAHX6agd
e7jmCVB1KxiVWkHAud46352TjwEsJQx9hQloJsT38GPlY3DcpuUTRZSA5aq1
y2fcH4NHWXv2mEsS8N2EtyE3pwmc2OgmimQJuIl63+y3WiN4sss/6542AW8O
vnR4X1UPmvslXeR1CGi6b5P0M3eMj9dJ0nUJGCBG7V6xXAdaGSszjxgQcDJo
dm0iqAMdr7gZEoCAhpcFXrCe1oAen++MIGsCynO9fPm+VYL3iVHJ6h4EPLkl
mseXfheMS2+yZnkSMMghaKDQ4C6YKHsuSHgR8LWxcrXjhwow+VyeNuhNwPwP
GncI8wrwZU1TYrI/Pm93RewV3x0wX0KNnwwl4AyYfHh/823A35oeXZhGQH1f
WoG0YSE4y3q+/JNBQOUzTRIRtQVgyndl2O6LBLxhMneiBRSAAUF6yLdLBDRP
6xSQscoHFbsT/SCbgJYfCtteeOcCz+eRTkMFBNz71TNdIocNXl+v7dIswn7d
yv/mNLCAbdCSTWwx9jdqc0JinAkMxc9ZqpZi/dyK/RXa2UDCKcTkLIeA6QtL
BrMfMkBj37FNklUE3NLM/NfCnQb0S0oLfaoJOCIquEX0TSLghE4q1NQQkOvn
0lN/JAFclvKW8awnoNjn6uDeiFhw0t1DnNtEwNz2qtlPNeFA4a3b0u5nBOTZ
RhePfOcOsjnZZ68/J2DMzmDGzml7IBzd+/1bF643X21+7mcMfsk5zbBfYnzp
iNEKT0vU5WE7/uE1AeHO/Q69Jb4oZtz8eew77Mfos8Ja/0g09v3p3bn3WF+p
dmRWdjQyoziwjkwQsOF7jfHSYAyibDroYfYR1+WVRmqmLyC67+k5vml8H8/i
q+dGEtDU2aVXJ2cI2No6qPX3RSKyo52vHZvF84kLQWn1SUjiZmp84zzOS/Up
0zQ5GTE/F625sIjvq2rCwO5LKvq1pLY8u4TvwyLv45OqNOQuXDHi8ZuAvwTK
4l5dYCCZzfWlO3hI+F5o34kvsekoP6DPiJdCwvTjHO/BqYuIiD4gH0wl4YGc
+jBt8wx0lDFGjApg/Ecz24eZgZS5U50NK0g42cAr5K93CXFmKYdjxEnYENAd
onAoE4nxpZrPSJAwZv4Pb1Z+JgqWWKVyWJKE5nVGK368z0TbtOW+gTUY03zk
k49koSyzor5yKRJWPh5e2Xg9C/1wUquRW0tC6OS8fbY/C1WF6MX9lSGhcjHn
CrDMRmvj63wDZUmY1NDH6xWRjSKyzGyG5UhovOAqnczJRtsf2P2D1pNQhvMS
TAgzUW5z76KGIsZ3TQYUDJiI99X+4RwlEi7nlBsfO8JEj3/63IhSJqEi58mw
egUTbRSYok+pkNB/m+3yrT4mSpQKCT6khuf3nmPtXGCiSeVFl2fqJMwcvlm9
IM1C1gYxhts1cD7rRk526LPQLSuKHEcT5/PPtYEGFxYScafzy2rhfFZ1Sw4E
sVBXGKvjtzYJhRXmqhPzWGhriuydEzoklJrgv7L+IQtdulKY9UaXhPauhTrT
T1lovkw1zEYf55NxanBmiIVca7mH6gxIeHbb5LjqVxZ62KFrttkI58HUfZi7
xEJSb2o3XTMm4a8R3WoXATYK+2oqLLKdhCM91p42q9ho8HfrTATA/P5maiky
bPT651P5CUjCoR8fDs1tYKO+2Q57O1MSFkZ4+laqsFHP52cxlWY4n8stN99s
ZqPu8S6uwk4SbnuZk+69hY26hrtHki1I+JrWluKqxUbP+nvE5neRcKbdb/Ud
XO942QcPWpEw6Gfr7XMabPS083VQszX2o7F96K4qG7W2DORq7sF6SyQ1jyix
UfOjoS6WDQn1nwUbpciy0eOatzx8dtivudE1zX/YqPH+yJbj9jive8s/nITZ
qKF87HCPAwm94jpnl3jYqL70fbqJE8aHdU3U5lmotmCiodiZhPOF/zDGx1mo
+trkjKgrCXvyaAUafSxUyfwkf86NhDea2o2FnrDQg4tf7Mf2kpCbLrchooKF
7qVMxex2x/uTVaGYlMNCFfEz3Hv7cb/ihdVbaSzEjf42su4gCfFKPI88yUKc
c/NiiYdwfsu6WoHuLFR64lfQPg8SxvU7JjhuZKFin8XcRk/M3yrutEeIhQo9
lrvUvLBfG0r40he8ry48Wn+8cV66iq00DhOxTARm8/1xPi9Wv+pbz0TZekIK
wgE4/2T9/s/L2ShTS9jhdCAJb3kqJ/X1ZqN0JbE7u06S8OoKET+TuGyUKCIV
/CUU6xneH/HkZRaKo67NczlHQkJjv/ByYRa6wCvzoj6MhM6aFUUqp7NQ1Hc5
rYuRWA8nbjxMIgudebNpVicWvx9a/hvy35GJQl6pKFyPI+EehsBYt1AmOvlC
zUEgAfuR3Sbn+PISCniieWcgCePvE0m3PS4h79t6wdFpJIzg+8xwCMlALpG7
ZlvZeJ/o1/7InU5HrfeH30pfwX5Hzzbe0E1HhlOhHceu4uelQz/DepqB5P+7
USJ8HfOvqX8jOpOGvkDBQ/aFJGz1Uq4tH6ejOKL96SsO3n+zjaK0kiRUkWJb
ONGE933M8IxOYDRSejxxUe8Jfh/p6Sh8sI5CrOWo6KRmEuYKu33Q2BiJok6U
u6u24f5428DKwTBkZScmHvCMhPLRQ0565mfQiER35PfX+H3UKiDWufkYWnnZ
xY2YIiFPlbSmTIQT8JfQuRU8jefnqdQb6e0F7cmSvMMzGO8STTnz5QBICn95
s2oO93MiJuXWHwG8Bx3+BCxgLLKBK+/gD+blbIr6CQo8rDL2gvbrDHBkqS9a
UCgwV71yMkzgLLgjJmx3j4rr41c//ll9DgTwtv9KE6LAhkdFs/Eq4eDDmOUe
czEKlF+5uYhXKxoMFJnPcf6lQBh7dajVPRboyypayqyjQLFtj3rFO2IBM5v/
Gk0Wz/+k0PLAKA44JzZaeClQ4BZtCfGl1fGg0xdelt6E510721N3PwGoj8pN
Jyhj/n3qDbrSiSB531+zeRU871TC6oGwRGBhXf/1mToFzlhUWCXpJ4EGNeMd
cVspsOv2ZbWRqzQgW/hv9qw2BX9fPzgIztJAhMzSp0M6uP+byG8Ns2RgIFKd
aaCP9XaGCruPJgNWPPtjsQH2Zz1T5rw5Bfz4fXa7pBHmP9ZkoRuaAiqm9Can
TDD+U05nE3Qg5rPG5ADAemUMvopZ0kHg8I+LbZAC7ftE7rnT6EC9675RoRnm
296f5ECmgqI72ox9VhSY7mUMzMdSwVnf0jyONfZ/ct9Ghlga2CMnd49/D9Yr
y5zvNk4D3+hC/bdtcf2Y6XVdRhpoNov5zGdPgTwy9Tvt7qcB9uL3324OmP9c
mI9jfxqAvqPr+Zzx+cggbaF/GWCVnJuOmws+31xHqdRngInejl23XHE+DiEl
ps4MUE03defdi8/b97UUn2CAVLNKf9d9uN9FcONoHAMcXtwcXeaO6+Or6VNs
Bth2p+AizwEK5BZNPG+/xQBUX+lCl4OYz2LXy9N1DDAgy3hw8xD2L/4u9mM7
A3B6iba//1HgCDQb3PCaAc7TwwadPTD+3PFWYYwBnM1mvpZ64vPl9ddHPjKA
8uJRnr9HsD5pDaOD0wywxB2UcD6K61xiIPMbAzzzcVAq9cb+OcvcuDkGyJdt
0fvjg/lo13hUcf10r7G1kx++Hxn91RemGMCSXnHgxjHcf37MInmSAWTMlAN/
H8f7d//UAhhhgOmFa+cdT2A9b6Ku5vYyQCN3VWZJAPa3z7astJUBsn1oxcuB
eH7o21t7qxjAT/ZvpUMw1jf7SrushAGMe0Pai09iLJv8NucSA4jRP71ZOoXv
t++9q1YkA7wzPTxjfxrr2XDS8bAXAzxY6OUrPoP3IdMuQ8WKAZK5u1cvhWJ8
bNO7ZDUGOOjzaJP9ObyPB1TWXVjBAFtk9QyLwnDdlF9R5GMaIHpv7VkMx/r3
90+oPE4DN01ZwYVRWG+4WrbYqTQQtSAStxCN9zf1J7vPIg04cGOzbc/j/k7b
pI1SaeDXusCaX7HYz9em5wfupoL2nvedNvHYf0fGZRCZCnJS3EfyE/Dz1W2k
XWSeCnYu7CRtaPi8s4/6t3Y6kOLWrMlPxnWfdre+FDr44q2l+jOFAoPePZzQ
taKDjB4Zu7w0fF8M8e0+tSnAOyXD4wcD74+kmcq2kynAwFQgZPdF7E84sC5U
KQWMlM+xvl/C+zYceu1gXDK46+1XZp2F9QlneP7WTAYJ64brrmfj+WsFm1b2
08DmlKdjVmysV/VO3fkNNBDmnaeek4P1nI6rTWYngk+US8lfrmP/jT615VsT
gXtJ3KRhHq7zk5S9bQnAYNKn8FUBzlO9aJ/mdDz45achI16K+d1tzcZl4oCv
kHzYfzdxnm1nGGL5seD1TfHXt8uwf7/aoSrFWFD5ef6SNQfvU0RNbNz6CyD0
RM2KuLtYj8H48aG/0WBC5LZf9z2MT40sLY5GAVdOTov8A5wHoR8liiKB7vT5
2LpK7N91+1WpY+HgR5Dl0o86rDduBuXHngEhIb2f/Fox5rq+Eaf5gPeSLZaV
bZgvZp71scwLON+vLKa047rioa2cxx5A+8cVz4JOPH/vExmS6wa+hXoODHXj
fp6jmj4xK1Fw+HSb3RuMKV2eqn+PoZF/RzflvMX8lp0HUUQAsq/tjv8yjM9/
HRBX5AtGW37f30Ebw/11/TWZrBA0ExVR1fgB+6kyNvzEE4ECLgiW6nzD9xP8
Z27mbTxq8zQNyJ2jQGX5kKNaywlI0Sxce8V3CryR8S7FViYJDfJ/rRv5SYH6
+ppu0keTkWV8V3fKb/w8fPIeb5FioPVJzOVRASoUW+XRlhmbiV6lKtmnyVFh
oYtV6etz19HWgEOrF+SpsOJjcrXT2lyUZsscOLKeCi1jmfNHzuYic1HBowZK
VMxfVR+hm4cq0r+ce69KhZf113nGVOcj+qW7BYa6VHjjmq2L42gRguwdPyf2
UKE+33F5avEtJFYpFmZgS4X+To3j3aK30Ujf8HKKHRX+4s+wUgi7jc5LRvFp
OVJhB9N92MyegxoZ1SLhblT4ZqnzkyUvF5knaCuKelLhcREhuwB0B1meUnLQ
C6XCB6Eb8qDffeRgI1iWmEeF3gFH4k286tBbJQs6bwHmN3CUNCyvQ/5/LpwI
L6TCKHB046nFOpRQvqwZWIL7uQL+7Iv1qFp85p7rbSoMpoXfvdWI0Pq+vnql
Kipccjh+uGvNIzR/qLC7qYsK711026HFbkLn9UbvmnRTYajOhOqGxia0Ukw2
6+FLKuyRj1ze/LkJKT9iupX1UaG69JWHqSaP0YENKUMZQ1T41KtRN/jdY/Tk
Q/CExyQVyjMBKNZuRo4NnJbBj5g/YPsuyUPNaIT1+YbLZyr8ceNoByupGS1a
HT1uNUWFLoFbq9+/aUYat/bObJmnwpsli+vjaC2oJi7rxc3vVOj7VEIi/14L
sjzYXaH4kwqv6sXv7x1uQZ4r95yWWqRCZvFQYLhuK5qeSHLNWKJCIa2Q+a8e
rSgCPdET/k2F3B3tFqdTW5Egi0864Q8Vym00NhevakXZQWDx718qzJl0fvro
fSv6H3/uGP8=
               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVVXc8le0bN57nHERGeqNXRlFWJNl03yGh7FUabySjZJRSdpmHw5FwzmnI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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR
IZkaNKgQaXCnMg+Z6U1Ckumc5zwPEpLf8/tjr70+a6917eu+7r332ipO7oed
hVksVgsz/n9OjbUtUzpAwi+z9pNC1/vAzczZt8aeBP2WuV9uGfVC8XWvmWuR
JDiy/lFSqOgAjnXU7u+xJBBh/nUp/u2gp5BzdUciCU8b+vdI67VBblqXwnAG
CW9N03QfPG2G7Jx9m/cWkbDCMm37t9w6iEFld+FeZt07wN1nfxEcuLSt8OgP
hovOxW0Tz4f5e6xmno6QwEpPOvIo7TGEVUdcdZhg+MXDk+LqyVAyNGVpLy6A
t4Fu2keaMzF/3Nnj1VIBCMLVJ00vvUcZm9FFfy9nmBXCLd5Zhh4vLhTJqAiA
cJRwDZ0uRx3/lD+nVzJcaLLVx74a77MaI+U3MHrKGcU55xowbf6OHB9jAUgF
P/lV6teGM65VZir7BOBx49TyhvXtaFdvLag1FUDSSER3YF87KsSe26JuwegF
xXY07v6E8XL3yppsBZB+QxHmD33GKyoyvevOCUA+ZG6vmEs3rrBOXFbvJYDs
ghNV83K78UXEMhtXjgDuuzrOyI9348Doytr7/oz/qpRQ2ws9aFy+vVAlTADd
YqWAV3tR9IxzxKIUAbRYvqlT4vZh6u2hD89uMfvZgOyXZ324scV99mC6AGqF
OgtrhvrQycDPO/KOADoGOl7Cse9YujDaXuwp4ze30b1kXT/+W/BCd+KDAD6M
Z27pLfyBcoMGZxMqGD292oaYvh/4WOn9vY3VAmD5oUq09AB2htUt8/gogCMt
FhaXTg/g9qO94oOfBJDqtP+hj/QgNl37e2d4J6M3Z3CgZesg/vNuxF/jqwD0
yqs3xJ0YxGStCcGJPgGMJI+90H4yiL9m5n/+jy+A+HdjnkuMhjBGN1b2PCWA
y1wZ1g2XIdT8W+7QkjEBXBiRagi6MoQ2DSvKLCcF4DauGppSN4SFmZue1IpQ
cKPhpt/yg8PoZeIQXCJPwQ7xV9dv649g77RnZMJSCuaZ2GlXWY3goadhCa7L
KWiQqfB38BxBHYXce4rqFBQqjkp8yhnBgaHfNZx1FJTst2vWkeGh9W2pVnNd
Co7ZT7B5a3hYZqnepb6JgszuR+oaRjzMfG0qaNpGQdxPn2NzPXloF5W8eJ0x
BadEfmTWVvGweleukvg+Ci50t6mGdvFw60Tpyi+mFCzX+zf7Pc1DOcdB/asW
FKxUsDnTocDHxg36x3/YUVD7VcnhshMfiX5TlxIHChT36p1I8uJjbrKDe4IT
BdyGiICtIXyMFAm/aHSKAvXGnl162Xw0bm29c9uLgt3jhsrrv/Kx4MpgLodD
getZPzneCB/VDGeKzM9TcF961mLPFB9Z99Srp/+lwON55OnaRSS62+o3N12k
wM1t8b0ZZRK7Fpp15oQw+emOD9drkfiK68W3iaDgaXPHGutdJK7RDp/QuUaB
xBpXV0lzEpN6klniMRREyV/dfcaGRM7+dzIFCRQ4hq/VWHKGxPXLpLdIZVDg
+WbdhFUUiWkN6sSPLAqMDY0OW9wgcUGo/r6SuxTk0c4fJ2+ROMRzsHV9xPgL
NzC0fkTikUyvv4yeMPmkqK6XyCexwjr8rGIeo1cQtturmMRszA2qLKJgTud0
4ZEyEmW8312+/ZKC33fdZjuqSbyo2RbLeUOB4UNdkGwgUdA5mGz+lsn3+re/
JltItI+dyVJ/T0E6GW6X8onEuj3Sj6fLKFh/MGnh+BcSd0ypFzZVMn4IcWd2
L4kKJ80qL9RT8OCmSdjRQRI94yPNVjUy52fkZJzzCInVZbUNdc0U0GYG3M0k
iWoTElbebRRccqsdrKVIDNA0/6T4iYK7hgaJq8dIbDl67XjpZ6b+wFEd858k
al+t6/m7i4ID5tHH9X+RGPZ6gYtkDwUBeVTd8CTTH575UME3pj8SO1efmiZx
s3KUm20/BaqBPLnc3yRGH6qnhQYpcDF7vqNkhsSBi5K+94cpSN2SY3jzD4lE
/oHpA3wKhl6tR5hl+tcXFTQuYPKzlHTIY5iS/SiSOkrBmjsn31AM7zdZeHnX
Two2P33u+4fhTO5BicFfFNR8E6z+xPBUTnRM9DQF/bpn3S4xbPn54+LNfyi4
rkh/mWL2eyQhdbOTRYNr2suFRgyLGh5SChahwXnb+Zu2jD8795iM1eI0xFbb
LtzD+H+e3qDRMIeGu6cWirKY+iSbpB5w5tOwmnlhrjH1u4hY6ChJ0rDBcsPj
kQkSS/Ri895L0VBplBSkzOS3xKVx8z+LaOicrZRYyeTrkSj9SkqOhp2eGt0s
msTKSgsokqchUf1O8FOmPypTse+PL6Vhe0dH0CYeiX5aTSaiy2kAOb5tzBCJ
WlGHD1mo0bDlWFJVVR+JIRjXMqFBg1p/kVNOD4mdgqYjaZo0qA60DDl2kRhl
aXliWJuG7lVBlUfbSewPuf49dj0NDSvZS1ObSYTC5tP6G2moKrps/eIjcx7l
/+cZqk+DGfuk94UKEvfuj/+ptZ0GEYeYfdrvSczwb/FrMqDhXKML73kJiYe7
/hesbERD+qWt5+2ek1iQZRVfbE7Dt+E8k/kZJEq0Jsg7HqJBqFR4Z1YKic7i
baniljTcJ5KSFZn7Jnfa+o7lERoc08JUciJI5OrYFPKcaJDR2qVh4UmiQfGR
DhUuDXsj3F6s3EGi6z+rtIT8aZgT01i6V4/E1KU/A7sDmTxaFvBN15I4HXhd
7XYwDd7jlcETS0ks3lXvtiyahmqHF2sFk3zcVGsktuQuDUomYykVT/mo/VVH
V6KFhqySqaQmCT7axcyEDLfRYJ9HqXwXYt63nbXt1Z9o8D8eqff9Jw+Hs04H
XvnK5PdQzuBJNw9zTmVXig/ToHC2J94rn4catIKDkPAoBE3GAsuah0piYpE/
141CeQ1Rszh2BMOu1PhU6o7CypHa3IyQEeQviHNI3jQKupN7pTW4I1gip7zR
cPsoxP9w0ZRyGEFHza3/hRqPQvZAzOHAtSOYbXpWU/b4KGQe/2L0tWwY18a1
ftgYMQoi4dvkhceGcJvy3RmPvlHYrzXnxzrjQWz1ctlWHTkGjhaaoRGr+3Ft
SbmijdE4iKq6yr8U/YYsI+Pyd7xxMCs9U6jE/A+kb7xc1xL/EzrN1hSdNu3E
r131OxT2T8AqitM6KtuBa5yEZQ1GJ4BfYjO/81UL6n5ujYl/8AvaTPO2y95t
RF/VtOpY+0kQub8sdt+GetyaHfrxrPgU/NHm/UWsqsaipQu4ga+nwC5B2b3d
vRzz6/KHz7hMw1HluJfR/77HMz5TwlHLf8OGXna8fdVbdBze1GHV/BtSDYfn
Gcu8weaUGO5v/xmof37tM8e/GIV3XX3dpvsHwgyLUiJXFmKu6p2a6C9/oFLT
1LnNPx8TG/OT+CGzwPJp5jzSf4bLtz8LIZRYhHcJDC7Uy8Una5JUJ8+xiC11
TTFqlQ9wuezBuJo6FpH3IsbYI/YePnJh9QhWCRHHKvpu/9eWjeetdiaIBQgR
bY8PK7ulZaI6HF6q1y5EpN5xj8gNTscF5bT44bXCRN1FVtyKxFsoW3Ct8V2Q
MNET2i/afCsZp1N/nTX/T5jg23KyDMsTcYXaqHuFjgiBNSpw1z0B1bLfGNlG
iBBOi7T2huteR+d3SwK7vooQ15znlVoejcUyE9eEgo2ihNtiR2otNxpFKmOC
sqNEifgNBZ6TxyLxwvfdH4O/iRI38/Zff/ThCn6eqRQEgBiRML3Hgr87HK0C
TajKm2LE58l0bSm5UJRMtrIR5YsRi61cWmWNgvHOs43RR/eJE+3p3g9/B1xE
P5eMtWlp4sTR9nmHfFkX0O3S3JxNtDhx5kAyPdchEImbOyf6zdhEpFjW3jc1
fmhhPvdheAabKHap2BqXzsUuDeNIoSw24a3mx7dL5KLrn0tn/bPZRPfssrta
UVwMe/J7nfs9NlHVtU2u1Z+LL6UFBdaP2YRaiek7Gxsuqra1lWgUs4m2DOFY
xYVcHLPPbnrfwCY6fAr8L1/0xYtbevINmtiEuXJD+UeuL0pKLU8oamYTH8K1
2hU9fFGzNNHmYRubSD6hS7y290U7taudcZ1sItX0yazWDl8s+3Gu/8QAm2j2
3nzzzQQHD7/Nrfg8yCZWTTnZEiQHu5OG71sNswl7r8tl5f0cnNrnfGYfn01s
KIqO6GrloM6jI4L1Y2xCVubina0FHHwVktD4YJxNaNY5+Hx6yMG9x5vy1CfY
xCvxsa6ALA46SZr5yE+xCadWbW59HAfJ/svWcdNs4pvJgeyACA4GYNkWiRk2
EUornNS5xMG5ScIKYX/YRGFuQ9638xy84QFTs7NMvWb5sannOPh/or4eSA==

           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922113332017043*^9, {3.922113452959154*^9, 3.9221135264030733`*^9}, 
   3.922113973319003*^9, 3.92211877219796*^9, {3.9221191331962543`*^9, 
   3.922119156783126*^9}, 3.92211919957332*^9, {3.922213484956573*^9, 
   3.922213495252357*^9}},
 CellLabel->
  "Out[3480]=",ExpressionUUID->"c8df772a-6cfd-4fa4-bc72-d45805fbc83b"],

Cell[BoxData["1.2864658541479104`"], "Output",
 CellChangeTimes->{
  3.922113332017043*^9, {3.922113452959154*^9, 3.9221135264030733`*^9}, 
   3.922113973319003*^9, 3.92211877219796*^9, {3.9221191331962543`*^9, 
   3.922119156783126*^9}, 3.92211919957332*^9, {3.922213484956573*^9, 
   3.922213495433758*^9}},
 CellLabel->
  "Out[3481]=",ExpressionUUID->"e629fe4d-db4a-4cd1-89c0-7c34cfc145be"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lasso regression", "Section",
 CellChangeTimes->{{3.922108230321486*^9, 3.922108232959588*^9}, {
  3.922135092627462*^9, 
  3.922135093600297*^9}},ExpressionUUID->"219b7d6a-bc4d-4fe4-9964-\
db2508dfa524"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wp", "=", "MachinePrecision"}], ";"}]], "Input",
 CellChangeTimes->{{3.922213558931281*^9, 3.92221356219067*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[626]:=",ExpressionUUID->"e65b88f7-3757-4ae2-9613-f3ae8c5ccace"],

Cell["Using only Mma Fit function, no direct implementation", "Text",
 CellChangeTimes->{{3.922213537954433*^9, 
  3.922213549767763*^9}},ExpressionUUID->"57586e85-660a-4ee3-9260-\
67e3ff55fcef"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lassoLambda", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"weight", " ", "of", " ", "regularization", " ", "term"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.922122829349701*^9, 3.922122848737938*^9}, {
  3.922123012687141*^9, 3.922123013389862*^9}, {3.922125991755205*^9, 
  3.9221259935062523`*^9}, {3.922135098573461*^9, 3.922135100620913*^9}, {
  3.922137124370079*^9, 3.922137124700053*^9}, {3.922137235234328*^9, 
  3.922137235382807*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[627]:=",ExpressionUUID->"da68f7b1-5baa-4e8f-8f24-811cd67dc0fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generate", "[", 
  RowBox[{"24", ",", "750", ",", "250", ",", "250"}], "]"}]], "Input",
 CellChangeTimes->{{3.922135832625894*^9, 3.922135841898711*^9}},
 CellLabel->
  "In[637]:=",ExpressionUUID->"9d4b5339-cb31-4b55-a117-9bc1b21bec60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "576"}],
  SequenceForm[
  "nTrain: ", 750, ", nValidate: ", 250, ", nTest: ", 250, "\nnGaussians: ", 
   576],
  Editable->False]], "Print",
 CellChangeTimes->{3.922135843710486*^9, 3.922213555204315*^9, 
  3.922213590678469*^9, 3.922376304793915*^9},
 CellLabel->
  "During evaluation of \
In[637]:=",ExpressionUUID->"2e842825-784d-4986-92ef-9d90a6d8a095"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematica Fit function", "Subsection",
 CellChangeTimes->{{3.922126425033379*^9, 
  3.9221264291936493`*^9}},ExpressionUUID->"ce16388b-7869-44fe-92b2-\
17e27a023a02"],

Cell["Fit function from Mma Fit with Ridge regularization", "Text",
 CellChangeTimes->{{3.92212206085918*^9, 
  3.922122076579733*^9}},ExpressionUUID->"34c6516b-e321-4e10-b8f9-\
a48a2df6890b"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\n", 
 RowBox[{
  RowBox[{"mmaFitLasso", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<LASSO\>\"", ",", "lassoLambda"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, {
   3.922120424797739*^9, 3.922120447099926*^9}, 3.922120706798108*^9, {
   3.92212830740444*^9, 3.922128310335128*^9}, 3.922134648997183*^9, {
   3.922135171056163*^9, 3.922135216721237*^9}, {3.922135256695713*^9, 
   3.922135258761607*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[638]:=",ExpressionUUID->"c3b10ff8-721e-4965-845c-5c1f16612049"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "576"}],
  SequenceForm[
  "nTrain: ", 750, ", nValidate: ", 250, ", nTest: ", 250, "\nnGaussians: ", 
   576],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922128311034256*^9, {3.922135190070249*^9, 3.922135218208961*^9}, 
   3.922135288178158*^9, 3.922135850137865*^9, 3.92213712913046*^9, 
   3.9221372405585012`*^9, 3.922213595006237*^9, 3.92237623609728*^9, 
   3.9223763102261143`*^9},
 CellLabel->
  "During evaluation of \
In[638]:=",ExpressionUUID->"b56022e3-96a1-469f-8e5c-2759fe53b19f"]
}, Open  ]],

Cell["Coefficients from Mma Fit", "Text",
 CellChangeTimes->{{3.9221220461160088`*^9, 
  3.922122054900242*^9}},ExpressionUUID->"8dd7f499-62c1-42bd-b462-\
834d12e645f5"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\n", 
 RowBox[{
  RowBox[{"mmaParamsLasso", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     "\"\<BestFitParameters\>\"", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<LASSO\>\"", ",", "lassoLambda"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, 
   3.922120424797739*^9, {3.922120457049314*^9, 3.922120466507172*^9}, {
   3.92212070907828*^9, 3.922120718485894*^9}, {3.922121718833121*^9, 
   3.92212171976037*^9}, {3.922125507532485*^9, 3.9221255130820503`*^9}, {
   3.922128314495399*^9, 3.922128326619739*^9}, 3.922134649799423*^9, {
   3.922135227582181*^9, 3.922135263563427*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[640]:=",ExpressionUUID->"d07665cb-82d3-4d91-8718-4c9af34ffaca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "576"}],
  SequenceForm[
  "nTrain: ", 750, ", nValidate: ", 250, ", nTest: ", 250, "\nnGaussians: ", 
   576],
  Editable->False]], "Print",
 CellChangeTimes->{3.922128317559909*^9, 3.922128347842922*^9, 
  3.922135236551754*^9, 3.9221352903489647`*^9, 3.922135864516972*^9, 
  3.922135955906052*^9, 3.922137141391724*^9, 3.922137247545541*^9, 
  3.9222135989205236`*^9, 3.9223762390902557`*^9, 3.922376313159799*^9},
 CellLabel->
  "During evaluation of \
In[640]:=",ExpressionUUID->"8a37d5ce-b57b-4a38-a384-85ea09051466"]
}, Open  ]],

Cell["Count how many coefficients have magnitude above a threshold", "Text",
 CellChangeTimes->{{3.9221226346627607`*^9, 3.922122644968471*^9}, {
   3.9221265529849358`*^9, 3.922126561915202*^9}, 
   3.922135241802781*^9},ExpressionUUID->"282b8367-8fd5-44b6-8a10-\
37441c4d2ae6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Length", "[", "mmaParamsLasso", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"mmaParamsLasso", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Abs", "[", "#", "]"}], ">", 
       SuperscriptBox["10", 
        RowBox[{"-", "7"}]]}], ")"}], "&"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", 
  RowBox[{"Abs", "@", "mmaParamsLasso"}], "]"}]}], "Input",
 CellChangeTimes->{{3.922122500442021*^9, 3.922122553337991*^9}, {
  3.922123070011699*^9, 3.922123070324998*^9}, {3.922125518779883*^9, 
  3.9221255313495493`*^9}, {3.9221283314183197`*^9, 3.922128338757143*^9}, {
  3.922135265649846*^9, 3.922135277702627*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[642]:=",ExpressionUUID->"57aca6da-31d6-440d-a6fc-315b19286a3f"],

Cell[BoxData["576"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.922135248606319*^9, {
   3.922135282054122*^9, 3.922135293239501*^9}, 3.922135875017294*^9, 
   3.922137146891299*^9, 3.922137251510727*^9, 3.9222136068577347`*^9, 
   3.922376245944031*^9, 3.922376317265287*^9},
 CellLabel->
  "Out[642]=",ExpressionUUID->"7448f1b4-3129-4ac6-aa2a-df622ffd626f"],

Cell[BoxData["27"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.922135248606319*^9, {
   3.922135282054122*^9, 3.922135293239501*^9}, 3.922135875017294*^9, 
   3.922137146891299*^9, 3.922137251510727*^9, 3.9222136068577347`*^9, 
   3.922376245944031*^9, 3.9223763173734493`*^9},
 CellLabel->
  "Out[644]=",ExpressionUUID->"5b5142cc-c1b2-43b6-9e4c-692bd29eeb63"],

Cell[BoxData["2.2728891302046943`"], "Output",
 CellChangeTimes->{{3.922122523802148*^9, 3.922122553891212*^9}, 
   3.9221230338250847`*^9, 3.922123071876252*^9, {3.922125524413287*^9, 
   3.922125531830742*^9}, 3.92212567012071*^9, 3.922126484392908*^9, 
   3.922126666228232*^9, 3.922128350022584*^9, 3.922135248606319*^9, {
   3.922135282054122*^9, 3.922135293239501*^9}, 3.922135875017294*^9, 
   3.922137146891299*^9, 3.922137251510727*^9, 3.9222136068577347`*^9, 
   3.922376245944031*^9, 3.922376317446714*^9},
 CellLabel->
  "Out[645]=",ExpressionUUID->"edf90766-4b86-48a0-b89b-16792c47e40b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MeanLassoMmaTest", "=", 
   RowBox[{"Mean", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"mmaFitLasso", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "->", "rTest"}], "}"}]}], ")"}], "-", "yTest"}], ")"}],
      "2"], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<MSE error: \>\"", ",", "MeanLassoMmaTest"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lassoMmaPlot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"mmaFitLasso", "*", "yTrainStdev"}], "+", "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"lassoMmaPlot", ",", "LJplot"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9217687936291533`*^9, 3.9217688327658987`*^9}, {
   3.921768864444922*^9, 3.921768870848134*^9}, {3.921769486805279*^9, 
   3.921769542793608*^9}, {3.921770940634282*^9, 3.92177094183883*^9}, {
   3.9220952593893003`*^9, 3.922095259496469*^9}, {3.922096300918138*^9, 
   3.922096301503976*^9}, {3.922096529892295*^9, 3.922096530718207*^9}, {
   3.922102592447061*^9, 3.922102645533327*^9}, {3.922112668774447*^9, 
   3.922112669746542*^9}, {3.922113273091929*^9, 3.922113279521315*^9}, {
   3.9221190633074493`*^9, 3.922119078179054*^9}, {3.922119127356476*^9, 
   3.9221191312846127`*^9}, {3.92211919570715*^9, 3.922119196419444*^9}, {
   3.922121506969965*^9, 3.92212160524834*^9}, {3.922121643794643*^9, 
   3.922121646650465*^9}, {3.922125240798301*^9, 3.92212524639273*^9}, 
   3.922125723549638*^9, {3.922128369111349*^9, 3.922128424159648*^9}, 
   3.922134650736749*^9, {3.922136055776037*^9, 3.92213608668617*^9}, {
   3.922213614151449*^9, 3.922213623517144*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3495]:=",ExpressionUUID->"3afcc535-ec34-4020-84c4-b6344ef52bf8"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "250", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "576"}],
  SequenceForm[
  "nTrain: ", 750, ", nValidate: ", 250, ", nTest: ", 250, "\nnGaussians: ", 
   576],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922128417419879*^9, 3.922128425510849*^9}, 
   3.922135315722446*^9, 3.922136087835258*^9, 3.922137155302932*^9, 
   3.922137279072151*^9, 3.922213625096517*^9},
 CellLabel->
  "During evaluation of \
In[3495]:=",ExpressionUUID->"3cf51bf0-8d8f-4e88-9ac7-4a7c3bfa8fbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE error: \"\>", "\[InvisibleSpace]", 
   "6.613546166628044`*^-6"}],
  SequenceForm["MSE error: ", 6.613546166628044*^-6],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922128417419879*^9, 3.922128425510849*^9}, 
   3.922135315722446*^9, 3.922136087835258*^9, 3.922137155302932*^9, 
   3.922137279072151*^9, 3.922213625181254*^9},
 CellLabel->
  "During evaluation of \
In[3495]:=",ExpressionUUID->"373fc8d6-9f33-4787-89b3-f8b98b4537dd"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVVXc8le8bxjlG2VIpsldFRSEa74u+lC1llLJKkpS9HWTvTZSdFRJSGm67
iEJEEZLscc6xV37Pzx98rs+9ruu67+clZPng8m06GhqaN+jX//++/Sxa01C7
gKU9/v9PKxYLAg/oRhcw2W6ZSNnPrzCdAKVqk4kFrFxDNpIu+SXG/N/V7fLZ
BeyKi6Flw2AxFtwWHmG2uoD1p7hJZPElYbXTGwY3GcjYeVumqo3veVC5fPvh
O14yFvNu8VxAfSNwGS3uucNPxqpk6E+8c2+Gh2/8XnMJkbEA1pOVJkc+wjGv
9H93xcmYnZJuMrNPGxTSdEXyyJCxw3FLPrsdOiGD+WyRixoZY2poYDUy/Q7b
dq1aQpfIWOeQiP4MWx+YfjEkt2uSMTrZ6YTj0AcH4hwURPXJ2MRHWokxnh+Q
uK+gufs6GUs727z5/uUAhAlxjR53IGNHX9vffIiNgKBhCt8XJzImNRHmaRY8
Am/C+YzsXMnYH39PGav2EZhcFG8v9CJjKo6sopVXf4Nay5lqoWAyphDpz1J7
YxSI926H70knY+HfVGKL/xuDJ5nTTS+fkjGlB7x8XKQxONnzYEc3i4xV2FUe
evV6DCzPeTpHPiNjjnIsPNXif6GePeYmfTkZm1xkNh7a/Au+VW9kV5vI2Al9
R6dHgROwb+rc/aSPyD+uwaeJFRNQeqix4GQbGVvy3tCgGZmAweAOvodfydiK
dA5h/vQknDEZZZj6QcZOB9c46v+ZhO6oO8ohg6i+t83qNssU2DbMeokNk7Ex
tiMTI6emIO3oKtlijIxpHPSo5Q6cgrVt5oGf82RMPGVS9jHvNMTKxu31oJCx
SId2iz34NEje2ae3f4mMNfE1fKa5NQ1GnYLNButkLDHCvkmpeBqqc+RetBMo
GI37zB29EzPgpG72qJaHgnWO4O/4RGdhdNMxMomXgpnLh3Y0qcyCXnlwkh0/
BfM90pQzZD4Lxw6UFRwUpWDCbjoy99NnYXJ667PrcQpW8leHnW/3HBhmcvRq
y6K4fE+Uu+gcNBuIDonKUbCqkewI/fNzkPNek9ytRMEeNpmy+z6cA9PoNO7j
ahTsdN/tzD9f5qBNpewQwyWEs/EMtb9zoLhaL/5Lk4LFf//1+fjmHOwznzod
oU/BVObo1B6LzUOXzOkbE6YU7GBeBO2k8zzg45rWtWYU7GZB2c/0kHkoSzN7
kGRJweQXHF8NPZ6HSEKIv6oNBUuTV87e+2Ee1Hp7n2U6UTDiLlee2//moSps
qszVlYJtVbL9KGVdAJHz26+1PSgYXjj0LopvAWgKRNs2fSnYtFjO532KC/Dg
+ulv3f4U7Kc+w996tQUYYtcaLApE+ity1hmvLMA7d6d5o3AKRmYz67O5vwBH
pENWj0VRMLsHCj5BHguQ+juNhiEW8fPu7cODFsBVo4GrKgnpe6Kjn5K+ACf4
OBU4silYrOVGwGDjAmR0iuITuRQsoF95F1PHArAGnb5Um0/BmtyY7vzoXYDp
ObPrdiUUrM65nt9hfAGMc5xuqb5A+y2/eEJxfgE+GobcP1hBwYq7IkOLlxcg
D8pIn15TsA07D4UWWjJwOTeEZr6lYLeeBlzdIZLBX/J7nOsHCtZz7U8TGxMZ
yINTadp1qN+NmoWl3WS4GbedK9qI/Lj9FKtgJUPHf5ylm81I/3r+IXUOMpzd
EK3u/oT4rT2gVnKR4YCV1ie/LxSMbUZdcP9+MjgmRmpJdFGwwZS0iTkeMrQ1
t3d2fKNgE9G2srkHySCyynLV+TsFc2tfMFDgI4O3pPaPgz8omGEMR2bxITL0
mETdqB+gYAZCVtbb/GSQjuj4fWeIgt0JP751XJAMwe9Zrdl+U7ByKYcKFSEy
DM1pT1f9oWD71Pt/ygmTQV4g2v76OAVTMPvcskuEDDF6X6i0U+g+Htt8rEV4
0p/NrXAG3Ss5WPqqKBnwSp1NnXk03/L1pQ6EU8eiSctkCua6/Z+dhBgZKHu/
Ep4sUjC9QaW/VghrqLOHqqxQsJjd14mPEM5x12WZWqNg/CaHDwQhvFEUExuz
ScGsuCccbRE2GPjKLf+Pgq2VJ5qfRLiEhePxIA0VazGlnhhB84jn9Q49IlCx
VJKfrAPCpg9isw8zULHJw36V44jvq6xOsU4mKjZ+b5FWGWG2bo5iV2Yqdirn
6T0/pNeaoH/sEBsVG8onnH+G/Kg9FVfRyEHFYjfutbxAfu237pK33UPFBL4N
6WcJkOFhCuc7jn1ULEpEXNoN+fvpkz72moeKhYZ25J1C/gttxDXe4KVi/ceF
6X/wksHzaLc6kZ+KPc6XTbuF9nc0+rKevggVY8kLjpNF+w6E+J5VMSomVf88
3GUvGQbJ3cYZklRMnkd3PGsPGaINDCxmpKlY1zMu8kt2MowHJvyNO0HFzp7i
PJmK7gur/nb39EkqBgGX6GyY0T3yXHEMOk3FGjs17JoZyHBRI3Hl6BnER2Pw
sQG632yvHs/uc0gfWd6jHd335aErjwRUqVjVodrhf2sLUJV7NbFGm4othc2f
H/u9ACy9STzmelSMKmBGejewALcZvj9hMKBifn+3MuzQ+9p31/CZgTEVM942
Lbv5aQHcjxlVz1lSsWldOu24kgU4V2PcL+ROxXqwvJuF9gtgZytxlNaLih0z
3yf8/PYCPOFd8RnxoWJ1l4pEIkwXYNMnQSTzEeLr4Or899IC1Kh8seeLoWIB
smX79oosgFy7Kv3+fCpmJ5dNmf46D9LDx2RZeqhYcYXuQOD+eTCN3Q6c+U7F
KmSfaxgzo++bcntf2w+0Xz25M7w7czCTe9cnbJiK2ZYPRziMz0GRTd4nhhkq
Zq0WvPt+1RyIUQ+Y0dItYtHcwzcJOnNwiJ4+cuX4Iiap7LbPw3MWlATytx+O
LWJvHst1bElPQa+TtVJb5BImFSpCbD4zDlK1LQeNVJex3aP6ls/5/wCNqlpL
w9wyNoZHtR8yHwEt7llmM/IyNn/Ug0RnOAKpf+P0N6nL2N0n19LmNEdAJvTX
4Mk1VJ9irNSnMAKWHc6LeXQrWNXSWdd19hFoMsoVDNm/gjHpMuOMj4Yh1I7G
S1N5BWO5V5AzaDAEnMlvj/ckrmCk0gcs8sKDcGpiXrUoZQV7XsNgIs8xCMan
RYx901YwnRlim/q/Acj4GeEnmbWCmRMV+57+HIAjAje6vJ+vYKUj0/nciQNw
oXDHUaxhBbtQdpyZd/cAuL+9UO26sIKZBMoc/UH7E4aHvpw9oLGKjeafXWU/
0A9HLOn2nltcxWo/dMpw/ekB2YHe2MTiNWxQ2df+z8su0N16H3SrdA1Lprb1
EfO7wO5Qnuep8jVM3j9wUiqtC/LNHG/1vFrDcEl3g7iALjg4xnaau34No7p9
SCk16ALCnPpwQt8a1uwlsE9ttRN6/tVIJxDXsWuNe70DL3QCRSBb2IpxHcs7
sKCao9gJbMqh+0/uXsd6eNbEW491wsVHhrTf2NcxtR8NJNkDnfCBcbGHi3cd
WxqPvzU9+BXyOaS842XWsZscVRrRcl/BTTijLe7mOrbinRP5Y7kDfOteKslY
rGPfFafO//jTAcE3m4s7rdYxqYtjDDNdHZCYNhvOfncd2zjMM32hrAPKuc5o
RjmtY4+uMl3uvtMBk3T9n0ND17HBlkftBkPtYPyHs4NUsY71q37zbuv/DIp5
QV/vM2xgP5mKHeZ2WmFfgwSb2q4NLJZhTWGZ3ApLw61a/CwbmCOPIxPraCuU
87K1feHcwIQNaljsmlpBMiG56fihDeysroDtaFgr8AQU1FBObmC3p0Osgva3
wppZa66LBeqn99r23NlP8JqX1d3n/QZmJLwdpJDVApUdlTP3rDcxI36HKsvG
Rrg8yeGsdXcT0z8/Wcz3uhHIdPZbUnabWKu90VhfcSMcOy3JOu+wiWFfvW5c
jm+E4pwnxx76bGLEdEllE4tGyHYLcnBO3MTIpibzsNMAMUJGq94Nm5iPbi0x
/XwD3HPZoIvm38L6b09JnPtcBypWusIWQlsYe4qRr2ZdHRzUz1M+JbqF1bbk
81m+qoM2KR2/n4e3sD3KjoWFmXVwZCx7W1xuC/ve2ns8w7kOJi9fWgPNLWzm
Z5a1qmAdWJ9InaO4b2FLDSyDF/7Vwnn+OZZmry1Mce8r7v7pWtjHoiKV6ruF
ffCsfu7fVwvNEzO25wO3MPehYSuel7UgmolNhsdsYXTc2+8Mb9fCH9aJUZH8
LUzAxT5UsvsDmM/I9V/9hviz2clbfngPwoavHdd6tzAzG9Loaul7GKs7zZre
v4Xt/H5ak53xHu4kn1EZ+bWFyXx3L5fxew/2ysoltpNbGK30z3X8wnvwSdHy
I21vYRniombMne8gTdVKskhiG2smJPLFLL+Fb+mx7lte29iAG/uttAc1YBec
9bvPdxv79mOD4T+rGiA6lGtU+m9jWX8a4zYNa0BerZPPNgTlN+diEedrIJXM
Xt8Xv41Z83TzSbPVwM3/YnZVFm1j86cMps68eAPT81Fpd/u2sXaursjUlddA
pxLx/rvsP+zih/LfBZHVUCb87HPMr3+Ytvuy3PvOSrC98UNNeuQfdv6UPX9j
cyWIpbI2tI3+wxaYPIdb31bCE1bXN/ST/7AsTnPbvrxKiFhTe+ZF/Ydt+Fop
rLhXgs2XSd87jDvYL6uvL82FKkHYU0oWk9nBGD4zWU47VcBQlXnp4MkdbNwo
h3LibgU8XkiU9JTfweTpq6leNyuA4/Y2/6szO9itusFxgUsVsKP7hfmo2g62
9rXkTy5/BQyKPfy77/oOVkVwVK1tewkpXZWp84E72JEyHUFVyZdwJNJ1tClk
B/t8iE0+4tBLeK+mKJUevoOFfm+f+sX1Ekbf1YJ67A7mnHfgU+52OUjlt45n
pe9gWVXSAa++lUOd5/Apg4odzFN5lz97QDlMizB3vR7ewd48+hr4ufMFeA91
HIwe3cE0NoZavGtfAPvj2Fu3/u5gdkVHRi6VvIBTbPvWOGZ2ML89xjMKoS+A
tCYoYLuyg531a5C9rfwCwq3T5aMZaPC8I4OsLDVlwH/mZSB+iAa3zFyLNv5Q
CoPfJe8k8NPg3l/kBv1flEKaY9alcQEa3HdU/WRDdinsL45hixSmwbWcq++H
BJcCxwH71D4JGrzNNKlDQL8U6FaPlNjL0uAVn98XWEyXwHhF3rcn6jS44Znz
Ya+OlkCeDl/1wkXUL2/9k4VgCVhOJ6SqaNDgR74qKvHvLYFhoUc3JrVocKYL
4kkt/55Df6zFxMnLNHjV7TKVju7n0GbPv9lmSoNfM72o5eDzHF4cSRVed6DB
3yqQiSs/i4F/r2785w4avD0yN6BcthBKrGl+kyVocSlmRtt7J5/BHduuk8qH
afEVlhfaryWegbB9TnDcEVr8O9EvksD3DB67XJCSlabFjc3e0WQQn0FwYKib
kywt7llrzvO7Nw/McjjYVs7S4iXv8u58c88DriHBM5v6tDg1n+zH2JALHb8p
UZoGtLjdHduQzupcCP3bMJJ+hRbXsRRTzH6eCzuzt4LPGqH+1nne15JyYXaz
sMvHlBZn8j3uK3s3F1oOyNjQ3KHFDTteheRz5YLHVeUkem9a/LK87/u5+zkg
+NhE19GHFh+dk/imYJUDLYMOu4Z9aXFvubzyOOMc4L6V4/PGnxbv+apq5aKa
A2WOBOt7IbT4WY59nTQHc2Asplm+K54Wr/MUMrvQlg3h336RzyXS4tFCiXvS
67JBZv9KcXESLW4/uN+F8DobfDPEBQJTEb/we4G78rLhQGkIo0IGLc5lUms+
65sNOm2X+p8U0eK+swPa3KezYZnVMn7Xc+SvVXFZ+PFseKLvqeVaQovzRbHz
7pHIhqn+4jrdF7T4Fy2tVZN92RA4wVxE94oWr2CKi6hdzoIa4hcPmzpaXMMv
I77ndRaIYpd5T/XR4q51e+WcLmYBXk+TENpPi8smMCjdV8mC66ovdv/6QYu/
PzNQ43Q2C+LVWTaCBpFfO+mPnp3IAlq9lv6+37S46JuAoJQDWTBkrpTsNUuL
J/4QED44kAmpAcKcjbR0uOAUbW/N6UxgbaEyXJaiw/M2SzQ/cmVAi8yhtkxp
OpxFf4ZpdVcG+D5Vj5o7Roe/N/rMKkabAfPOT/aEyaB43F17z4Wn8EVETbBO
ng7nVpe+QNP+FGL8HyseU6bD2yn73h8OfAqc53C73YZ0OMenCIem+SfQVmh7
3NgIzeeaFT749wkEcCdRnxnT4Wv0bfG3Bp4AdWbKXfk6He6eVvj3+8cn0J2W
EORuTof3e9SrSGU9gYS18YxxWzr8zagH7qbzBPZWRXU1kOjwiw1N2r+y0uGN
2c6mlD8dPhmt8S8pMR1MmR3EUwLo8FPC3FrnQ9Mhz/KK170gOvxETPrajQfp
IMvJK8YdQYcvhfe8HjibDjr2he63kxHfwadq0z1pECrZKMBUSoc/uRZik7Hx
GDafrN3X/on6M9r9ZySdCtwhNIaZA3R41TPlwRaBVJByYDpPGaTDafYasyly
paL/DzxsScOof17AW/HVFKibUygbHEP65GUfyNSnQOB5t/l7C3Q4UUj021XD
FGAbWbYPJxLw0xIVQldDkkG8bdtwkJ6Am06nCrV6JgNWRY8dYyTgnYyXOjXs
k+Fh6F727l0EPGvj0X33q8nQfULuxQF2Al7S69YdKJoMKf7OC4UHCPhDbse3
mc1JICiy+ODjMZRf2iD0aG8SiGqrgNwJAl7HWqujtTsJJN3i2PJkCPiI8vKY
9E4inPh8vNTvFAFvEqSZVJpKBNzJblpRiYATPc/+I9UmgkXj31sl/xHw8hHi
3vb7iWA9d6rqoDoBN15cXJS8lQi2+wMJYReRHh+ZyMxrieB4TzjntiYBb6/4
+veHeiIE7DEb5tcn4FWHOjICRBIhx6rfJM6UgJ/6vfdAynAC5EdJFO3cQHyu
0vGF9yVA8WvXtftmBJxjmbk86WsCVDDvTdGwJOCxEfFzy5AADZX6PQQbAs6X
5DjXm50Ao4TPOq5OBHywyuDs+N0EGJc+mDHmjPh2p8trWiXAtNHducuuyC/+
Wa1m0wSgPmeMPO6B6mmEi1Z1E4DuyoXWSV8C/n6h7K2WQgKI5H1QvR5OwC9o
7g9/sCsBnrDk6r2MIOA0AqvspsQE2OcSeoMxCvlbXXjTcCcemNQM3CpjCHgP
kxyP03I8zE5MFjMnEXAmrtR9F0bjoeooN9f7TAL+xrA1cuNDPFyotB3he0XA
z/5U8tbxiocPvHpzjtXIP8a73tpu8SAfKLfx6TUBLzymh+s6xYPkVRpul7cE
nNxinm9yLx5YVpPUOwD5v+28Q7oeDz1K9WU+bQTcJjmnpulMPNxu2O8zNEzA
A7vOXx1YjwNPbo9e6d8EXHResDFrOQ5irX9K+4wif9gOzd+kxMG73U+HeP8S
cHNrep+myTjgNBDGTaYJ+JPDaW3SfXHw4Y8UoWeJgDunZwerV8RBt1z0dZEV
An5r45qLT2kcTIYsVDquIv01adWFhXGwR6riFucGAT+h/TxwKCMO7jortOjs
oHuKGphpCI+DvfQqYa27iDiup/lczzwOjhjl/uZhJuKmlw4XtF2LA7yIqGTD
guLPlagKV+PgnvbHaQZ2Ip6XvO/o7KU4qE/S0rrATcT7dUKca2Tj4L64ETvw
E3FvqgfzMG0cNKvbJVWdJOLmwfsU7yTHQssP7quCckQ89Pn3F0XRCN/7wB0p
T8Q70/OZhoJj4VMMW6KVIhHnm4mjOeQWC+195fFcGBFv9w/rWzOMhZ47yzEP
NRA/Yc3qK9yxMBbiGy5lQcTJCpc+vGKLgb8HJDRSLYk40xNxk7itaBh//nUX
8RYRn1SwkbKYjobJr4JhA9ZEPMv/qNJIczTM7m8MCbcj4nWEybQH3tGwVMAY
NOlGxP0Oeji5TEYB4VMsKS+aiAuyqfiZ1keCe+rXrdUYIn5RILzCvDwS5m3Y
PDXjEH8ea40HmZHwc1ekMzUB1b8ncZX5REKFZshd/DHSb+tb1KAUCZZffQwG
c5H+8yx5ra8joD/zfefxZ0Rc8qL3ubcFEaDzcFP7UT4RN049ZVqbEgFKnB4X
jxShflrCOME9ArgMnM+5lxHxkcXjg1GKEdDw3VaCuwbpM/bt4KwPh9MFRXl3
3hJxGpcrdi4V4VDmNin07h3SF7SHfik3HNJ4rPksa4k4T8LpStWQcHC8ZsFZ
3oj6DVNMFXTDQWjIaFPzCxF/ONXO9nYsDJLLkt0zvyK+bNeyV/rCgIXUu0zt
RPhd7imDz2GwJmBAfvwN+c+7/+z9ijDotND5O9GP7iWz4+yRgDDw+3vh66M/
iM+RVtspiTAYXW6rXBxD+n6q+RjyhYEqg36q1Tia5+D0eIYjDBgkblioTiE+
0ruZozdCIdLGZZFuAeln0cit/BoK8+6bfY5ktD85Fqp5cyjohvm/H6WgfHce
Tvl3ocBVHBXUsIT0RZP0jApCIWXm2f6ADTS/cKnXwT8U1jaPblE2ifhaNvNH
E/dQuMZSMWKxjfxbLFO0eRAKfNK1Rco09HjWTsvz1RuhkGP//QwtAz1uo/Ry
74+zoVBGYTD346THY9P2PLxOGwocdFEXyFz0+Mg36f3BGyHgwLXnsDk3Pa43
XZXQtRgCp04KULH99DgHr5FA63gI1DgrBO7w0eMXbxtekPoSAgeDPtg84Ef5
uhJOup9CwDtJVXtYgB7nsVNTi2kIgfPVuvtAmB7/NBEVZPk6BJpW7xT6StLj
xn/1fdVyQkCcaT5y/jA9/iaRZfPc0xAI4XF2uHmUHl+T/CGlnRoCGop+SueP
0eO4eiVjeXQIdHqmtm+fpMdTH38JdvYOgYHtT2RvjB53Z10uNbkeAv2rbYLj
OD0+uZqcE24UAt8p7Xq6Kii+S/rWR4MQ6P7bWS70H+K7dcPGQisE2jr6H7Zo
oPi3H3SE8yHw9ukkmd2QHj8he9vBSDgE3qRMC3oY0eOhV7Vk5vhDoDpuVm/U
mB4XXDFcC+ANgYogcnnVdeTnLSh5zh0CRffXHppYID0SsRq/GEIg9RwTJceO
Hjdv19QTmg6GZIXdQiz2aB/a5joW48GQKMOi7/KAHi8vhN3Jo8EQK8bxUt0R
1Xd18Q/8DIYQVh6HWTekN6vyY31bMAQyHsy+6kGPk+kkIKklGAJo+bpqPenx
QinczqQhGHyXBWTifJC/I7XRpTXB4PpLgiL3iB7v3zh/0KMgGJz7DgtlBtLj
nRv3vr3NCQbHrqP6TMGIf8vb7xNPg8G++fjLn6H0+MNc2/e0icFgXargQIpG
8+ZF3kiQguGqjzrl02OknzRIHdQLhk+vhocOpCM/Pyxa7tYMBqV5t3bbJ/Q4
k1/RccH/gkHQrLCAJRPd48PxRYJiMMziu27q5aH92qyb5QsgPcTPbX1l9Lif
cZyX7GQQrJ61eiNZju6lpMe6cyQIbF02n3m8RP3zZKyu/AgCvfGj/rxVSG8d
sy1bWxDwfopUMKtB9/aO3VyjOAgqInTyxhuRfpFl2unbQSDWNB6n0EyPSz5U
1J0xDYLULV9SaAvSa1YY/c0gCHzvv7h2pBX5rZEVaaIcBJd0OTjtv6B7J5d0
4bxBMMLV7bPcj+7JooX9ZVsgsKVdNSLOo3tpGflkdDAQ7LjkShwWEP8nviof
WQPhczg37TAZ6ZfLOShOGwihXt+KaxbR+7L77lc18Qhob+j/s19H92ASvS1e
9QiWBLSf/SAy4IIbCkx0mo/g57MLi2W8DPhIHxlfdQmA0/yiF/kOMeDuBiRi
vU0ApCQTnobxM+DkvWJT8dcD4EpIg9otIQa8vLTY+bJyAHTY4GkHJFBc/bWw
MWsA1B09qxwoy4DrLVdHnC70B/483mTKSQbcr9M4fjLdH7z5NqdvyjHgJ7rF
yKUx/qDI+jZR8TTCfQm9Xm7+UDGvMDl/jgG3+SowoHjRH569PBljcokBX7uS
xD427wfuNkXZZRoMeCF35NrKmB9oCQhUEbSQnmKKt/iAH1Ajd/8o1UH1jAbm
vz76AW7zW5juCspPGZZ/k+MHewSM5IyuMqDvy9LLD4/9YLy3Xb3EkAEPTRWM
/xPrB1Gqb+wMTVD8RdDxeJIf/OSPqS6+yYDT1N6dD7rpB2W9xNYdMwbc/O5O
9WNDP/CP9By4YsGA99fHznbq+IHkxm2aHSuk3ylrtBjzA5fesxoGdxnwi4Ne
rHtF/OBiZIVpoS0D/nCV5a4Wnx/wqUo+2L6H/NwYvVa01w8ayvckFtijuKj7
lx4mP+CInP616YT02V+3mftNgj8q5mQ9F5S/dloBvpOger2XLt+VAceb61OG
PpPgxp16CT0PxNdO9xnDaxKc4FdQeuaJ9uO9L4y9lATE3hKtDS+Uz0m5Z51L
gmKVVIc8X5T/dOH8v1gS+K6zBq6TEE56KoSFkkC//FGyjj/aT8mNyQ4SCdYO
PXi39ogBzxKrKeh5QILPPWMd2kGIz4+L2lo2JMiIuDaSE4zmKTWe4LQgwX/r
/9FrhyGcHVnsb0ACnvJ3+3PCEW5QK5DSJsGstcyR1QgGvJPhbZmIOgnie/h0
s6MR7qW5tHSGBNYR8RYrMWhe7snNdnkSKKowOWvGIfxocGVBhgQjLxZTlxOQ
P5I+BVyHSVBpffe5RhLi87v6FKcYCYIPDX/ITEb9JsnvjIRIcK3nSudSCgMe
2yaZ8PcQCaQj2kYvPUZ+pIUyvj1IAhoVfDkjDeWff3CjZz8JetZeMS6lo3iT
a+fJvSQoeHH04KWnaN4n74Q+LhJ4WmdLZWSgexAv6azlIME0Q0L4bCba3+Wv
FyhsaF5B4KRSNrqHDsE/lqwkaFN3VQvLQfOZWdq4WJCeyTt5fbmIr+0hDhpm
EhSGmtCJP0PzCtibDu9Gfh3WNHfOR3pn+2ejd5EgtPVsbUMB8u9QTdgxhNfu
HuPjLEL92i/FMyJss1vQ06wY7W8+coUH4f5izv7S52h/L3cyLBC+qEmQ3yph
wOsWiuxGEH4zs5SgUYb4LcgqJqJ5kpHjlNQXqL548bsX4pMq1a87UY70/GLm
TEZ8mTpaS+UqELZ2ff4b6XG7/445sBLxGRKwusFOgnHW0rvdVai+f3uOkZME
hmUZHwWr0ftfEtscRn616MSKPXiN5stPyI5xk0B+wf/RhzeI371R+T3I7/wY
p9/Mb5Gej2I59w6QYN+J29i1dwj3qO2a5SXBysOLmysf0H4C27Zvon1acyqZ
/AeITxJNko4oCb6/PPo6oQ7pyVo9Yy5BgldUNqcTjWh+vHTEH2kSODv3Tt/9
hPydMH957iwJxrg/XnzTivhrBTpx4iS48upNPsNnxP8a/fUNVRKcXEm3zO1A
/l9aaiRqkYDqZvlzsBvx7xgX/2xKAgevhVbdX+h70VTvFI7exwjvb4mMIcTn
Sv36z0ck0HvfHTQ7jHDL4SgR9J5ObL9SDhtF+VcIJ5LQeyP7etc0TCB+vtQr
TVkkMBew3885hb7HRYz/ZeaRoBPMXMymUX5wfbNlIQle0KjKbM2ifPmG4vQX
JODPPhWjMY/0KOZIsFaSIFpZfC51Ad3n81Zrs2oS2AfsKpKjIv4Wa+YZ70nQ
aqlin7WI+scOvGkCEoiqep1kXkb9pJmo7xtI4CdSteaygvyL3koMbCbBAGHu
w8gquu/lUKkDn9C+xsQeaa4jv6aPqrm3offadPNi9QbiN2vnmNlOgrm8FFah
LdRPRPG/yC/o3oI6uyO20X6P4oZnO0mQe3tX6so/5Mfey8qlXST495/KDQsa
RpzMVZs/2I3ei7iXcDstIx57/OXRT9/Q/hiqJuQJjPiJPSme93tIwDExW5JN
ZMSzHD1U2xC2+yjmyMLAiOO+lmcHEf5YcFPBjZER77z3QSgbYeHQlK3fTAg7
1FTvQ9jHprNeazcj/lCwtFkJ9e+/uCvkNTOq/+QuyIzmnzqsoiXMyoiXy85k
BSG+Mbu8OKPY0PwvYocLkZ7pqcrvq+yo3zfavIdIr1rbbLolJ+Lf70z/q5UE
2cViFh1cjLg5x5rGTAsJtsJvip/mRv0GZr0eN5LA+F7KTM5ehD2IxX+R/5Wa
neWs+5Ge1WeUjnckYJPa5erOw4gLpht66qHvty2Lypk/BxjxOk5Bt3sVJGie
9aTR4WXE9YTWxQ+h77lgR2XzGz6UHyXda1VAgr4oMb1oAYTTFh4XpZFA1v7m
3nVBpC/+TuizBHQfOik/rYSRHr7fYiciSXCBfddtRTHkh9ncmxkvEmQtKB/J
E2fEaazurh9wIsHmV88FNklGnKMtktR1lwQVsbMeY0eQ3p3JzL6rJGB1EMN0
pRD/BGl6UU30/dG/SXwrjep/0KovYyQQ4OqMjjnBiI9ofH0lLEmCyITKXCV5
5M/lpawEqi9MOM3aPFNA+oonu8l/fEHlitgxDkXEf4jGo6PHF9a5U978PYP6
d52aJrzyBetkz45YZUbcL1j/qcUDX6h3rYzfVEH1f80PVZv6Ap/RrJH1BdR/
K/xP2CVf+Lb/5ugZdaTvJnWsXMgX8MfKq+NaiE9OfRZruw9wvOHwVNRB8zS7
vyxW+8DI9+GtCF0UP+M2a5/tA/7cvnQyl5F/zjGjEi4+0BDzltXLCM2nyLQ3
7feBC8EnRdktUfyD/75FDW/gfkZXYGGF/FGs+t123BvGGrsOV91COE1PW5/b
G4JoHx43uYPmXXyV5zToBS3eJUq5dmgf462iRne94KKTmD46YNxcTunCKXdP
4Ilf+hbmju7FnC9O08QTJssbDQc9kB8b7aWqSp4QNm9h6u+N9Fc3xY5vekDb
3Yw7n/3RfXrsqbf39QAt8/2+ZpEobtZ05VmgO/CRxmkqolD94KG3M7fdYfbp
q0fEGMRnmXHWXN0dogYMworikB76j6oLu93hi2Fs4mIy2v8VFxP1JDfIcDHb
r5aK7u/Gwt8ydzd4kHgsLfUx4t8j4OVm6gYc3e2Z556gesGGo+pibqCvvet5
SDbys1fXp+C9KwyJqUXS5qL5O5YS9NmuYPcv4L5XHvLnWfxJsWBXCH6xdfxB
AXr/nT/O9192hT2hipxThWheWFGWv5IrZJm7Ui2L0bwYpSMHRVzhLSe5yrAU
8e8pylRfdQH1aankzjKk19bSd2nUBXoa7rpplCPsXWVb99UFLNLzjZteIj4H
Xwy8/uAC805/FM9Xov5H33lOlLiAl5Yg75sqxL8nX8T0qQswid3YkqlGfi6U
jgnHuEDS9uNfz1+j+Ge/fxcDXED4+/dasRrER1ljbMDVBV6U7cnKfIv4yLw8
M2XnAmdD9PwPvEfvwevnoO8tF2g1i7JM+ID2uXynu/iGCxieblNlBaS/wMXE
y9gF/nAwioXUIbyY8PvfFRd4OKXKQNuA/OdsYLlg4AL/6v0mPBsR3xO3Xpgg
HJH24dNSE9KnpNipc9UFeJw2iuxbULxeu1DWxAXyNRUiJj8iv/PmcrjNXOCk
qLOdZSvSo5pwg3jHBeq2yrUH29D74Ost4HRwAe3euWOG7Wj+c71HWj4u8LP0
CEdnB9JHlyTSHOECd4LvUC59Rfneu+YjnrjA0s287sZOtK87PR4vX7iAv8Lv
ynPdCE9/iFFrdgE2Dv6k19/QexHfc8T0lwukT15zlelFfnAGORPWXECyPsXo
+XcUb2Js197rCq8e95wW60eYoaxWS84VVBw5D2b+QPoKApm5jF3BVCRiMH4Q
9f83nquQ7wpTmx8/sAwhfzppLN53uYJrDzEzeBjxzWK/rkfjBoRSZT+a30hP
XZQqg6wbxAb5WniOImw2uUm2doNDN9+pLP1B84y1k0Qy3aBYfk3E/i+at9tN
7+VPN2iecBi3mETxq768UqbucLmu7OPAFNovIT8Vz3GHkdSZwqszaF5dBefO
jDtsXLp979I8er/epO62cA8IEc7RalxAOGRng2bEA7g3h6TPUdD9mVmNyCp6
wrESY/KJJVSPj6b+WvWEd4FJXcXLyJ8r4m/8bqDvwY3uCtFVpJeLS8r5oxdY
smm58GyguENDQk6hNyyMhxrGbyI+a7j8LkEf8IZmBZZtNG+fSvj+Jz6wK5Xu
QPA/VC8d++0Pny8kP8Q2dnZQflOzX2COL/wPSGyGRw==
           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVVXc8le8bxjlG2VIpsldFRSEa74u+lC1llLJKkpS9HWTvTZSdFRJSGm67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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVVXc8le8bxjlG2VIpsldFRSEa74u+lC1llLJKkpS9HWTvTZSdFRJSGm67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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR
IZkaNKgQaXCnMg+Z6U1Ckumc5zwPEpLf8/tjr70+a6917eu+7r332ipO7oed
hVksVgsz/n9OjbUtUzpAwi+z9pNC1/vAzczZt8aeBP2WuV9uGfVC8XWvmWuR
JDiy/lFSqOgAjnXU7u+xJBBh/nUp/u2gp5BzdUciCU8b+vdI67VBblqXwnAG
CW9N03QfPG2G7Jx9m/cWkbDCMm37t9w6iEFld+FeZt07wN1nfxEcuLSt8OgP
hovOxW0Tz4f5e6xmno6QwEpPOvIo7TGEVUdcdZhg+MXDk+LqyVAyNGVpLy6A
t4Fu2keaMzF/3Nnj1VIBCMLVJ00vvUcZm9FFfy9nmBXCLd5Zhh4vLhTJqAiA
cJRwDZ0uRx3/lD+nVzJcaLLVx74a77MaI+U3MHrKGcU55xowbf6OHB9jAUgF
P/lV6teGM65VZir7BOBx49TyhvXtaFdvLag1FUDSSER3YF87KsSe26JuwegF
xXY07v6E8XL3yppsBZB+QxHmD33GKyoyvevOCUA+ZG6vmEs3rrBOXFbvJYDs
ghNV83K78UXEMhtXjgDuuzrOyI9348Doytr7/oz/qpRQ2ws9aFy+vVAlTADd
YqWAV3tR9IxzxKIUAbRYvqlT4vZh6u2hD89uMfvZgOyXZ324scV99mC6AGqF
OgtrhvrQycDPO/KOADoGOl7Cse9YujDaXuwp4ze30b1kXT/+W/BCd+KDAD6M
Z27pLfyBcoMGZxMqGD292oaYvh/4WOn9vY3VAmD5oUq09AB2htUt8/gogCMt
FhaXTg/g9qO94oOfBJDqtP+hj/QgNl37e2d4J6M3Z3CgZesg/vNuxF/jqwD0
yqs3xJ0YxGStCcGJPgGMJI+90H4yiL9m5n/+jy+A+HdjnkuMhjBGN1b2PCWA
y1wZ1g2XIdT8W+7QkjEBXBiRagi6MoQ2DSvKLCcF4DauGppSN4SFmZue1IpQ
cKPhpt/yg8PoZeIQXCJPwQ7xV9dv649g77RnZMJSCuaZ2GlXWY3goadhCa7L
KWiQqfB38BxBHYXce4rqFBQqjkp8yhnBgaHfNZx1FJTst2vWkeGh9W2pVnNd
Co7ZT7B5a3hYZqnepb6JgszuR+oaRjzMfG0qaNpGQdxPn2NzPXloF5W8eJ0x
BadEfmTWVvGweleukvg+Ci50t6mGdvFw60Tpyi+mFCzX+zf7Pc1DOcdB/asW
FKxUsDnTocDHxg36x3/YUVD7VcnhshMfiX5TlxIHChT36p1I8uJjbrKDe4IT
BdyGiICtIXyMFAm/aHSKAvXGnl162Xw0bm29c9uLgt3jhsrrv/Kx4MpgLodD
getZPzneCB/VDGeKzM9TcF961mLPFB9Z99Srp/+lwON55OnaRSS62+o3N12k
wM1t8b0ZZRK7Fpp15oQw+emOD9drkfiK68W3iaDgaXPHGutdJK7RDp/QuUaB
xBpXV0lzEpN6klniMRREyV/dfcaGRM7+dzIFCRQ4hq/VWHKGxPXLpLdIZVDg
+WbdhFUUiWkN6sSPLAqMDY0OW9wgcUGo/r6SuxTk0c4fJ2+ROMRzsHV9xPgL
NzC0fkTikUyvv4yeMPmkqK6XyCexwjr8rGIeo1cQtturmMRszA2qLKJgTud0
4ZEyEmW8312+/ZKC33fdZjuqSbyo2RbLeUOB4UNdkGwgUdA5mGz+lsn3+re/
JltItI+dyVJ/T0E6GW6X8onEuj3Sj6fLKFh/MGnh+BcSd0ypFzZVMn4IcWd2
L4kKJ80qL9RT8OCmSdjRQRI94yPNVjUy52fkZJzzCInVZbUNdc0U0GYG3M0k
iWoTElbebRRccqsdrKVIDNA0/6T4iYK7hgaJq8dIbDl67XjpZ6b+wFEd858k
al+t6/m7i4ID5tHH9X+RGPZ6gYtkDwUBeVTd8CTTH575UME3pj8SO1efmiZx
s3KUm20/BaqBPLnc3yRGH6qnhQYpcDF7vqNkhsSBi5K+94cpSN2SY3jzD4lE
/oHpA3wKhl6tR5hl+tcXFTQuYPKzlHTIY5iS/SiSOkrBmjsn31AM7zdZeHnX
Two2P33u+4fhTO5BicFfFNR8E6z+xPBUTnRM9DQF/bpn3S4xbPn54+LNfyi4
rkh/mWL2eyQhdbOTRYNr2suFRgyLGh5SChahwXnb+Zu2jD8795iM1eI0xFbb
LtzD+H+e3qDRMIeGu6cWirKY+iSbpB5w5tOwmnlhrjH1u4hY6ChJ0rDBcsPj
kQkSS/Ri895L0VBplBSkzOS3xKVx8z+LaOicrZRYyeTrkSj9SkqOhp2eGt0s
msTKSgsokqchUf1O8FOmPypTse+PL6Vhe0dH0CYeiX5aTSaiy2kAOb5tzBCJ
WlGHD1mo0bDlWFJVVR+JIRjXMqFBg1p/kVNOD4mdgqYjaZo0qA60DDl2kRhl
aXliWJuG7lVBlUfbSewPuf49dj0NDSvZS1ObSYTC5tP6G2moKrps/eIjcx7l
/+cZqk+DGfuk94UKEvfuj/+ptZ0GEYeYfdrvSczwb/FrMqDhXKML73kJiYe7
/hesbERD+qWt5+2ek1iQZRVfbE7Dt+E8k/kZJEq0Jsg7HqJBqFR4Z1YKic7i
baniljTcJ5KSFZn7Jnfa+o7lERoc08JUciJI5OrYFPKcaJDR2qVh4UmiQfGR
DhUuDXsj3F6s3EGi6z+rtIT8aZgT01i6V4/E1KU/A7sDmTxaFvBN15I4HXhd
7XYwDd7jlcETS0ks3lXvtiyahmqHF2sFk3zcVGsktuQuDUomYykVT/mo/VVH
V6KFhqySqaQmCT7axcyEDLfRYJ9HqXwXYt63nbXt1Z9o8D8eqff9Jw+Hs04H
XvnK5PdQzuBJNw9zTmVXig/ToHC2J94rn4catIKDkPAoBE3GAsuah0piYpE/
141CeQ1Rszh2BMOu1PhU6o7CypHa3IyQEeQviHNI3jQKupN7pTW4I1gip7zR
cPsoxP9w0ZRyGEFHza3/hRqPQvZAzOHAtSOYbXpWU/b4KGQe/2L0tWwY18a1
ftgYMQoi4dvkhceGcJvy3RmPvlHYrzXnxzrjQWz1ctlWHTkGjhaaoRGr+3Ft
SbmijdE4iKq6yr8U/YYsI+Pyd7xxMCs9U6jE/A+kb7xc1xL/EzrN1hSdNu3E
r131OxT2T8AqitM6KtuBa5yEZQ1GJ4BfYjO/81UL6n5ujYl/8AvaTPO2y95t
RF/VtOpY+0kQub8sdt+GetyaHfrxrPgU/NHm/UWsqsaipQu4ga+nwC5B2b3d
vRzz6/KHz7hMw1HluJfR/77HMz5TwlHLf8OGXna8fdVbdBze1GHV/BtSDYfn
Gcu8weaUGO5v/xmof37tM8e/GIV3XX3dpvsHwgyLUiJXFmKu6p2a6C9/oFLT
1LnNPx8TG/OT+CGzwPJp5jzSf4bLtz8LIZRYhHcJDC7Uy8Una5JUJ8+xiC11
TTFqlQ9wuezBuJo6FpH3IsbYI/YePnJh9QhWCRHHKvpu/9eWjeetdiaIBQgR
bY8PK7ulZaI6HF6q1y5EpN5xj8gNTscF5bT44bXCRN1FVtyKxFsoW3Ct8V2Q
MNET2i/afCsZp1N/nTX/T5jg23KyDMsTcYXaqHuFjgiBNSpw1z0B1bLfGNlG
iBBOi7T2huteR+d3SwK7vooQ15znlVoejcUyE9eEgo2ihNtiR2otNxpFKmOC
sqNEifgNBZ6TxyLxwvfdH4O/iRI38/Zff/ThCn6eqRQEgBiRML3Hgr87HK0C
TajKm2LE58l0bSm5UJRMtrIR5YsRi61cWmWNgvHOs43RR/eJE+3p3g9/B1xE
P5eMtWlp4sTR9nmHfFkX0O3S3JxNtDhx5kAyPdchEImbOyf6zdhEpFjW3jc1
fmhhPvdheAabKHap2BqXzsUuDeNIoSw24a3mx7dL5KLrn0tn/bPZRPfssrta
UVwMe/J7nfs9NlHVtU2u1Z+LL6UFBdaP2YRaiek7Gxsuqra1lWgUs4m2DOFY
xYVcHLPPbnrfwCY6fAr8L1/0xYtbevINmtiEuXJD+UeuL0pKLU8oamYTH8K1
2hU9fFGzNNHmYRubSD6hS7y290U7taudcZ1sItX0yazWDl8s+3Gu/8QAm2j2
3nzzzQQHD7/Nrfg8yCZWTTnZEiQHu5OG71sNswl7r8tl5f0cnNrnfGYfn01s
KIqO6GrloM6jI4L1Y2xCVubina0FHHwVktD4YJxNaNY5+Hx6yMG9x5vy1CfY
xCvxsa6ALA46SZr5yE+xCadWbW59HAfJ/svWcdNs4pvJgeyACA4GYNkWiRk2
EUornNS5xMG5ScIKYX/YRGFuQ9638xy84QFTs7NMvWb5sannOPh/or4eSA==

           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR
IZkaNKgQaXCnMg+Z6U1Ckumc5zwPEpLf8/tjr70+a6917eu+7r332ipO7oed
hVksVgsz/n9OjbUtUzpAwi+z9pNC1/vAzczZt8aeBP2WuV9uGfVC8XWvmWuR
JDiy/lFSqOgAjnXU7u+xJBBh/nUp/u2gp5BzdUciCU8b+vdI67VBblqXwnAG
CW9N03QfPG2G7Jx9m/cWkbDCMm37t9w6iEFld+FeZt07wN1nfxEcuLSt8OgP
hovOxW0Tz4f5e6xmno6QwEpPOvIo7TGEVUdcdZhg+MXDk+LqyVAyNGVpLy6A
t4Fu2keaMzF/3Nnj1VIBCMLVJ00vvUcZm9FFfy9nmBXCLd5Zhh4vLhTJqAiA
cJRwDZ0uRx3/lD+nVzJcaLLVx74a77MaI+U3MHrKGcU55xowbf6OHB9jAUgF
P/lV6teGM65VZir7BOBx49TyhvXtaFdvLag1FUDSSER3YF87KsSe26JuwegF
xXY07v6E8XL3yppsBZB+QxHmD33GKyoyvevOCUA+ZG6vmEs3rrBOXFbvJYDs
ghNV83K78UXEMhtXjgDuuzrOyI9348Doytr7/oz/qpRQ2ws9aFy+vVAlTADd
YqWAV3tR9IxzxKIUAbRYvqlT4vZh6u2hD89uMfvZgOyXZ324scV99mC6AGqF
OgtrhvrQycDPO/KOADoGOl7Cse9YujDaXuwp4ze30b1kXT/+W/BCd+KDAD6M
Z27pLfyBcoMGZxMqGD292oaYvh/4WOn9vY3VAmD5oUq09AB2htUt8/gogCMt
FhaXTg/g9qO94oOfBJDqtP+hj/QgNl37e2d4J6M3Z3CgZesg/vNuxF/jqwD0
yqs3xJ0YxGStCcGJPgGMJI+90H4yiL9m5n/+jy+A+HdjnkuMhjBGN1b2PCWA
y1wZ1g2XIdT8W+7QkjEBXBiRagi6MoQ2DSvKLCcF4DauGppSN4SFmZue1IpQ
cKPhpt/yg8PoZeIQXCJPwQ7xV9dv649g77RnZMJSCuaZ2GlXWY3goadhCa7L
KWiQqfB38BxBHYXce4rqFBQqjkp8yhnBgaHfNZx1FJTst2vWkeGh9W2pVnNd
Co7ZT7B5a3hYZqnepb6JgszuR+oaRjzMfG0qaNpGQdxPn2NzPXloF5W8eJ0x
BadEfmTWVvGweleukvg+Ci50t6mGdvFw60Tpyi+mFCzX+zf7Pc1DOcdB/asW
FKxUsDnTocDHxg36x3/YUVD7VcnhshMfiX5TlxIHChT36p1I8uJjbrKDe4IT
BdyGiICtIXyMFAm/aHSKAvXGnl162Xw0bm29c9uLgt3jhsrrv/Kx4MpgLodD
getZPzneCB/VDGeKzM9TcF961mLPFB9Z99Srp/+lwON55OnaRSS62+o3N12k
wM1t8b0ZZRK7Fpp15oQw+emOD9drkfiK68W3iaDgaXPHGutdJK7RDp/QuUaB
xBpXV0lzEpN6klniMRREyV/dfcaGRM7+dzIFCRQ4hq/VWHKGxPXLpLdIZVDg
+WbdhFUUiWkN6sSPLAqMDY0OW9wgcUGo/r6SuxTk0c4fJ2+ROMRzsHV9xPgL
NzC0fkTikUyvv4yeMPmkqK6XyCexwjr8rGIeo1cQtturmMRszA2qLKJgTud0
4ZEyEmW8312+/ZKC33fdZjuqSbyo2RbLeUOB4UNdkGwgUdA5mGz+lsn3+re/
JltItI+dyVJ/T0E6GW6X8onEuj3Sj6fLKFh/MGnh+BcSd0ypFzZVMn4IcWd2
L4kKJ80qL9RT8OCmSdjRQRI94yPNVjUy52fkZJzzCInVZbUNdc0U0GYG3M0k
iWoTElbebRRccqsdrKVIDNA0/6T4iYK7hgaJq8dIbDl67XjpZ6b+wFEd858k
al+t6/m7i4ID5tHH9X+RGPZ6gYtkDwUBeVTd8CTTH575UME3pj8SO1efmiZx
s3KUm20/BaqBPLnc3yRGH6qnhQYpcDF7vqNkhsSBi5K+94cpSN2SY3jzD4lE
/oHpA3wKhl6tR5hl+tcXFTQuYPKzlHTIY5iS/SiSOkrBmjsn31AM7zdZeHnX
Two2P33u+4fhTO5BicFfFNR8E6z+xPBUTnRM9DQF/bpn3S4xbPn54+LNfyi4
rkh/mWL2eyQhdbOTRYNr2suFRgyLGh5SChahwXnb+Zu2jD8795iM1eI0xFbb
LtzD+H+e3qDRMIeGu6cWirKY+iSbpB5w5tOwmnlhrjH1u4hY6ChJ0rDBcsPj
kQkSS/Ri895L0VBplBSkzOS3xKVx8z+LaOicrZRYyeTrkSj9SkqOhp2eGt0s
msTKSgsokqchUf1O8FOmPypTse+PL6Vhe0dH0CYeiX5aTSaiy2kAOb5tzBCJ
WlGHD1mo0bDlWFJVVR+JIRjXMqFBg1p/kVNOD4mdgqYjaZo0qA60DDl2kRhl
aXliWJuG7lVBlUfbSewPuf49dj0NDSvZS1ObSYTC5tP6G2moKrps/eIjcx7l
/+cZqk+DGfuk94UKEvfuj/+ptZ0GEYeYfdrvSczwb/FrMqDhXKML73kJiYe7
/hesbERD+qWt5+2ek1iQZRVfbE7Dt+E8k/kZJEq0Jsg7HqJBqFR4Z1YKic7i
baniljTcJ5KSFZn7Jnfa+o7lERoc08JUciJI5OrYFPKcaJDR2qVh4UmiQfGR
DhUuDXsj3F6s3EGi6z+rtIT8aZgT01i6V4/E1KU/A7sDmTxaFvBN15I4HXhd
7XYwDd7jlcETS0ks3lXvtiyahmqHF2sFk3zcVGsktuQuDUomYykVT/mo/VVH
V6KFhqySqaQmCT7axcyEDLfRYJ9HqXwXYt63nbXt1Z9o8D8eqff9Jw+Hs04H
XvnK5PdQzuBJNw9zTmVXig/ToHC2J94rn4catIKDkPAoBE3GAsuah0piYpE/
141CeQ1Rszh2BMOu1PhU6o7CypHa3IyQEeQviHNI3jQKupN7pTW4I1gip7zR
cPsoxP9w0ZRyGEFHza3/hRqPQvZAzOHAtSOYbXpWU/b4KGQe/2L0tWwY18a1
ftgYMQoi4dvkhceGcJvy3RmPvlHYrzXnxzrjQWz1ctlWHTkGjhaaoRGr+3Ft
SbmijdE4iKq6yr8U/YYsI+Pyd7xxMCs9U6jE/A+kb7xc1xL/EzrN1hSdNu3E
r131OxT2T8AqitM6KtuBa5yEZQ1GJ4BfYjO/81UL6n5ujYl/8AvaTPO2y95t
RF/VtOpY+0kQub8sdt+GetyaHfrxrPgU/NHm/UWsqsaipQu4ga+nwC5B2b3d
vRzz6/KHz7hMw1HluJfR/77HMz5TwlHLf8OGXna8fdVbdBze1GHV/BtSDYfn
Gcu8weaUGO5v/xmof37tM8e/GIV3XX3dpvsHwgyLUiJXFmKu6p2a6C9/oFLT
1LnNPx8TG/OT+CGzwPJp5jzSf4bLtz8LIZRYhHcJDC7Uy8Una5JUJ8+xiC11
TTFqlQ9wuezBuJo6FpH3IsbYI/YePnJh9QhWCRHHKvpu/9eWjeetdiaIBQgR
bY8PK7ulZaI6HF6q1y5EpN5xj8gNTscF5bT44bXCRN1FVtyKxFsoW3Ct8V2Q
MNET2i/afCsZp1N/nTX/T5jg23KyDMsTcYXaqHuFjgiBNSpw1z0B1bLfGNlG
iBBOi7T2huteR+d3SwK7vooQ15znlVoejcUyE9eEgo2ihNtiR2otNxpFKmOC
sqNEifgNBZ6TxyLxwvfdH4O/iRI38/Zff/ThCn6eqRQEgBiRML3Hgr87HK0C
TajKm2LE58l0bSm5UJRMtrIR5YsRi61cWmWNgvHOs43RR/eJE+3p3g9/B1xE
P5eMtWlp4sTR9nmHfFkX0O3S3JxNtDhx5kAyPdchEImbOyf6zdhEpFjW3jc1
fmhhPvdheAabKHap2BqXzsUuDeNIoSw24a3mx7dL5KLrn0tn/bPZRPfssrta
UVwMe/J7nfs9NlHVtU2u1Z+LL6UFBdaP2YRaiek7Gxsuqra1lWgUs4m2DOFY
xYVcHLPPbnrfwCY6fAr8L1/0xYtbevINmtiEuXJD+UeuL0pKLU8oamYTH8K1
2hU9fFGzNNHmYRubSD6hS7y290U7taudcZ1sItX0yazWDl8s+3Gu/8QAm2j2
3nzzzQQHD7/Nrfg8yCZWTTnZEiQHu5OG71sNswl7r8tl5f0cnNrnfGYfn01s
KIqO6GrloM6jI4L1Y2xCVubina0FHHwVktD4YJxNaNY5+Hx6yMG9x5vy1CfY
xCvxsa6ALA46SZr5yE+xCadWbW59HAfJ/svWcdNs4pvJgeyACA4GYNkWiRk2
EUornNS5xMG5ScIKYX/YRGFuQ9638xy84QFTs7NMvWb5sannOPh/or4eSA==

           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922122682178133*^9, 3.922122941845788*^9, 3.922123081009536*^9, 
   3.922123260310014*^9, 3.922124789105058*^9, {3.922125699592486*^9, 
   3.922125725291663*^9}, 3.922126570520119*^9, 3.922126671781057*^9, 
   3.9221283632512503`*^9, {3.922128417493479*^9, 3.922128425732784*^9}, 
   3.922135315928055*^9, 3.92213608809898*^9, 3.922137155562039*^9, 
   3.922137279270236*^9, 3.922213625296524*^9},
 CellLabel->
  "Out[3499]=",ExpressionUUID->"0e954208-75c4-4526-af8a-a504906d0558"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MSEValidationLasso", "[", "lambda_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "myfit", "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"myfit", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"lambda", "==", "0"}], ",", "\n", "\t", 
         RowBox[{"Fit", "[", 
          RowBox[{"dataTrain", ",", 
           RowBox[{"functionList", "[", "x", "]"}], ",", "x"}], "]"}], ",", 
         "\[IndentingNewLine]", "\t", 
         RowBox[{"Fit", "[", 
          RowBox[{"dataTrain", ",", 
           RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
           RowBox[{"FitRegularization", "->", 
            RowBox[{"{", 
             RowBox[{"\"\<LASSO\>\"", ",", "lambda"}], "}"}]}]}], "]"}]}], 
        "\n", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Mean", "[", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"myfit", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
            RowBox[{"{", 
             RowBox[{"x", "->", "rValidate"}], "}"}]}], ")"}], "-", 
          "yValidate"}], ")"}], "2"], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"nParamsValidationLasso", "[", "lambda_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "myparams", "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lambda", "==", "0"}], ",", 
       RowBox[{"Return", "[", "nX", "]"}]}], "]"}], ";", "\n", 
     RowBox[{"myparams", "=", " ", 
      RowBox[{"Fit", "[", 
       RowBox[{"dataTrain", ",", 
        RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
        "\"\<BestFitParameters\>\"", ",", 
        RowBox[{"FitRegularization", "->", 
         RowBox[{"{", 
          RowBox[{"\"\<LASSO\>\"", ",", "lambda"}], "}"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Length", "[", 
      RowBox[{"Select", "[", 
       RowBox[{"myparams", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Abs", "[", "#", "]"}], ">", 
           SuperscriptBox["10", 
            RowBox[{"-", "7"}]]}], ")"}], "&"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Code",
 CellChangeTimes->{{3.922119243261956*^9, 3.922119332512197*^9}, {
  3.92212525537693*^9, 3.922125255924914*^9}, {3.922128778511451*^9, 
  3.922128827656794*^9}, {3.922128881019218*^9, 3.922128882189539*^9}, {
  3.922137307871285*^9, 3.922137315291273*^9}, {3.922176115798989*^9, 
  3.922176217267546*^9}, {3.9221762543835506`*^9, 3.922176266008847*^9}, {
  3.9222136327589207`*^9, 3.922213633209227*^9}},
 CellLabel->
  "In[521]:=",ExpressionUUID->"54b085b1-bccb-4084-a6d1-ed263fc4bafb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generate", "[", 
  RowBox[{"10", ",", "100", ",", "100", ",", "100"}], "]"}]], "Input",
 CellChangeTimes->{{3.922128503724788*^9, 3.922128525946734*^9}},
 CellLabel->
  "In[3502]:=",ExpressionUUID->"6744cd1a-2174-40e9-bc2f-8dd6b53ea2d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "100"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   100],
  Editable->False]], "Print",
 CellChangeTimes->{{3.9221285128473997`*^9, 3.92212852663913*^9}, 
   3.922134796723916*^9, 3.9222136501704473`*^9},
 CellLabel->
  "During evaluation of \
In[3502]:=",ExpressionUUID->"ffaba0d8-7e1d-4dc2-98f6-996cf3e4cccc"]
}, Open  ]],

Cell["\<\
Try to identify an appropriate lambda by looking at MSE for validation set\
\>", "Text",
 CellChangeTimes->{{3.922213728912833*^9, 
  3.9222137732242393`*^9}},ExpressionUUID->"3ad2e352-2a38-48cc-be8d-\
4489d41d8927"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<MSE for OLS: \>\"", ",", 
    RowBox[{"MSEValidation", "[", "0", "]"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"MSEValidationLasso", "[", 
      SuperscriptBox["10", "expon"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListLogPlot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Joined", "->", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.922120284354642*^9, 3.922120335897293*^9}, {
   3.922123103389437*^9, 3.9221231376329813`*^9}, {3.922125033012699*^9, 
   3.922125033518644*^9}, {3.922128473111985*^9, 3.922128480389758*^9}, {
   3.92212861879235*^9, 3.922128636604733*^9}, {3.922128672660734*^9, 
   3.922128737170776*^9}, {3.922128856502161*^9, 3.922128898289894*^9}, {
   3.9221289290226183`*^9, 3.922128930922021*^9}, 3.922134651501492*^9, {
   3.922137326417802*^9, 3.922137327880034*^9}, {3.922137374966103*^9, 
   3.9221373787550583`*^9}, {3.922213682520218*^9, 3.922213684761959*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3507]:=",ExpressionUUID->"aef97820-b371-43ca-af0d-e257c6a5b72c"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "100"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   100],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922128481720935*^9, 3.922128531682762*^9, 3.9221287394922953`*^9, 
   3.922128902511836*^9, 3.922128933153825*^9, 3.922134757233074*^9, 
   3.92213479931756*^9, 3.922134978493159*^9, 3.922136109636384*^9, {
   3.92213737981622*^9, 3.922137390370537*^9}, 3.922176073277006*^9, 
   3.922213654354528*^9, 3.922213685467349*^9},
 CellLabel->
  "During evaluation of \
In[3507]:=",ExpressionUUID->"4f3d8b07-732d-49b5-b04d-a5991b0f7764"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MSE for OLS: \"\>", "\[InvisibleSpace]", 
   "6.893747095889087`*^-12"}],
  SequenceForm["MSE for OLS: ", 6.893747095889087*^-12],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922128481720935*^9, 3.922128531682762*^9, 3.9221287394922953`*^9, 
   3.922128902511836*^9, 3.922128933153825*^9, 3.922134757233074*^9, 
   3.92213479931756*^9, 3.922134978493159*^9, 3.922136109636384*^9, {
   3.92213737981622*^9, 3.922137390370537*^9}, 3.922176073277006*^9, 
   3.922213654354528*^9, 3.922213685534628*^9},
 CellLabel->
  "During evaluation of \
In[3507]:=",ExpressionUUID->"8f089455-e43c-40e6-9ac2-30a7eca052e9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0.00014589924716142656`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "0.0020228577545545958`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0.0032421425906485795`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0.004429122146599682`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "0.012724897048369585`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0.01196488480071196`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.9221203249673862`*^9, 3.922120345425477*^9}, {
   3.922123109081856*^9, 3.922123139341893*^9}, 3.922123276837272*^9, 
   3.922124805423234*^9, 3.922125034222176*^9, 3.922125277851454*^9, 
   3.922125735843158*^9, 3.922125865970783*^9, 3.922126731444713*^9, 
   3.922128481951581*^9, 3.922128531773082*^9, 3.922128739641801*^9, 
   3.922128902665716*^9, 3.922128933312818*^9, 3.922134757481391*^9, 
   3.922134799472696*^9, 3.922134978667449*^9, 3.922136111354931*^9, {
   3.922137379956108*^9, 3.922137398123529*^9}, 3.922176082518759*^9, 
   3.9222136710225058`*^9, 3.922213703607463*^9},
 CellLabel->
  "Out[3509]=",ExpressionUUID->"0b4eea42-b016-47bd-899b-df91f0d179f7"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.012833333333333334`], AbsoluteThickness[2], 
         LineBox[{{-6., -8.832594262411654}, {-5., -6.203244037379114}, {-4., \
-5.731520874325982}, {-3., -5.419553875600032}, {-2., -4.364194807079687}, \
{-1., -4.425779185690552}}]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             
             Line[{{-6., -8.832594262411654}, {-5., -6.203244037379114}, \
{-4., -5.731520874325982}, {-3., -5.419553875600032}, {-2., \
-4.364194807079687}, {-1., -4.425779185690552}}]}, 
            "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-6., 
               0}, {-9.182271878091736, -4.364194807079687}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, -9.182271878091736}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[0.012833333333333334`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
            "Primitives" -> {}, "GCFlag" -> False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLogPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-6., 
              0}, {-9.182271878091736, -4.364194807079687}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, -9.182271878091736}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
           "Primitives" -> {}, "GCFlag" -> False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLogPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[{{-6., -8.832594262411654}, {-5., -6.203244037379114}, {-4., \
-5.731520874325982}, {-3., -5.419553875600032}, {-2., -4.364194807079687}, \
{-1., -4.425779185690552}}]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-6., 0}, {-9.182271878091736, -4.364194807079687}}, 
        "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0, -9.182271878091736}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
        "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLogPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -9.182271878091736},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentSet", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{-6., 0}, {-9.182271878091736, -4.364194807079687}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0]}, {
    Automatic, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
          TemplateBox[{"10", 
            RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
       0.}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
          TemplateBox[{"10", 
            RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
       0.}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.005\"", ShowStringCharacters -> False], 
          0.005`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.010\"", ShowStringCharacters -> False], 
          0.01`15.954589770191003, AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.819778284410283`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.41431317630212, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-10.126631103850338`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.903487552536127, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.721165995742174, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.567015315914915, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.433483923290392, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.315700887634009, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{{3.9221203249673862`*^9, 3.922120345425477*^9}, {
   3.922123109081856*^9, 3.922123139341893*^9}, 3.922123276837272*^9, 
   3.922124805423234*^9, 3.922125034222176*^9, 3.922125277851454*^9, 
   3.922125735843158*^9, 3.922125865970783*^9, 3.922126731444713*^9, 
   3.922128481951581*^9, 3.922128531773082*^9, 3.922128739641801*^9, 
   3.922128902665716*^9, 3.922128933312818*^9, 3.922134757481391*^9, 
   3.922134799472696*^9, 3.922134978667449*^9, 3.922136111354931*^9, {
   3.922137379956108*^9, 3.922137398123529*^9}, 3.922176082518759*^9, 
   3.9222136710225058`*^9, 3.922213703749597*^9},
 CellLabel->
  "Out[3510]=",ExpressionUUID->"838d3bf4-fea4-43c8-be05-133c0765579c"]
}, Open  ]],

Cell["Plot number of parameters vs lamba for Lasso", "Text",
 CellChangeTimes->{{3.922176350938534*^9, 
  3.922176363187677*^9}},ExpressionUUID->"0fb3b5f0-af04-4eb8-8268-\
9d4de5a60dee"],

Cell[CellGroupData[{

Cell[BoxData[{"printParams", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<params for OLS: \>\"", ",", 
    RowBox[{"nParamsValidationLasso", "[", "0", "]"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"nParamsValidationLasso", "[", 
      SuperscriptBox["10", "expon"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"expon", ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListLogPlot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Joined", "->", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.922120284354642*^9, 3.922120335897293*^9}, {
   3.922123103389437*^9, 3.9221231376329813`*^9}, {3.922125033012699*^9, 
   3.922125033518644*^9}, {3.922128473111985*^9, 3.922128480389758*^9}, {
   3.92212861879235*^9, 3.922128636604733*^9}, {3.922128672660734*^9, 
   3.922128737170776*^9}, {3.922128856502161*^9, 3.922128898289894*^9}, {
   3.9221289290226183`*^9, 3.922128930922021*^9}, 3.922134651501492*^9, {
   3.922137326417802*^9, 3.922137327880034*^9}, {3.922137374966103*^9, 
   3.9221373787550583`*^9}, {3.922176366616608*^9, 3.922176383680645*^9}, {
   3.92221380396574*^9, 3.922213805706069*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3515]:=",ExpressionUUID->"8be18d89-7e86-46f2-8643-3cee1b926a0b"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", 
   "100"}],
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   100],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922176386584496*^9, {3.922213783374269*^9, 3.922213806703233*^9}},
 CellLabel->
  "During evaluation of \
In[3515]:=",ExpressionUUID->"01284a8c-610b-4a57-a588-6769f4ee5a5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"params for OLS: \"\>", "\[InvisibleSpace]", "100"}],
  SequenceForm["params for OLS: ", 100],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922176386584496*^9, {3.922213783374269*^9, 3.922213806787827*^9}},
 CellLabel->
  "During evaluation of \
In[3515]:=",ExpressionUUID->"115eacc5-6935-4938-95be-c1a28dbba0c0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "11"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.922176394475387*^9, {3.922213799924539*^9, 3.922213823645265*^9}},
 CellLabel->
  "Out[3517]=",ExpressionUUID->"36cc54a8-c82c-41ee-bc52-53eabee73d54"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.012833333333333334`], AbsoluteThickness[2], 
         LineBox[{{-6., 2.833213344056216}, {-5., 2.995732273553991}, {-4., 
          2.70805020110221}, {-3., 2.5649493574615367`}, {-2., 
          2.1972245773362196`}, {-1., 2.3978952727983707`}}]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             
             Line[{{-6., 2.833213344056216}, {-5., 2.995732273553991}, {-4., 
              2.70805020110221}, {-3., 2.5649493574615367`}, {-2., 
              2.1972245773362196`}, {-1., 2.3978952727983707`}}]}, 
            "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-6., 0}, {2.1347368185521582`, 
              2.995732273553991}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, 2.1347368185521582`}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[0.012833333333333334`], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
            "Primitives" -> {}, "GCFlag" -> False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLogPlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-6., 0}, {2.1347368185521582`, 
             2.995732273553991}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0, 2.1347368185521582`}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.012833333333333334`], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
           "Primitives" -> {}, "GCFlag" -> False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLogPlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[{{-6., 2.833213344056216}, {-5., 2.995732273553991}, {-4., 
          2.70805020110221}, {-3., 2.5649493574615367`}, {-2., 
          2.1972245773362196`}, {-1., 2.3978952727983707`}}]}, 
        "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-6., 0}, {2.1347368185521582`, 2.995732273553991}}, 
        "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0, 2.1347368185521582`}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.012833333333333334`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {Log, Exp}}|>, 
        "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLogPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 2.1347368185521582`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentSet", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{-6., 0}, {2.1347368185521582`, 2.995732273553991}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      15.954589770191003`, RotateLabel -> 0]}, {
    Automatic, {{2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}}, {2.4849066497880004`, 
       FormBox["12", TraditionalForm], {0.01, 0.}}, {2.70805020110221, 
       FormBox["15", TraditionalForm], {0.01, 0.}}, {2.8903717578961645`, 
       FormBox["18", TraditionalForm], {0.01, 0.}}, {2.995732273553991, 
       FormBox["20", TraditionalForm], {0.01, 0.}}, {2.0794415416798357`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1400661634962708`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.2512917986064953`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.3513752571634776`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.3978952727983707`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.4423470353692043`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.5649493574615367`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.6390573296152584`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.772588722239781, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.833213344056216, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.917770732084279, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.9444389791664403`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.970414465569701, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.0204248861443626`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.044522437723423, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.068052935133617, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.091042453358316, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{
  3.922176394475387*^9, {3.922213799924539*^9, 3.922213823766605*^9}},
 CellLabel->
  "Out[3518]=",ExpressionUUID->"93579492-4eb8-4776-a229-80e4a06f2537"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mmaFitRidge", "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataTrain", ",", 
     RowBox[{"functionList", "[", "x", "]"}], ",", "x", ",", 
     RowBox[{"FitRegularization", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Tikhonov\>\"", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "16.3"}]]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ridgeMmaPlot", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "rmin", ",", "rmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "11"}], "/", "10"}], ",", 
        RowBox[{"2", "/", "10"}]}], "}"}]}], ",", 
     RowBox[{"WorkingPrecision", "->", "wp"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"ridgeMmaPlot", ",", "LJplot"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MeanRidgeMmaTest", "=", 
  RowBox[{"Mean", "[", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"mmaFitRidge", "*", "yTrainStdev"}], "+", "yTrainMean"}], "/.", 
        RowBox[{"{", 
         RowBox[{"x", "->", "rTest"}], "}"}]}], ")"}], "-", "yTest"}], ")"}], 
    "2"], "]"}]}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.922113801564647*^9, 3.922113822719157*^9}, {
   3.922113853302573*^9, 3.922113858050037*^9}, {3.922113892535127*^9, 
   3.9221139368300343`*^9}, {3.922118337105389*^9, 3.922118339072853*^9}, {
   3.922118458221966*^9, 3.922118493620129*^9}, {3.922118540709791*^9, 
   3.922118586838917*^9}, {3.922119172828432*^9, 3.9221191803820543`*^9}, {
   3.922120424797739*^9, 3.922120447099926*^9}, 3.922120706798108*^9, {
   3.922126066787107*^9, 3.9221260886688433`*^9}, {3.9221267944673038`*^9, 
   3.92212679639928*^9}, {3.922213797396077*^9, 3.922213797844245*^9}, {
   3.922213836407323*^9, 3.922213836789312*^9}},
 Background->RGBColor[0.87, 0.94, 1],
 CellLabel->
  "In[3523]:=",ExpressionUUID->"3525025a-e85d-4e1f-bf66-760c776d5eeb"],

Cell[BoxData[
 GraphicsBox[{
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVVAk0lVsblumrbjgkUuhWNBsioXL3h4bboAwZugrVRYOi5BxzyZSSKRok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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVVAk0lVsblumrbjgkUuhWNBsioXL3h4bboAwZugrVRYOi5BxzyZSSKRok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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
             0.2}}, "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
            0.2}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwVVAk0lVsblumrbjgkUuhWNBsioXL3h4bboAwZugrVRYOi5BxzyZSSKRok
ZSgUUkml9IaUe8hMk5lwOOd8w8k8/d+/19prr2ftd3yed+/lxzytXcXFxMR6
mP3/k2aldfZ/IFDynf+v/1AcLPMU7ybQdeWZkSKTV2j/5S1Fh/oJVOI0l9Yb
f47+2GE7XcAn0NWfIe6KYXkognv1mvMogdgOn2sF/Dvo/eCEjZM0id5f7cx3
INPhxbCr19ulJIqg1c43RpWDgr1oobs6iR5EaJ9HuyvA6/WlVwrLSbREmX6C
SXwG7YC7MydXkSja+gqH58qFbLH66MUbSeQ4kLZ1t08dpP6xLcdnJ4myBRqh
M0EtMO3x377lu0kUHqjoM6X/FQ7X2JHVe0n0rFce3en/Cirx5ww1rEi08Gir
4n+7vkOiUlZFgyOJNj6er/ec/xOilit065wj0eZ8vbVTbp3wp90t1RpvElm0
5hT/zu+E11dV7T3YjP9ps3Mjw50wIFpVnR1AIq/IvKRlIV2w89PWouURJHo7
MdfsQHQ3SJ52vbrwLolu6Kj6mPv2Qsr9wY/P7pFoudpB3+FnvaDf5Dl74AGJ
DkrqdLUM9sIxE/8L0Q9JdLYzJ033n19QKhfrJFVAouEPgU0BOn0QXPhab/Qj
iXwj2nr+KuoHJZ7JmaTPJHJwQOu6e/ohT608S59LIqHnPMdm1gC0RnxR9aol
kVxxGe/5iQHYeqhbmvedRGKDD58FsXjQcN3dNLKVRKq/bhxvNOLBqTJ+gGYH
iaz8+C6RLjxIXj9KHu0l0ZHRcSX5fB6MTf/x84eQRMbBTid/mA5CnF78Ij+K
RAlqeKyV6yCscVeyVP5NIrc/PEw3XRkE+7o/K2zGSRRzPiDZrHoQitINnlZL
UChkvuOpfIsh8N7lHPp+MYX8swz4coZ86J48H520lEJ6hTUfNx/kg2VBRJKH
OoWE8t+fcr34oK2Sn7VEg0JuCm4JeDYfBganqtg6FGpKbLO+wRKA3X1Ws4Ue
hWymXj22WiuAChuNdg0DCt20Htx+1VQA6e/2kg1bKPTPjgshXl4COByTrKiz
k0LOunWCrZUC4Jrlq0nvptDirqE9o60CMB4tXdW2l0LXCv+dMqIEoOTCM7pm
RaGXhqJFtouFUL/R6Ej/YQrpXg6xUz4qBLxvr9t7Zwrlxp56tOG8EPKTnT2T
jlHIL8PYvvGyEKIlIkPMT1BoQEpD5Ue6EHY2Nz+8702h/fmEGNUmhMIoXj6b
TaGrC7bZvhwSwsq/pl9Z+FEoUotYvWhcCGJZGtzJYArNiRUq5ioQ4Olo1NgQ
QqErT2eif6kT0C63rzUnjEKZ5UsQrCPgra+30P4qw8eL9gF7UwLWaUWOal9n
+HDboqGyj4DbXcli0nEUGn+5cPlFOwLYe8oUCpMoRIvWfTQ5RYCuqrwhK41C
31RNP2dcJyC1TgPvz6DQhd+q23KSCJAJN9r9/hGF3pSICR3vETAocHb0yKWQ
5X5juS9PCHBI9/7X/Cnjb/bW//pzAj7bRZ5Z8pxCn+qyl86+JiAT8i9WvqLQ
CvmZr+MfCVC4UHblfjGF6k2rv4dxCQhZ0xLPLqFQo21P28daAshWXrLFBwrN
c+ivK24iwCl+OkOjnEK8u7wU9+8EfNkhnzdZQSG5y15rq9sI2DahUdRQSSGk
FO7I6yJA5fi+yks1FPo8NWhoxSPgfGL0vtX1FHqr6uXqzieAW1Fd96WRQj2R
EyfMCAJWji6wvdBCobxyaVE3RUDgGovvS75TqHQ+/nz3bwKaDl0/UvqTQrNP
bthwRgjQuvaly72dQlX3Nl72GCMg4p2Mm2wXhQ5pXelfO8HoI7AYLOxhcL3N
+oJJAjYviznr2MfYf0gTzU4REGtZQ8/hUWhatqpXZYaAgRBZTvYQY58dmTbD
YPzF/sn9QqaeOYPc/FlGv96Yi8MkhSrHtC8tEiOBWlQrkSKi0KaBTsKYwXt2
yV0xG6HQ1uIs8R0MTvc9sIA3xtRb9FPKkMETObFxsZMUSrGcu5PFYJuftYqb
Zxg9MZFaOhM/dwHrTqsYjTbmeNiLmPySf1mqhUrQ6NyueV8UGXzYMy5trTSN
ZNKa5bFpAl4+qNOsm0sjUeqRV1ymP9kG1mP2HzRKoj9YuDD9u0lYaavJ0iij
NPd4JcPP+03xz8tZNLr+wy5CYpQAZbf6zacWMvnOx5oqDBPgdUv+LUuJRsYF
H5cN0wRUVlqhV4tpFCAjysklCVg+EV9+ZCmN3LFP7sZCAvzXN+ySVKdRaFF4
x90hAtbHWFtaraRRlIq+XO8vAsIgoWlUk0YX0+Z/4XYT0Eo2OKSuodEy6weW
UR0ExNjYHB3SolEO/+Kj2G8E9IXd+BWvS6Os40cufGPmDRU1njTSp9EZDbXZ
iTpmHhcfPB9uRCP9uUWbaisJ+HtP4sj6rTR6+XJjfQgzz2kBTf4NJjTaVNgl
w/pAgHX7wdBl5jTCq2ZMSosIKMywTXxjQaNR4SOF0HQCFjQnLXaxpNGBzQXW
y5j35CrdkiJtQyMFb53S5FsEKJ20e2jjQKNLjq4/daMJ8NW2LxIco5GTy7KH
v7wJMHnj8G25L9OfRPaqKhMCPE6tXj8ngEZ5uk8chQYEpCwdCeoMYrDgIofW
ImAy6MbK+6EMP5Ss8X01At6Y1ZxVjaVR4+UU71uTQjCoNpdSfkQjqW2B5sef
C0GrQ1tvQRONCkTZmrqyQjgcNx021MLoLZay10SC+d9Mq79yv9No5qFTo+GY
AIYyTgZFddDogl6m9UiXAHJOZFZKD9Ho7FhgX1qhADRpFec54iKkmBWiP2on
ADUpqegRHRGa76Ucez2eDxFRVT6VeiKkIRXkoBDOB6FMgnOygQgVytWkXPfl
w3ulZfp/bRUhYgnX84QzH1zWGP8I3ylCHeoY6+UGPmTuPbNm0REROjnXu7ql
Ygg2JDR/1L8qQi+n+QdDRYOwZdmjaa9exr6MllTawYNmb7ct3OjfKDaTMq1c
0wcb3n9aYm8+jGxbTvtYSfWAmPnOT2WCYdTjJH1wvnsnyN8s1mlKHEGXtuND
j/e2Qkd7zTaVPaOodviFQrDiN1h3THyRiWgU3a3O8ckrbgK9n81xiY/HUN7A
5fWJj+qBsyKVG+80jsQ2pLpM6deAcWZ47RnpCfTtZEbJxjVceLVUxjfo3QQq
E7Am9M98ghdfXgyddptEE1jOJQv/cjjtMyEeoz6F/nGwnS/49AFchgy+2TZO
Ic1Lb7f8UiyBxrtxvlMB0yhD/I7MgtA3IG527V2L3gwq1JB6VaRVBPkrHlbF
ts2gmT0hhw8Gv4Bb9S9uC8Nm0ex+rbBtm5+B+tZnYbiaGH5ua8Dn6nX58HTd
7RXj58RwIy67XrnsMagvOpBQ9UUMp3zuxtQnZEGum1gXuXoO/kDVvrG2LRP8
bE2TpALn4CYG/PMaj9JBA1kv3fR1Dm5UaAqzkQ9A5hMtbb1BHI/eoFS19dY9
WFR4vb7soji+pf9NbOvtZJhMGTtj8UMcX9AnkC4qvQV/rhR5ftaWwJ26pNpW
eybByswSc8erEjj/oG6N3OYb4FqmHNTeIYFPhCWlRx2Jh4pdHkmF+pL4mX8v
nQoJjAWJyriLmTGSOOdOUtmTQ9Fw6df22tAeSfz0u1M9cqVR8HO6kgxEUrjt
W4vgW2aRYBu0i6q8I4UvTdLLt1AKB9lkW3tJoRSu+fr3hsztofDwmX7sod3S
+NKxKkk8KAT83dI2pKZK42Sn5a2WiYtw9vK8HANaGvcqvze2+VAQ4HdMR/v2
YXi6eslQ4ld/YL1m+Rvvx/DC6QS/1zX+0NnSMXXtAIafWG3c11bhDyGKweIb
rTF8rr7hiFahP5TFFssE2GP4Ftcgzc44f9geoa8hdwzDP+3K4Pns8Ye/vTWt
DDkYrq1R2FhQ4geLE343RvlieMuuCy7thX4wUFBu1+qH4QM1q/Pn5/pBlPDo
4ZBADN/Pd7dwTvYD7slU96oQJj6OPx1h+8E+F+Vg52gM7/5qy2vQ8QMri3lP
ItMw/OwHOsP4gS+0a+6MnpOB4ZtMqj3X3PQFj5nLZwIyMXwdHhKpFO0LEU+n
dDyzGPslGoUUxxeK5clCuzwM3xbVnZd7wBdWtLS813yD4QmTmpviZznwNH/h
g/vFGC7LJZzThzmwLdIyROUdhn+w7N5ePMQBOyOuuQxg+Py1B8znfOPAteSS
yt8fMbyA4tyXeMaB306ZDeV1GP56Ou1MiSsHQgy7Xpg0YDhf33Jz3mEOyLLU
k141Mv2OjLu8tOHAmtJb9k9aMHzw5C+DRWYcOLzyWmtCK4Zb13udMP+TA7zJ
zyUL2jEcv1xqtmoxB9hNkvcjOjB85LSssi6LA3HhwUf9uzHc/46SR6kYByr6
z/UdHcDwuhiJStVeNlh/yP/8k4fhKTZdA75tbOi8PZRtO4Thf3ubV8p9ZcPE
btfTu4UYnjhbfXGcy4bIFen7ygkM97iX52VdwQbFyXYtE4rR492bf2hgg3au
A6n7m+H7YJavYhEb3oYl1T8exnAWyyv73jM2/H2k4bnGKIb/O9lTHZDHhmYD
ucTUMQzPDWY9fp7DhmOy+3wWT2C40s1k3Z2P2ED0XbFLmGT0cS9w35LBhkCo
MFwwjeH7qiKDbjxgw7zb4ioRM8x8rd9dZpvKhpteaGJ2lrnXG34UnsKG/wFi
1Jv6
           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1.1, 
         0.2}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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               "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
             0.6429449987430464}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0.9000000428571449, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               AbsoluteThickness[2], 
               RGBColor[0, 1, 0], 
               Dashing[{Small, Small}]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
            0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}},
            "AxesOrigin" -> {0.9000000428571449, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0], 
              Dashing[{Small, Small}]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlnk0ld37xo/xNEgoQkmmUqKSSgP3U4oKlXxREdLLW29ChuNkeFWmkkwR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           "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{0.9000000428571429, 2.9999999571428573`}, {-1., 
         0.6429449987430464}}, "Frame" -> {{False, False}, {False, False}}, 
        "AxesOrigin" -> {0.9000000428571449, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[2], 
           RGBColor[0, 1, 0], 
           Dashing[{Small, Small}]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9000000428571449, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9000000428571429, 2.9999999571428573`}, {-1.1, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.922126090720031*^9, 3.922126798535335*^9, {3.9222138320727577`*^9, 
   3.922213837651637*^9}},
 CellLabel->
  "Out[3525]=",ExpressionUUID->"16d4a813-518e-45f7-99b5-5e60af0a5531"],

Cell[BoxData["1.794983786428547`*^-8"], "Output",
 CellChangeTimes->{
  3.922126090720031*^9, 3.922126798535335*^9, {3.9222138320727577`*^9, 
   3.922213837840818*^9}},
 CellLabel->
  "Out[3526]=",ExpressionUUID->"e6c68a29-0402-4b04-9a57-5403937c09fc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lasso-LARS", "Section",
 CellChangeTimes->{{3.9221913080589523`*^9, 
  3.922191312587179*^9}},ExpressionUUID->"6202bcfc-a983-4aca-8e35-\
40a78811fa40"],

Cell["\<\
Attempt to implement the Lasso-LARS algorithm described in Sec. 2 of Efron et \
al. The Annals of Statistics, 2004, Vol. 32, No. 2, 407\[Dash]499
This is incomplete and does not yet work.\
\>", "Text",
 CellChangeTimes->{{3.9222116024978848`*^9, 
  3.922211675546297*^9}},ExpressionUUID->"68ec75cd-a745-44a9-a48e-\
a4bc322c9d90"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wp", "=", "MachinePrecision"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"generate", "[", 
  RowBox[{"5", ",", "10", ",", "5", ",", "5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9221913717575397`*^9, 3.922191387252143*^9}, {
  3.922193568523635*^9, 3.922193590354113*^9}},
 CellLabel->
  "In[2804]:=",ExpressionUUID->"44be5302-bf35-4094-85bd-bd083720d316"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", "1.1102230246251566`*^-17"}]], "Print",
 CellChangeTimes->{
  3.922191387882412*^9, 3.922193442354336*^9, 3.92219352161946*^9, {
   3.92219356979408*^9, 3.922193591171216*^9}},
 CellLabel->
  "During evaluation of \
In[2804]:=",ExpressionUUID->"e261a5f2-348a-44ac-b362-2cfd58506086"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm[
  "nTrain: ", 10, ", nValidate: ", 5, ", nTest: ", 5, "\nnGaussians: ", 25],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.922191387882412*^9, 3.922193442354336*^9, 3.92219352161946*^9, {
   3.92219356979408*^9, 3.922193591262229*^9}},
 CellLabel->
  "During evaluation of \
In[2804]:=",ExpressionUUID->"cee26893-70c1-42c5-b2de-f5038a7f1875"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wA", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "nX"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yhat", "=", 
   RowBox[{"X", ".", "wA"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "=", 
    RowBox[{"Transpose", "@", 
     RowBox[{"functionList", "[", "rTrain", "]"}]}]}], ";"}], " "}]}], "Input",\

 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQrRKWV/rX4q3jhAzhKhCtsGZWPYi2qeZrBtF8UW09
INrfcAKYjj20ZiaIXnqbeRaIViuZtgBEyyltXQii6zoOHWewfOsYcdj1HIiW
umR/GUT7HTK7B6JfXznKxAikLZ17mEF070M+CRCtuKBfBkRrbPXXAtERdmE6
IPq/aJwpiJ7r+cAcRLtstLMF0QaLa9xA9P2DU31AtOvOt/4geu/lh8Fg8Uth
YSCac3lXEojOvLYxHURnJPzLBtEzRHmLQfQ37rxaEP3Elr0TzGcwnwiip/IU
zQTRv33K54Jo3f2S80B0ybH910B09g7xWyB6zc0nnExAOqvkFDeIDmkWEgDR
S9olhUE0AEOMmo8=
  "],
 CellLabel->
  "In[3143]:=",ExpressionUUID->"c6171874-df8e-4847-9d93-edf6f6b2bb71"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"c", "=", 
  RowBox[{
   RowBox[{"Transpose", "[", "X", "]"}], ".", 
   RowBox[{"(", 
    RowBox[{"yTrain", "-", "yhat"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Chat", "=", 
  RowBox[{"TakeLargest", "[", 
   RowBox[{
    RowBox[{"Abs", "[", "c", "]"}], ",", "k"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Chatj", "=", 
  RowBox[{"TakeLargest", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "c", "]"}], "->", "\"\<Index\>\""}], ",", "k"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"svec", "=", 
  RowBox[{"Sign", "[", "c", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"XA", "=", 
   RowBox[{"X", ".", 
    RowBox[{"DiagonalMatrix", "[", "svec", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"XA", "=", 
  RowBox[{"XA", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "Chatj"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GA", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "XA", "]"}], ".", "XA"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"oneA", "=", 
   RowBox[{"Transpose", "@", 
    RowBox[{"{", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{"1", ",", "k"}], "]"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"AA", "=", 
  RowBox[{"1", "/", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", "oneA", "]"}], ".", 
      RowBox[{"Inverse", "[", "GA", "]"}], ".", "oneA"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"WA", "=", 
  RowBox[{"AA", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", "GA", "]"}], ".", 
    "oneA"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"uA", "=", 
  RowBox[{"Normalize", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"XA", ".", "WA"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"a", "=", 
  RowBox[{
   RowBox[{"Transpose", "[", "X", "]"}], ".", "uA"}]}], "\[IndentingNewLine]", 
 RowBox[{"gammaVec", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Max", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Max", "@", "Chat"}], "-", 
        RowBox[{"c", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], 
       RowBox[{"AA", "-", 
        RowBox[{"a", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"Max", "@", "Chat"}], "+", 
        RowBox[{"c", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], 
       RowBox[{"AA", "-", 
        RowBox[{"a", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "Chatj"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gamma", "=", 
  RowBox[{"Min", "[", "gammaVec", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"yhat", " ", "=", " ", 
  RowBox[{"yhat", "+", 
   RowBox[{"gamma", " ", "uA"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.922202792711239*^9, 3.922202798844736*^9}},
 CellLabel->
  "In[3162]:=",ExpressionUUID->"68b613fb-1c27-4221-928f-586b28ed6d96"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.10975657350254846`"}], ",", 
   RowBox[{"-", "0.3543184555329493`"}], ",", "0.010517728355852546`", ",", 
   "0.12402219165025088`", ",", "0.1618128403604756`", ",", 
   "2.463307335887066`*^-16", ",", "0.31491637819933666`", ",", 
   "0.3487600843803789`", ",", "0.3425163200124911`", ",", 
   "0.33827531758547524`", ",", "0.49435868190754817`", ",", 
   "0.7618102285158299`", ",", "0.6771044690034334`", ",", 
   "0.6489840523188531`", ",", "0.6377533761325526`", ",", 
   RowBox[{"-", "0.15968066318504157`"}], ",", 
   RowBox[{"-", "0.17479747994124217`"}], ",", "0.1132705610141527`", ",", 
   "0.18541029667958184`", ",", "0.20985488833437982`", ",", 
   RowBox[{"-", "0.10975657336598281`"}], ",", 
   RowBox[{"-", "0.3215474085109228`"}], ",", 
   RowBox[{"-", "0.16514088988625772`"}], ",", 
   RowBox[{"-", "0.03196794744964393`"}], ",", "0.02606503843623717`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.92220279994207*^9}},
 CellLabel->
  "Out[3163]=",ExpressionUUID->"0c0f2f9e-46bb-4099-ba3c-00d25b651057"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.7618102285158299`", ",", "0.6771044690034334`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800065914*^9}},
 CellLabel->
  "Out[3164]=",ExpressionUUID->"0f8056a6-af20-40f8-b1e2-cdad552c591b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12", ",", "13"}], "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800145129*^9}},
 CellLabel->
  "Out[3165]=",ExpressionUUID->"b5b1e17a-1e06-4184-a712-59e759739c09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}], ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800252708*^9}},
 CellLabel->
  "Out[3166]=",ExpressionUUID->"14941564-965c-4354-9c54-58005e01c1eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07248507432472398`"}], ",", "0.05312430722973858`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.08994228152794209`"}], ",", "0.03706486021946302`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.518856146445949`", ",", "0.47330450656584266`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21591117411852967`", ",", "0.28215115194583656`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.475748262642422`", ",", "0.4483101486458123`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.1421268132195689`"}], ",", 
     RowBox[{"-", "0.01293089509419941`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.685073581867877`", ",", "0.5642346286500068`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.09761617335684543`"}], ",", "0.029904188120438213`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.22513047812023523`"}], ",", 
     RowBox[{"-", "0.0996118344065116`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2718985000723321`", ",", "0.3205104461283548`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800352161*^9}},
 CellLabel->
  "Out[3168]=",ExpressionUUID->"f023f908-f49f-459c-9cfb-f2103e322da6"],

Cell[BoxData["0.9478173902519001`"], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800466896*^9}},
 CellLabel->
  "Out[3171]=",ExpressionUUID->"d74ab9a5-c2df-47a5-a90f-4e57c6208ad9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"-", "0.6720293098025876`"}], "}"}], ",", 
   RowBox[{"{", "1.7270848619424692`", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800566709*^9}},
 CellLabel->
  "Out[3172]=",ExpressionUUID->"53caf9ec-6f47-47c4-aca6-938c2aef76c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.14046228128709592`", ",", "0.1244580083723412`", ",", 
   "0.4687505103961156`", ",", "0.34220034598374205`", ",", 
   "0.45455289459799375`", ",", "0.07318063102383024`", ",", 
   "0.5140915593385017`", ",", "0.11724800021805926`", ",", 
   RowBox[{"-", "0.020743811447137956`"}], ",", "0.3708249782627407`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800690097*^9}},
 CellLabel->
  "Out[3173]=",ExpressionUUID->"00b12884-a869-4209-b732-525b53ee2e82"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.27695875611974824`"}], ",", 
   RowBox[{"-", "0.05783962011645361`"}], ",", "0.5586543198022953`", ",", 
   "0.6989542742905825`", ",", "0.736673649681657`", ",", 
   "0.5338996188532256`", ",", "1.12674461687566`", ",", 
   "1.0297595021960888`", ",", "0.9767046641227701`", ",", 
   "0.9530789040229384`", ",", "0.5917343995558204`", ",", 
   "0.9478173902518996`", ",", "0.9478173902518998`", ",", 
   "0.9372783862509464`", ",", "0.9322547508479198`", ",", 
   RowBox[{"-", "0.40293675809099294`"}], ",", 
   RowBox[{"-", "0.8018899791405588`"}], ",", 
   RowBox[{"-", "0.361726593367959`"}], ",", 
   RowBox[{"-", "0.20932336356939574`"}], ",", 
   RowBox[{"-", "0.1501681783885659`"}], ",", 
   RowBox[{"-", "0.27695875611448617`"}], ",", 
   RowBox[{"-", "0.8439286664525728`"}], ",", 
   RowBox[{"-", "0.7512281880962833`"}], ",", 
   RowBox[{"-", "0.5575706920059509`"}], ",", 
   RowBox[{"-", "0.458836663510423`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800838058*^9}},
 CellLabel->
  "Out[3174]=",ExpressionUUID->"232f2726-2570-414f-8641-8aa3e34f89ba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.7447106090167395`*^15", ",", "4.3201971303771225`*^15"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800914219*^9}},
 CellLabel->
  "Out[3175]=",ExpressionUUID->"d122d0b0-4521-468e-ac55-3f52a9927039"],

Cell[BoxData["2.7447106090167395`*^15"], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.922202800986601*^9}},
 CellLabel->
  "Out[3176]=",ExpressionUUID->"d9db2bff-7972-410f-8782-1e71d7f31b49"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.855283136153853`*^14", ",", "3.416012159566588`*^14", ",", 
   "1.28658449886623`*^15", ",", "9.392409200307756`*^14", ",", 
   "1.2476161521623812`*^15", ",", "2.0085965434564622`*^14", ",", 
   "1.4110325569223442`*^15", ",", "3.21811830084504`*^14", ",", 
   RowBox[{"-", "5.6935759350402484`*^13"}], ",", "1.0178072519261461`*^15"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.922193361991456*^9, {3.922193410482202*^9, 3.922193448304729*^9}, {
   3.922193514219475*^9, 3.922193524605735*^9}, {3.9221935729717073`*^9, 
   3.922193616759684*^9}, 3.922200180543297*^9, {3.922200273175861*^9, 
   3.92220030762351*^9}, 3.922200605974369*^9, {3.92220079131183*^9, 
   3.922200799390848*^9}, 3.9222009320235767`*^9, 3.922201115495925*^9, 
   3.922201268408721*^9, {3.922201383379561*^9, 3.922201411650217*^9}, {
   3.922201454527948*^9, 3.922201481625959*^9}, {3.9222016054118958`*^9, 
   3.922201619619212*^9}, 3.922201804471909*^9, 3.922201843110643*^9, {
   3.922202297406663*^9, 3.922202321662724*^9}, 3.9222027201560993`*^9, {
   3.922202784996216*^9, 3.9222028010611963`*^9}},
 CellLabel->
  "Out[3177]=",ExpressionUUID->"83f54594-e8fb-428e-8ae7-7b020f0eca66"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{{3.922191496743524*^9, 3.922191503139511*^9}, 
   3.922193502335417*^9},ExpressionUUID->"b4231899-7689-4923-bc3b-\
74255e9f666b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2666721412913766`", ",", 
   RowBox[{"-", "1.165326563906961`"}], ",", "0.26667214327356326`", ",", 
   "1.170792443147478`"}], "}"}]], "Output",
 CellChangeTimes->{3.922191503952281*^9},
 CellLabel->
  "Out[2697]=",ExpressionUUID->"62704376-c612-43b7-b21c-c81d7effebcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"functionList", "[", "rTrain", "]"}]], "Input",
 CellChangeTimes->{{3.922191315415907*^9, 3.922191356102845*^9}, {
  3.922191394237464*^9, 3.922191395384857*^9}},
 CellLabel->
  "In[2689]:=",ExpressionUUID->"248b69be-a04b-4c71-abbe-2b8f84f85eb1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.10713966375164673`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}], ",", 
     RowBox[{"-", "0.107139665368549`"}], ",", 
     RowBox[{"-", "0.10713966499426292`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.48971326138298404`", ",", "0.3246452345452503`", ",", 
     "0.4263854803912955`", ",", "0.4843008117537908`", ",", 
     "0.1447912331301053`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.10713966536854905`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}], ",", 
     RowBox[{"-", "0.10713966536854905`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5120766198157574`"}], ",", 
     RowBox[{"-", "0.21707493839890335`"}], ",", 
     RowBox[{"-", "0.380983969377711`"}], ",", 
     RowBox[{"-", "0.4993748946965157`"}], ",", "0.0066034006137744945`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.922191396818639*^9},
 CellLabel->
  "Out[2689]=",ExpressionUUID->"9ac65a60-91be-450d-b112-c036a6f8e439"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot for lecture slide", "Section",
 CellChangeTimes->{{3.922107183480682*^9, 
  3.922107186471921*^9}},ExpressionUUID->"0d8f6300-c53a-4639-ab1f-\
2c6f7a0816a6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"generate", "[", 
  RowBox[{"3", ",", "100", ",", "100", ",", "100"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"myfuns", "[", "r_", "]"}], "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"gauss", "[", 
        RowBox[{"r", ",", "R", ",", "S"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"R", ",", "R0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"S", ",", "S0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "gaussians", " ", "without", " ", "standardization"}],
    " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"myfuns", "[", "r", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}], ",", 
    RowBox[{"Evaluated", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", "Automatic"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "standardized", " ", "gaussians"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"functionList", "[", "r", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "rminG", ",", "rmaxG"}], "}"}], ",", 
   RowBox[{"Evaluated", "->", "True"}], ",", 
   RowBox[{"PlotRange", "->", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.92176765755232*^9, 3.921767745826783*^9}, {
   3.921767788372344*^9, 3.9217678449623947`*^9}, {3.9217700752480497`*^9, 
   3.921770104172182*^9}, {3.9221057177353787`*^9, 3.922105720793439*^9}, {
   3.922105880924859*^9, 3.922105909167992*^9}, {3.922105996072849*^9, 
   3.922106002946698*^9}, 3.922107171443389*^9, {3.922107350184824*^9, 
   3.922107372694001*^9}, {3.922107802671782*^9, 3.922107811399581*^9}, {
   3.922117560903652*^9, 3.9221175891184797`*^9}, {3.922189259487694*^9, 
   3.922189317064197*^9}, {3.922189568325667*^9, 3.922189597479381*^9}, {
   3.922189909284677*^9, 3.922189911052119*^9}, {3.9221899996277523`*^9, 
   3.922190001494377*^9}, {3.922190692677751*^9, 3.922190694331348*^9}, {
   3.922214069525631*^9, 3.922214098939472*^9}, {3.922214129208314*^9, 
   3.922214186294766*^9}},
 CellLabel->
  "In[3549]:=",ExpressionUUID->"051783ed-164a-4acf-bc3b-acccd8df9853"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"nTrain: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nValidate: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\", nTest: \"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\"\\nnGaussians: \"\>", "\[InvisibleSpace]", "9"}],
  
  SequenceForm[
  "nTrain: ", 100, ", nValidate: ", 100, ", nTest: ", 100, "\nnGaussians: ", 
   9],
  Editable->False]], "Print",
 CellChangeTimes->{{3.922189265156892*^9, 3.9221892771587*^9}, 
   3.922189319880977*^9, 3.922189538839172*^9, {3.922189569457175*^9, 
   3.922189597968468*^9}, 3.922189877383365*^9, 3.92218991190895*^9, 
   3.922190002279058*^9, 3.922190625338719*^9, 3.922190694987007*^9, {
   3.92221409994442*^9, 3.922214135825274*^9}, 3.922214187456958*^9},
 CellLabel->
  "During evaluation of \
In[3549]:=",ExpressionUUID->"46c484e0-40cf-4dc0-9fe7-1654be1ac831"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwVV3c41e8bNkJkk9BCNklCxvl8nmMm2UkDhYykEMI3yl5ZKYTMzCg7FBlZ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV1HlYjWkDBvCk9SjSa0ySoVCTZgjj0ML9aJmipoPGTESjTaNkazoiocWU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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV1Xk41NsfB/CxjGVQ+LrWkXKz5VbuT2lBn5OQEFG3hWhTKlQSidutiRBZ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwUlnc81f8Xxy8uLvdeiaTMaFgZ2ZXP57zJyspoIMkKSRIZDYVKRgrZRFZG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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwt13k0VdsfAPDr3nPuRQg3DXhCpPlJoVL2lxQZn6kMGZroZSiUlBQZMkTh
KlQyRNFgShkrSULGErpkijLdU6aS6bffWr8/7rrrs/Y6e539/e793d8jd/ik
2TE6jUabw7///tkav1wSE6pRhPjpE7qGXJTa1p7bWl2NPv7V3RNnzkXK3qW/
lvypRgknHyn123CRcW5A4DWbGhQmUycd8i8XhSoJ3QqSqkXNYZMpTSFcNMuW
q3G/8x6pdp8oiyrnoq8j+mt2pzQgnQ/aNknqHcjGxGTszMdmZJryOHRGsRPd
Vq1qmLJrR1K8E5GrtnahVJUA9WifLuT/RU/+Jqcb+c1FWWkX96LXj7Yk50T2
oB5fSnHNdD9ayaoMvpTUi+6THoWJtEFUUjbmqZbUhzIyg2yn9UaQaU3v+6m8
r8g4P+wKcZlCYtKVF2696kcbvh7YWa/1E40n7uIrLhxA9TNbdon2jSGboTBT
01ffkFxCcnL88Qm0ReVjY3L2d6Q3GKx3dmAShcqFJ1jFDKKre5/+rg36hcSs
B+1q/IZQwFqvRc6saSRlqbOKZjyMYlb4rvbJ+oME/jWo9ZQbQT6lM8Fde2bR
fbmKlWPdI2hxv5BeZOUckrk6LfQ2cBS9lnQWzz22gDwXO5yokOMh8eEHd4XP
0KClUE81OpWH0szYjgd8aJCq4r/lxj0e2lrsJ5viSwOBDSm1CRk8tD/MLGXr
ZRrM+3q9u53FQ4lKs6m212hwYf/fI9F5PCR/1CQjM5MGH/XNb217zUMqnZOP
9nyhAaOdun2mm4dMG7SL/XT54Nb80K+k5RTSW6OmVKjPB3qyZAhIUkgzYC1n
zIgPVKVss7qlKLRhi6i7swUfKL+tfyq9kkLMm51ypof4YCXXtSZQkUKl9j5h
Cr58sC6zv1JYhUKreY+tap/wgWWisNdifQpJ66ZUknl80P5U1CbQgELsZI4K
FPBB2meTxklDCtHMfIUKSvig9nz2v59MKMQt0HuV9I4PquM09EMsKXTdr0/J
s5cPHiu6xCU7UmhGaMWv5UvpEGHUNFl2hkLzIU0/pFbQwZwuHj/qjefjCx+S
kabDM7P5cSkfChGTfzoV5OlwKmB32+nzFBLq7HijvIkORn2uxssu4fd7nByj
t5cOvEyFJplQCu00WrPJx5sOAXKp6uoJOB5V3Uq+5+jw2+Bi9a5ECoFWgtzF
C3TYvCxZdPctCumoCkoEXabDGhuVF/vuUMjwr5GZa1F0UJkRjNVNodDB0ezq
+xl04HftZJGZFPKLVD/W+okO5b9H9EKeUygxgWYg9ZkOVe3rP54ppNCz9Gpl
h046NMiofjpSRCFeme3sQB8dBiWlNDVKKOTAuxQ79YMOhronE1pfUEjL5F25
xCIGqFVUOb6tpJC9bfR9axEG1KVU6N15S6HzzjaRd8QYsHb8dLpnFYXyLo1Y
KS5nwL7I86XLqym0Kkf0x1ZFBuTcyLEze08hUsxaxgIxoETfz8y3mULyf8kT
8dr4+bAbZ7d/wPFYOzzI3cOAHQNhi6ewvbX8Co4YMmAN+/rNEy0U+uaRYuhl
zQDfazKkVhuFqpsHz8d4MWD7e0WU1kmhSM751sb7DIhV6QvY+Y1CT8v59Tuz
8Hi4f9RL7A7ejdLBxwxIF9yrqfUd7799+Sn0pwyg/WJegUEK1cwNu2x9xYAm
+/iSTcMU4ne2o8W3MWDbAYO0ah6FlDnDnve4DHBbM/NZjaLQgfJz/TlfGLBs
c+fTVOwMqRs11V8ZMBtJM/H+QaE9jfWcmR8MmKnTlxIeo9Dl7bDWQYCAuMf5
/NMTFMpyqr/lIkRA+SFnu38mKdQUe1DEZzEB27SDzDOwZXk+49clCKC51a0y
nqLQy9TcstdyBEyGeZpH/qLQQANSblAgYCxod147tshcXSpXiYBawXV5Cr9x
vg4MXZnYSEAWEot7hj27aJXZ6h0ErB3WGaieppDC9tw3KrsIkE4qM1z0h0IG
TkgdAQEnAxkWBtiJr2ylrfYSEMj+pFOFvf0MZyDMjAA3j+InT2Yo5Jgqb33D
koAVaS8l+7FDG3JqU60IuDxjoSQ5S6G2tXU5JfYE6E0tkffH9v5C+o6ewOPN
qnc05ijEmJNOHHIjYHfOIjUn7OtSW4u+nSIgu27kwjXsh1aHf/V4E2B6sXTJ
F+xtZ88t7TpHQLBlyjHGPIXexl1X7bhAgNOE31El7O7mF16fLhNwvVPI1QXb
/WdLzIdgAnKLn52OwJ5ZPJrbGErApmDd9VnYS42kftREEXDuo0hqH3aai8ri
d9EEiGloHp7HVg7ft6mSQ0CS2d7GZQs4PlVnXV8mEtCq8LFgL3Zbf1RE6R0C
rEQtNh7EdiIysoqSCfATSTE7hT0uX1b9LI0A5+RCxUBsf62P3/MzCFjpEZ/B
wRZxHGblZhIQbanZcg/71kW60pNHBFwzfJCbj73mzoq9D7MJaLr4UaMc+1mJ
8rEHeTj/muVeddi7P+sGpRcQcEnAzboNu/G3fVpqIQHtQZ9GerDtl3m/vltC
wP6A2Y1D2MOqkT23X+D1T3dK/8T2sbhHSywnIED0fNEUNtOrZOXNNwRYSzQy
ZrBjo5s1OVUEpF/qmpnDls0ZtIuuIWDXz/spC9iP62l+UXUEdKuunfzPO0aX
3Y5oJEB995Gpeex3i/4uCf1AQOO2/emz2Jbr9n4O/kSAoiOdPo3dq2c3fbmd
gNgNx4UmsE85n17u30HAUY3QN6PYc8ER6n5dBLw1P7JuADv8Xur+8714Pqc/
uzqxl1UUnTnbT4D/NeOFZux7PY2c098JKBU/5F6FrUL7nu8xTICJw5aIYuyX
MgvN7jwCRoSrLB9hG+5aOubyk4ANPX/V38b+bLtR7N8JAiIrt09EYE/E25oc
+YPH91Tvc8IOeO7p7jiH1xuudc70v/x9Cou0o5FwTy10vwb2WnZh7QEmCaK9
EZKL/svX5oYhCwESjLjGfD/xftL5Z0DATIiElxtH4lqw7SOX6BmKk7A0qeJd
IvbIw/XO+yRIiCdIZ1/sczXaIXuXkxBk+Xe+DTaH5fEGZEg4usTEUgK7OqAO
VNeRwHuhVn4en49TKpMGXhtJeLIuVNkIe3mf9IFcZRKWW6wUl8E+ruPqtlGd
hC8xOzaU4PPIZC1KVNQhwcJ0vLQXn98nz1XSj+iSUJeOXj7Atjxuk5OiT8Kv
BZGtbtj3qjPf/mVKQmqB9ZmfuB5oX9Ubl7AnYfGh5APfcD0Z2nlq3vwQft9Q
gkrGjh69KRBzFMfHW33aCrvb+NtKERcSTJq3OL3B9eiiWIgh04cEiYPFaaG4
fhXfqEifiibBctDm+VtcHw/rDudsjSPhwcYlAc7YAr/FSz3jSZAVd3jBxLay
PtzMSyJhnWVvLIxTaEqKb2HgIQkQrf4o5SfOf4qmVWslCfs2Jd9dgev3Z1On
IxLVJEg+uJqZMorzSY9yN39PwvOdrDVrsBuPdAY1NJPgnzN6WXkE14/VF3Kr
ukiIVPTL2zSE6/XDIsHCaRJKnY0EevopZOeXkfpilgSHsiZJG2xRk9gdlQsk
nEyntzR9xfVuzPVEM8mEbKfs3WV9+D7dLlszIsYErWJ5oaAeXD/ehoTJrWOC
WZ+7dVMHhVi95vwRNkxg5Tu7u+D7sTgfkqPtmHBBUK24qIlCrsEbt8U7MkF/
bkMuE7t5Det4uhMTzE9TybcbKJR0srjqpScTQncZhBfi+1ZtTvbKRDgTYiZF
EnLwfX10OY+0L2GCvxLLMhXf/5svDIelv2DC66qovHzcH8x3fRceLWcCx9Y9
sAL3D/H3+yQuvGOChuCbS18KKFSn1q6Y2MIE3ZHSAb48PL/lmz2fKCZskNGM
msf9B39MYrCxAgvGOTJmjfEUapm8KXBDiQUq6sTRnJsUSrWOi+xcxwI5FUVe
1A3cD8ldj3PdzIItSW9cdDkU8sgJTg/XZAHkqYplXMP5qj9V+daKBeL9fusl
Qyj0aJEuiSJZEOcu9+WLB4W6HOtUz17HzyeQZzmnKCT+zNwpO5YFtBW9t/RO
Uuiso2PVykQWCHyG8EeueL8WnAuj3WfBiR/V84edcfztHwm/fsWCYe0DHuEH
cX+SJ7Z0zwQL1jvtbH+zB59Pq47VBrb8QJVkwjibQrfrlb4a2PPDwxVvWv8V
x++n45VieIgfbFXr1bpEcT+wWVDa2Jkf9Ey8jN4KU+gfwW1ipl78cDLTojeY
hfNfGjuzP4IfHjiGttT84SEFWYPGwyX8oNTxWssN98+D34rOnZcSgGG3xfdX
PuAh+nxJ49dhAWByHFolZXhofD/T2vOJIAQqt3GCwkeRiUAkY73bIki1vf7S
YXAEbdfeliezUwgCjrn87bF2BM2UrY9RnROCGREF3nPnYWTwarf3lXphGPuQ
FHboyhA6Td6LmI0WARtTbzozaxCx7kHFbdPFwHtqPHK06jvifPVfKBEVhW18
LTPh776h6HhSrcRDFEKKXqi2fRhAn67d5rV+FoW7K+iGApX9qDHfdJugthgk
6k9l6jz/itSmsySNU8VA54ciUVDUh/oCll7KFhSHtXDtl1lGL5pdv/qCvKs4
bCVzX2hm9KAauoXgw1pxuNjhqO/yuBt1SXMkTbewQSvw/UTA3i50yMqngp/D
Bv/nphrrHDqR4fp/kgvj2NAQTOsr39+J1OaV/I7fZEOf0byzjXEnErzXqvYu
kQ2usp5CUbs60VNKLetKChs8tX43Lkh1IuaVyevMbDZYOdi1CLd3oKwCT3ui
hg2ZKg/l2sw7ECdUX+NpLRskPDIfXDXoQBdt5ZcfrWODdeNTWe3dHcicr7mp
opENRistB7JVOtCs4eY9ga1siJaxbrsh1oFMvlLr6f1scDbR5cY0cNGO51X8
eQNsuLJ9tGh/FRcphN/tP/SdDfcdGLFSL7no998md8uH8Xrf1ak9eIK/n32f
iAeMscHt4YBFXSQXXTUOoZQn2PDqoPSyhGAu8pazf989yYbUNIu2Y35c3J8I
h8A0Xv/oYhu6GxepJfYf/vGHDS5J+VLNR7lI1q0MJc+yoUnz1pfUg1wkCHHS
/8zj+FnsTzttwUUT4m7TCwtsiPz/9/v/ALpKmNk=
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJw12Hk8VN/7APAxc2eGSJh2IsoSKQlp0XkoSxGRisRXFD6JjyWypChrogjJ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwVlnk8VP8Xxu1FzNw7EyE7SSS7wtz7ObSQpaJSUVrsFSKhL1mKSiJkSWXN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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV0wk019kXAHBkz/p9jTb/RDMSTSlLTeFev6lUREolIkUSoVKYqGGyNJUZ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV0wk011kbB3CEIll+d5IwKUoLMxrGkuR5MkkrmabGEm0UGolKBpESRdaQ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    StyleBox[
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJwVV3c41e8bNkJkk9BCNklCxvl8nmMm2UkDhYykEMI3yl5ZKYTMzCg7FBlZ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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwV1HlYjWkDBvCk9SjSa0ySoVCTZgjj0ML9aJmipoPGTESjTaNkazoiocWU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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJwV1Xk41NsfB/CxjGVQ+LrWkXKz5VbuT2lBn5OQEFG3hWhTKlQSidutiRBZ
L0pyKblZEopU2uR6xBhhhJmEsYwM40v2bfxO53nOc57XX+c857w/n7Pq+HnX
k+IUCiUDz58rYT7tcy+tFhaXfg4SHrZzStpqa2H/UkDTT5sEvZlWmasF1hq2
zU+/JzItXdfUwepIbQ8RtlMJIyzerQ4c6HvVFrE7nLxq66PrwH0y4NI8ts+w
7XJaRR1krLx+aRZ77pbRHzuH6iC86LLaNHaUgXx6uBYTil64eUxgq1aPdFc6
MEGw28h2DDvneJP+UigT1iX0NgmxN1BKfS2eMCEz/RZFgP0xI/XZlQ4mxCVq
Nfdj7zG/MvNCvh4up6bZ8rC72t23TVjUA7VZwrMDe4FYVXcuox5up2cENmFH
l0goPmHVw4soViATW8OZ/8fgYj3wzgrUq7HNogt4JzxZEE4O7SzH/s8gzuBB
HAtiaE3sIuy91Rf8Ot+xoEzukXgu9gWK2exBnQYIaVHZdQdblKEOqc4NILXu
+dE47Fjz+XD2tQa4k4i0bmLnB31QdOpugOS3Rlf8sfuG7Q13PPgMkvbQboN9
MXrtuetNn+Gfv45Ib8WmqMhwOymNYJPhz1mLHV8i0KH/3ggL1n6nVLCfDBcV
pCY2QmJOw6/fRCQEmD9wKstrhLbQ6LMN2Fujk8bYlY1gNGC+7z12rUHgJqUf
jZAbx1DMwuYf31oV49oEXKfHv3lgF5YYn8o/2wRLfStiHLAvUbRla280gVpE
wu0t2BL/LDlJPW8C16NewSrYKzn/ca8TzVB8unu8epEEN2fnH4EtzSDOqgpR
wx5fVz2ZPtIMB+S05UULJNxeZj5bKcMG+tI6kz7sdyx9yjJLNgjXM0yKsHUd
RQr/5rDhTN2CEsIW2BUatQa1gDfX+dDueRLCDH9du5DQAkz716prsekyaSa6
BS1Qu3z0lDy2U034pnNdLeDZ/vF97RwJz2wO20jZfQGjFcZ7ATvUSu6YmUYr
eGdbiavOkqCiy/A6bNoKVymywpEZEp6KTXvf2N0K0sUlZ2uwuz/0nGtgtMIb
z+IVl7Gt4fWfpwSt0HEw4UzTNAnyFmfupla0QazYvtv+UyTc31jzecqDA5Wy
acpHx0lI0D615VgQB3SG/+lchx1OpWYz4zjwRumFw+IPEny/WAVlvecA+kVH
Ng3bMvAd3X4VF5IsFJTqx0joLC07k9HHha9fR/avHCVBZ8MjCWufDvBdrfWJ
MYzPT9/h9zSsA3w8e19ZY8tI9rSq3+8AlfQ5R2nsUbZOvrC+A/RLVhyIGSLh
Q0D6njvrvgFFM2Q+TkDC0edJGYKxb5A4dS4i/DvuB/9jbEoM7gJFekSZYR8J
VTneVEZCF7iz/a15vTiv6k7sC7ldIDR9GJyGbbCkeX5PexecT+I2ymC3nnRj
S9O7cS6EqJdHwuH/TdBqQrvhkEbtqsguEryZBiE25jzQsbaZieaSMCOpdcxy
Jw+2B+Rt2IwdtW2Z3ca9PHDUyFHt5+B6KZn4Rc+HB6VCP6Yl9vCdyhLJdB6o
H0qeEbThevFyH6ya48GIzvMTG76QcHUx7qDV6x7YoclKDPtMQtC1/0jLmh6w
VFWM1sa+IDYXsaWlB+rYR9XLG0jwop4sMxnpAdty8+nvLBLsFcyVdXR7oZmy
693OetyftAeY87d6wdXUM3DsEwlFFgBlh/pg2MQkZ7KSBF4oqWc42w8eU61S
H5/h+7+xZdSGygeLFyFb7LFNosJen1Diw6RMi2JzCQl/Jas5Zxrxobi9vLC7
mATNQghWdeND/mB51uxTElw74+skK/gQ8pvVec0C3H+QyXnenwPwr9mJerVs
Eh5T/V/eowzCdgnKdfEkEv7NC3eftRuGw7HtLwxP4/w/vxUpeQO/Mz/pS8Vm
En7rO2DRsH0MLrupxJNSJDTMm1oq9v4AxzDZSlHdCKxKy8q6e3oCVHymNqbE
joDd4E27y/xJWOhxYXo5jsBt29IZZvg01NE4NAvKCDCMAuS8pWdhTQop3Foq
hCSNUP3g/DnY5qA1kn1YCMFv5m922SyArtRJeoqYEJb3y9vFVi9CqNKN/S65
w/BR01u55OQSXDQNcpixGgblodxMhUAK8j33Ls+lewhcPlu9vrpTDH3tDR80
9x+CeXmNaXVVcSRklc8aU4bgauymk22t4mgZ1xoO/C2A2OSQtsbHEohdXMsS
agggqJMaKjwricSqutmpOYNQy2ChjWuo6MOmVGLCZBDyC17RXs5SUbONynx1
0XfwUh+helZIod1HRg2mN3yHJ3I7qRArjd5qHxnPLRwAz4Md+g7uMiiUk+bK
1R+AwYFXV0K0ZJFH+FRyymM+iIsqGvuGZJEtJB/Wo/NhfL/UoYtPaWhh4Pir
rrv94CwbK2HsJ4equPZ33dX6YYvV5mcrLOTR3mUZEjrRfTD/1jhp46I80v9W
+JJP7QOHDzuCIhsU0IyZm5RLUC9coj6KWUhchpjbx2ibRntA+hGquu+yHGnn
rS/97tsDyX3XlyoUFZGH+x5RVycPEu9SzSr8FdF51q7WTjcetMbfH2njKqKP
otjKB/Xd0PjcZTPNSgmZCd7FU6y6wWw2X9PpoRKqjnnQER7WBb0M1WtFNGW0
XM/LUutCJywY6/+p66uMdu1fad/k/w3qxPfRCpjKSEMz6tql0A7ooidrupgS
SOnID/HXAV/h2MHgKplkAtlri7S2MrjgaLwn62UKgc4khURJX+WCmcjg6uk7
BPp4unzbl2Au0B61mX26R6Bfyt9G+V/gQilplh/5gEBT43IphUe4IBU5mSBV
RKDNyUSm6TYu5Jdd9JSsI1DBVMnc5XkOJEfZm5cyCUQPO1DlNM2Bv9x11b1Y
BLqZp9CuN86BvWLNTVWNBPJZP9HfIuDAguPvNmFtBDIsy04x43LAuY80Fu8n
kEjPZp/MKw5sLa+RecYn0LHVXvzeUg6sjs7sP/adQJ8yn1W/L+bAzHrnzMoh
AkmQq32DcznwMPSpMuMHgTI+7HYT3uHAbacI0mSCQBHZbQeYf3MgaJVnffck
gZz1V2TnxXPAoUYhAs0SSMHQ4FfvSA6Y3es/PjpHoN4c+YO2YRxY6fcWshbw
/pUTXL1rHKChFPoeEYESBaMF1FAOTCj7zS4tEehIjDKzH/8r/wfFjgWR
              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJwUlnc81f8Xxy8uLvdeiaTMaFgZ2ZXP57zJyspoIMkKSRIZDYVKRgrZRFZG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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwt13k0VdsfAPDr3nPuRQg3DXhCpPlJoVL2lxQZn6kMGZroZSiUlBQZMkTh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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJw12Hk8VN/7APAxc2eGSJh2IsoSKQlp0XkoSxGRisRXFD6JjyWypChrogjJ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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJwVlnk8VP8Xxu1FzNw7EyE7SSS7wtz7ObSQpaJSUVrsFSKhL1mKSiJkSWXN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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwV0wk019kXAHBkz/p9jTb/RDMSTSlLTeFev6lUREolIkUSoVKYqGGyNJUZ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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJwV0wk011kbB3CEIll+d5IwKUoLMxrGkuR5MkkrmabGEm0UGolKBpESRdaQ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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0., 4.999999902040816}, {0., 0.9999999999999997}},
            "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PanelPlotLayout" -> <||>, 
          "PlotRange" -> {{0., 4.999999902040816}, {0., 0.9999999999999997}}, 
          "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0},
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             RGBColor[0, 0, 1]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}],
     Selectable->False]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJwVV3c41e8bNkJkk9BCNklCxvl8nmMm2UkDhYykEMI3yl5ZKYTMzCg7FBlZ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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwV1HlYjWkDBvCk9SjSa0ySoVCTZgjj0ML9aJmipoPGTESjTaNkazoiocWU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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJwV1Xk41NsfB/CxjGVQ+LrWkXKz5VbuT2lBn5OQEFG3hWhTKlQSidutiRBZ
L0pyKblZEopU2uR6xBhhhJmEsYwM40v2bfxO53nOc57XX+c857w/n7Pq+HnX
k+IUCiUDz58rYT7tcy+tFhaXfg4SHrZzStpqa2H/UkDTT5sEvZlWmasF1hq2
zU+/JzItXdfUwepIbQ8RtlMJIyzerQ4c6HvVFrE7nLxq66PrwH0y4NI8ts+w
7XJaRR1krLx+aRZ77pbRHzuH6iC86LLaNHaUgXx6uBYTil64eUxgq1aPdFc6
MEGw28h2DDvneJP+UigT1iX0NgmxN1BKfS2eMCEz/RZFgP0xI/XZlQ4mxCVq
Nfdj7zG/MvNCvh4up6bZ8rC72t23TVjUA7VZwrMDe4FYVXcuox5up2cENmFH
l0goPmHVw4soViATW8OZ/8fgYj3wzgrUq7HNogt4JzxZEE4O7SzH/s8gzuBB
HAtiaE3sIuy91Rf8Ot+xoEzukXgu9gWK2exBnQYIaVHZdQdblKEOqc4NILXu
+dE47Fjz+XD2tQa4k4i0bmLnB31QdOpugOS3Rlf8sfuG7Q13PPgMkvbQboN9
MXrtuetNn+Gfv45Ib8WmqMhwOymNYJPhz1mLHV8i0KH/3ggL1n6nVLCfDBcV
pCY2QmJOw6/fRCQEmD9wKstrhLbQ6LMN2Fujk8bYlY1gNGC+7z12rUHgJqUf
jZAbx1DMwuYf31oV49oEXKfHv3lgF5YYn8o/2wRLfStiHLAvUbRla280gVpE
wu0t2BL/LDlJPW8C16NewSrYKzn/ca8TzVB8unu8epEEN2fnH4EtzSDOqgpR
wx5fVz2ZPtIMB+S05UULJNxeZj5bKcMG+tI6kz7sdyx9yjJLNgjXM0yKsHUd
RQr/5rDhTN2CEsIW2BUatQa1gDfX+dDueRLCDH9du5DQAkz716prsekyaSa6
BS1Qu3z0lDy2U034pnNdLeDZ/vF97RwJz2wO20jZfQGjFcZ7ATvUSu6YmUYr
eGdbiavOkqCiy/A6bNoKVymywpEZEp6KTXvf2N0K0sUlZ2uwuz/0nGtgtMIb
z+IVl7Gt4fWfpwSt0HEw4UzTNAnyFmfupla0QazYvtv+UyTc31jzecqDA5Wy
acpHx0lI0D615VgQB3SG/+lchx1OpWYz4zjwRumFw+IPEny/WAVlvecA+kVH
Ng3bMvAd3X4VF5IsFJTqx0joLC07k9HHha9fR/avHCVBZ8MjCWufDvBdrfWJ
MYzPT9/h9zSsA3w8e19ZY8tI9rSq3+8AlfQ5R2nsUbZOvrC+A/RLVhyIGSLh
Q0D6njvrvgFFM2Q+TkDC0edJGYKxb5A4dS4i/DvuB/9jbEoM7gJFekSZYR8J
VTneVEZCF7iz/a15vTiv6k7sC7ldIDR9GJyGbbCkeX5PexecT+I2ymC3nnRj
S9O7cS6EqJdHwuH/TdBqQrvhkEbtqsguEryZBiE25jzQsbaZieaSMCOpdcxy
Jw+2B+Rt2IwdtW2Z3ca9PHDUyFHt5+B6KZn4Rc+HB6VCP6Yl9vCdyhLJdB6o
H0qeEbThevFyH6ya48GIzvMTG76QcHUx7qDV6x7YoclKDPtMQtC1/0jLmh6w
VFWM1sa+IDYXsaWlB+rYR9XLG0jwop4sMxnpAdty8+nvLBLsFcyVdXR7oZmy
693OetyftAeY87d6wdXUM3DsEwlFFgBlh/pg2MQkZ7KSBF4oqWc42w8eU61S
H5/h+7+xZdSGygeLFyFb7LFNosJen1Diw6RMi2JzCQl/Jas5Zxrxobi9vLC7
mATNQghWdeND/mB51uxTElw74+skK/gQ8pvVec0C3H+QyXnenwPwr9mJerVs
Eh5T/V/eowzCdgnKdfEkEv7NC3eftRuGw7HtLwxP4/w/vxUpeQO/Mz/pS8Vm
En7rO2DRsH0MLrupxJNSJDTMm1oq9v4AxzDZSlHdCKxKy8q6e3oCVHymNqbE
joDd4E27y/xJWOhxYXo5jsBt29IZZvg01NE4NAvKCDCMAuS8pWdhTQop3Foq
hCSNUP3g/DnY5qA1kn1YCMFv5m922SyArtRJeoqYEJb3y9vFVi9CqNKN/S65
w/BR01u55OQSXDQNcpixGgblodxMhUAK8j33Ls+lewhcPlu9vrpTDH3tDR80
9x+CeXmNaXVVcSRklc8aU4bgauymk22t4mgZ1xoO/C2A2OSQtsbHEohdXMsS
agggqJMaKjwricSqutmpOYNQy2ChjWuo6MOmVGLCZBDyC17RXs5SUbONynx1
0XfwUh+helZIod1HRg2mN3yHJ3I7qRArjd5qHxnPLRwAz4Md+g7uMiiUk+bK
1R+AwYFXV0K0ZJFH+FRyymM+iIsqGvuGZJEtJB/Wo/NhfL/UoYtPaWhh4Pir
rrv94CwbK2HsJ4equPZ33dX6YYvV5mcrLOTR3mUZEjrRfTD/1jhp46I80v9W
+JJP7QOHDzuCIhsU0IyZm5RLUC9coj6KWUhchpjbx2ibRntA+hGquu+yHGnn
rS/97tsDyX3XlyoUFZGH+x5RVycPEu9SzSr8FdF51q7WTjcetMbfH2njKqKP
otjKB/Xd0PjcZTPNSgmZCd7FU6y6wWw2X9PpoRKqjnnQER7WBb0M1WtFNGW0
XM/LUutCJywY6/+p66uMdu1fad/k/w3qxPfRCpjKSEMz6tql0A7ooidrupgS
SOnID/HXAV/h2MHgKplkAtlri7S2MrjgaLwn62UKgc4khURJX+WCmcjg6uk7
BPp4unzbl2Au0B61mX26R6Bfyt9G+V/gQilplh/5gEBT43IphUe4IBU5mSBV
RKDNyUSm6TYu5Jdd9JSsI1DBVMnc5XkOJEfZm5cyCUQPO1DlNM2Bv9x11b1Y
BLqZp9CuN86BvWLNTVWNBPJZP9HfIuDAguPvNmFtBDIsy04x43LAuY80Fu8n
kEjPZp/MKw5sLa+RecYn0LHVXvzeUg6sjs7sP/adQJ8yn1W/L+bAzHrnzMoh
AkmQq32DcznwMPSpMuMHgTI+7HYT3uHAbacI0mSCQBHZbQeYf3MgaJVnffck
gZz1V2TnxXPAoUYhAs0SSMHQ4FfvSA6Y3es/PjpHoN4c+YO2YRxY6fcWshbw
/pUTXL1rHKChFPoeEYESBaMF1FAOTCj7zS4tEehIjDKzH/8r/wfFjgWR
          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJwUlnc81f8Xxy8uLvdeiaTMaFgZ2ZXP57zJyspoIMkKSRIZDYVKRgrZRFZG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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwt13k0VdsfAPDr3nPuRQg3DXhCpPlJoVL2lxQZn6kMGZroZSiUlBQZMkTh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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJw12Hk8VN/7APAxc2eGSJh2IsoSKQlp0XkoSxGRisRXFD6JjyWypChrogjJ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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJwVlnk8VP8Xxu1FzNw7EyE7SSS7wtz7ObSQpaJSUVrsFSKhL1mKSiJkSWXN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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwV0wk019kXAHBkz/p9jTb/RDMSTSlLTeFev6lUREolIkUSoVKYqGGyNJUZ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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJwV0wk011kbB3CEIll+d5IwKUoLMxrGkuR5MkkrmabGEm0UGolKBpESRdaQ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          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PanelPlotLayout" -> <||>, 
       "PlotRange" -> {{0., 4.999999902040816}, {0., 0.9999999999999997}}, 
       "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{502.68646240234375`, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.999999902040816}, {0., 0.9999999999999997}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.921767733837853*^9, 3.92176781078128*^9, 3.921767845700141*^9, {
   3.9217700618558693`*^9, 3.921770121022317*^9}, 3.922105669836732*^9, 
   3.922105721472352*^9, {3.922105882409622*^9, 3.922105906100602*^9}, 
   3.9221059483061247`*^9, {3.922105984003936*^9, 3.922106003618525*^9}, {
   3.9221073273278837`*^9, 3.9221073732259283`*^9}, {3.922107804548157*^9, 
   3.922107811945222*^9}, {3.9221175807085114`*^9, 3.922117593148942*^9}, {
   3.9221892435746098`*^9, 3.922189277287222*^9}, 3.922189320002033*^9, 
   3.922189539020043*^9, {3.922189569640163*^9, 3.922189598126857*^9}, 
   3.922189877622743*^9, 3.922189912065086*^9, 3.9221900024335136`*^9, 
   3.92219062546271*^9, 3.92219069512157*^9, {3.922214100106464*^9, 
   3.9222141359806957`*^9}, 3.922214187599626*^9},
 CellLabel->
  "Out[3551]=",ExpressionUUID->"97b471b6-f74f-4ee3-a3d5-eef5e3ca5d54"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJxF13k01N//wHG7yFIi0YYS7SpUtpeEJqQQKUkqS1F2KUspio+llDYJyVJI
yT6Dy0che8m+D2bMPvYl8n3P9/v76a/3eZz3Ofc+7zn3nnuu/CU3cwceLi4u
U24uLs43onPtxWSzVtC+SdShSC6Av95Ke3WZNrj9enDULGsOJBWCr5w/0AYl
Tdvx4jZzkM0943TvRBs8tr9s2S80BwPlxBuNwW0w2NQqXuM0C/qAD3CktgHt
DTMfpzgDIlpXXz4ntAPlvtvUqsxJiFerbpq27QREay3z/82CxxsdD9v7dkI2
T8Fe85ssCOHnf1cX3QnqgWnZ6yeZ4Nqq55uEOiHJ463QCzYDtH3KNhjJd4Eg
8wAxZooGfXn5V98MdwHP92cBmvtH4Wf86RbBxS6w36v66t8yMlSFTGh5SnUD
Lk5n6KoJGbJP71t1zLAb+L+TCza7kCBoMquAnd4NXkvW904VDMNm1RRefZce
uGlR35QSMgiSG45ez77fA0f6M1WKtwzCCj5i27r4Hih4s3bV78oBYLdszmDU
90Cd9602gRUDUO71+tSLPb1AFRakumj1wsXcJ2+oY73QI9p++BtfB5x+vU/Q
UrgPpgWifsg7twPufrM7UugDOtgdqmhoAxULMf1Yiz7Q+baXXZLYCtwT4VTt
/D5guDgdPHWhBZL3Bx+M8euH2GebgiJCG6Ey1Yk/+HE/jLaG/N71vAGG15m2
uL/vB+06CfP8jHpQWpJ1O9XRD41Hrnpb99dCm8O5FsENA6DiI9077lMNTokn
8EtKA5BiVHCzLaUKZjt0384cGAA56R+pZ9u/gYyJkhvZeADgd4CSzLGvcH7/
pHC1/wAc3ex0xuNUBdZFHit7OABVd9Y0Gr4uh6DUro6CpwPgqxqS1fsTQeK6
irS0zAHolnZes2lzKRD/ROk96B6A5q3PVMd5i8CpTum2geYgXA48G5LX9RFm
+dbbax8bhMlgGm28OhPCdMRwahaDsE6on+83+gAZOZNSii6DkNE1ueV7UyrQ
X1Tk8L0ehGben3xSv+Ih8Efey4W0QVBWiHR7YP4KxFa+vzP5ZRCSsnecXzv8
DPYGRZ8Yrh0EUlGCa0lQNHhesaFUzg9C9o6pmhkPR+BNMG0mCBAh5V8x/TQr
eRTbfqQwV4IIx5VGSrPWOqN8I+XQdzuIsL22rW1+SzCaVZmSu3+OCCe87TOC
Jp6gsGujgv6ORFjFdzVti+MzJJPSzfT0JIKk9cKSRu0LpCH9b8mlf4igy8Ql
NDnFo8DFaGs9PBHqCiMyR+8kI987X1na1UTAxQ9EGr98h9y55x8c/kWEClU9
b8sPKegKv0O+ChPr836rvZCfhoxENSU2KwyBYUYY43tgBtJ/5P5Bdu8QbDqw
UBVvl4m0V6fprtUagjUbV3foa2YhFanVbqJWQ2DdnZ3+duAjWruRXPc7fAju
2FBfpXp9RqsSN1yeeT4EUQ3aF782fEZC8ubz4++GQHyu+5eFYg5a2FqqTC0d
AmRkUMHTkIOm08bRSO0QrHgpHKm78QtiKSufGWwfgjLduMydLl8QcdfT0I6x
IeCOZWYd5cpFPdk1G379GYJVm97URh7LRa0qf3KbVg7D9eN5+YTIXFSjepVY
pTgMNgJ2cVyr89AnLYD8s8NwTnSl1GOefPS+zLvts+Mw4C4OEz018lGybsb1
LK9heDcvZZbkno+e60vFv4sahs6vip0rOvLR4yqjA4lxw3DJSFTvnFABCsfd
rY1LHwaT3R+pCocLUIAJbTamYhhKihQk9GMLkG+j3OOoxmEw30gVyUEFyO2U
lVJ49zDcX8jTLaMUoEunKyzvTg3D4b0VxP7DhQh3/sWXG9tHYFa0UVGvrhDp
9dUfv6Y+AhHpJ8Py6IVI8yLPoMPREfjgzuoUEy1Ce65cF7e1HQG2jI71a6Mi
pExKTrO+NgKubfclep2KkLxzh/bpmyPwvulth2JIEZJ0PepqHDMCBo3lCZTi
IiTG9OM9ljACj8+4Fnm2FCFB9+w4vcwRsDrwU2IzvQjNe8l8P/xtBERfuHb9
li1Gg/4sReW5Efii+LbC260Yrbh3mG3ATwLrG1kO94OLkUrYffzl1SRojWjO
/P2kGAXFSp9M3E4CDT/uBxp5xSg1zl6mVI0Er7w7w4S+FqP6pMyhriMkCLW6
JmLRUoxkP4Lf2nMkOGtRb+rALkZHcsP1VB1JcGnJIEPtTzFyLm4RMfckAUqs
LX+0Eo8Kvjm9jfqHBPlPZo+ztuKRed+jWj4CCfSPihKLzfHo1nBnrEI1CUTP
C3So2+JREnWLnW4LCaaTSI/OOOERc7pwwp9GguqVaZ8f3cYjqUXuslczJMAZ
3X2TdR+PtHhNwgp5yfC1RtrSLxKPIsQHNkysJ8PJOjObbW/w6IvUDvIqZTJ4
mP95IZqKR13rvXP2qJIh+P3JgI9ZeKSsvMLwGnZPLPzZcVaOgEdfdVXcBgPI
MOYomCTWikc0w9uHl8LI4MTUap7pwiOJE195Nz4jw63dxwwzBvDo4lnrl9Yf
ybDbMvKQJw2PHtolX/ItJoOUqOLuCDYeZTvQd8V+I4NcxG9r7yk8WvS4W9HU
S4Ydzu1FpX/waKtfbQSDQoYVJ68uyfESkEmQpNXKaTKkz44nnxMkoLh/3lMN
xUbhYU55qpU4Aam/a15TpjMKUWv5CM83EpDtB9m+bqNRqHiy+/xPOQIK+XTl
/ZzVKNh3fYhhbiGgn4RZLTW3UfjR2iPbsJ2A5ir0BC38R2FDAld4zC4CkquJ
/OH+cBSI5MZyjb0EdOOXnGNW4ihk2jc7gCoBPeu6plKbOQpnmJcy49UJqGQg
b55cOArG7j9ciIcISJiBe7SleRSqRKIJO7QJKJ3foyiOiwIux0ZTv+pjvacX
95eIUsCU7c2TZEhAVcnhH3tlKXD6lh3dEUdAJEhOllOjwHazd+/xxgTkG71n
o54eBQq11q84foKABHrxLy6fpAAt6aN4lSkBbbvdEpl2lQKZEz3EaDMCKqix
E6zxxbzvM2+POQEZStODKfcp0HE64KbsaQJyzOO7uSuBAj1fBkqvWxHQNE/M
2IlMCkjIjeTdP0NAD8w2uroVUcBeUQ4XZU1AaUw1+y8/KbDeyulU4DmsX/vf
7pZ+bLwaF3TFBuuPMLWaolNAX3us7Mh5rF/ZyfiQIBXazVP39tli/Tcnvp2V
pIKC/oxPwgWsv+qOrr88Fd7pXZyxtMP6L79UK9OkwuYNNOWsi1h/ztbP/Tgq
7NGwiDa2x/q5cnZwW1HhRn/KqyHMjm++b9Z3p4K9CnHkzyWsn2YZ5xBIBYLP
i/J7l7F+DaLkw3+oENIr4MN1BetvnxeqTaECu+F8IBWz+raHIbQcKhR3OVmc
ccD6vdcsiSAq1NVlCiLMpNW7Jk92UsEw5Nn4HUes/2LRDQ8SFWwtpV90Yhb4
pE95MkEF1kzR1B4nrN/Etq9VlAbMm0kpDZgL4ijWM7I0uOvhbCbtjPVTfFrW
KdMgfE+ghy1mxwfRNTZ6NEiQyP3Uj3n6l+zRwJM0EB4IW7/hKta/Jb004Tz2
X/DQc0vMaeXoy6AvDYwaao6UY1YXN9nNG0KDar7q3DHMVbYd6VtjaFCjP10g
dw3rn2fHO2XSYKeX6PBNzL7HA6XDi2jw7sIl/STMAi+FnmR8o0FbZE9yFeZt
agoPGf00yDh0Bi/qgvXfz+YWZ9CAUVqctAez4U+NAJV5GjzftGHgBGZHNwsP
L0k6TBf3Fj/EPF3aT4uVp8PM/sVbyZgfiLg6Fuyhg6Xp5z4C5rQPITZzODpE
Vup0UDHXl6qG9VrSIWbq83YuVwKa+DGcV3GJDjdEbjlLYtad1xf7JwAbT24/
8TBmJ7EpjRvhdCiNL1UzxhytkOpk/pwOtdUD6TaYu434K2Q/08HXeu+a25h5
7PIZf0ro8K2+TC4Ms7KXg+zQdzoUThT5PMPs+/qbV+YQHbbyFclkY47/5JP0
iE0HVXh1qxhzZaVig9ciHUbF0/W+Yl5FD92mJc2A7pZfuzswq3OpW8htZYBb
cq/tIGZbSdIdvn0M8IuhS1AxZ2gZdtYbMeDWNa+t85h/nJrmzznDgKeaFyK5
rxPQ7JW0/c+uMEDghebjFZgNogQibYMY4KTeeEcKs+vbgqIjEQyIsaN6r8f8
JN9xRPElA15fr18nj3mgt0qHmcOAcH9c4E7MAuO+Lj/LGKD7+LmBCubdAkov
C+oYIGEnXa+K+faeh2NBIwyQfrteXhtzkt7BTZfHGbBbizali7naimx0bIkB
h2rDn+ljlrxzLEVchgkjPEq6xpg1n840TygyITYBd8oU86X09MX2/Uywsbin
Zob5U5PgmSQTJjDZymFWmNuGCu+HnGWC5mTlnDXmhRmnz86OTBD804qzwWwk
VyO07y4T1q5PeGCH2V3VT10qigmv1xT72WN+gVO+PPeKCambpU9exjzsHlZS
kcsEa5OAbEfMwqGHKKnlTOC2ParhjHnfq1GpfxqYkKjb9Okq5qAKnJs5mQk6
c1PnXTGnts6+VsfeUQEt359fx1xPeV8jy80CF+m2shuYZSSEFIZkWXAn83qv
O2bdbcWm1UosWKJWtnpgdtS46p+pyoKoYgryxJx36fsvL1MWDH3Au3pj7vK9
xW1twwKTTe0qPpi5I7bv0XJmQXpLGoVj09zwh3z3WNBq3K15E3OysSlZOJoF
iTwn6zmeHpI4tjqOBdwd1NN+mBMk4wU2fWEBnq5x6hbm8ayLjlvLWEBW/lLJ
saGBYtWOWhbMLrar3MbM8skOPUhkwRnr4DmO9cW8RrSZLJiXe2fpj/ll2kED
/XkWPPX6nMVxksvFe8pCbDj5OtEkAHNtod6XneJsKE/lfs7xJK8icY8UGz4u
nOzmGBdPOaImz4Yt2x6dC8TsOVrncUiJDWuSybEcx6tmv9XczYYS/oU6jtn1
ntx6h9mg4rFyXxBmWRnLfQbAhiC5c3Yc6zsctMcZsGGdnkgEx68Wf5ebmrGh
XnxnN8dfj/exzc6wQXhj9xLHzGflcpa2bMh95KNwB7PentC7NlfZQHnXa8+x
622nzxfc2KDnPhjE8fOq4wP2Pmxs/2jFcUy9IKbrHIzNh7Oo51gyk+3m8pAN
bw5qDnGsM/Mz8UYUG2qlf8xy7Hw0v8njKRt2/FQSvcs5f49eLHm/YoOukZkc
xyXdt/b6JbLhkMuF/RyTlM7b+aeyoVvV7ijHGuVyKDiHDdUeNy9xfEWElxVS
yIbMwgx3jqOtRzaFlbJBwV4oiOOilGrTiEo2rL2X+A/HRPaHoOjvbLAO8XvO
sYh2ZHZMExveqSS+5Vg9/EZfbCsb9hVuzOI4Qv6AzutBNvQcxyGOC65L3Ugg
s4GPV6CG44HimTdvGWxo+KPTzLGwQFdDygQbeofn2zlWNS9ZTJ9jgwlLt5/j
CwkJuzOX2PCALU3iOIx61zabfwwmrB/QOe65Z1Cat3oMPK2OzHKssl54I2Hj
GDwNTeAJxhyS2xhQsX0MTsR/W8lxh/HTnmq1MYhhdq7heNfwGa3GI2NwkTQv
yzHl6wWTDtMx8NlZKc9xWqrDeaLNGFRHflTi+PIDV1e68xhwFbTu4ljOyStg
2mcMsqct9nEcpxwcL/x4DCRDUw9xLEmNLtmUMQYMv706HK+4nrFg2DcGtaGh
Bhwvsr5puUmMwz6trOMck6YWStDtcXgVZnKC48bfB7RXDY3DoqCzKcd+RtQb
v1InYKfgz/9a/lVS0kvnSXjf1/1fqx55OvlQaQrcsnv+axwlFHeTNAVvyv5n
qvSbpLf501CJ/udIw7zZupAZ+Pl/Fihac0/GcHbZwdu9VjoJzi37iYz/Nr+M
+WX7lfwO7TdYWLb4iAgu6tvisv+VdZLIcVhatgTtfaKoD5fu/9usSQ8feIx7
2b9FZGbWreVZdmDUQYf2tr+Oir3d3pzOu2zfPn5/xjW+ZX8PbtBV28G/7IzM
YuGiub++so7Jf4EgsOyslcf4IUpw2Rese7YZ26xYNoVcfOv2eqFl8/whNA/T
/nrCSuCsZ7bwsk8KRfHuvL5y2Yf1Dn3ZpCXyd32lO5+oLf61cflR34eNosv2
5k+JWIgRW7Zgim5lvJn4smOH7y4RVq1adsxLfnWCx1+3PYpntnf9dXOu2SFh
vdXLVp/LkDVN/uuh4LV3PglLLHth57YABde/ruU5LZxZ99f9G2JlzQ6sWba9
tV/liti/zsj3vMBX+9eTEtfnlpb++j+ILRnh
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV1Hk4lfkXAPBL9i28ZawjRpYQyr50vqPuMCpL0zShNLZUaGdEKSHDEDVF
QpYWDZG1MaGXrmW4lqvLtWS793XfElkahUv83t8f5znP579znrNo+Z05EChM
o9FyqPh/xuwWg+9ntoFUrELfxhYSCgYGy/vb2uBUedCUHGXT8LrFTYI28KRH
bpehjGO5Dge2tYNVxo8PxCm7lsfEpnq1A92WYytEedg1oK0jqR1KV7eILDeT
EDz9w0ap2naIf7dNMENZkGjws9NUO7Ts+qxOUP5dTyYrTo0JbjExIX2UlZpn
xhv3MoF/oud9M+XHfj2661FMsPlA3qqibE6rCrF/xoS35k1B+ZRf56RXXBpm
gmNl8Klkyu52l5ZeyHRAp9R4ZhjlsQHvXQv2HVCjpvPlCOVVTKv9dE4HGCno
W+hSTirfIP+sswPyhme+kaCs4kb+PPm1A34x+VPvfRMJlknFXH+fTlBsiOss
oNykd1Mv/2YnSNcN+V+h/FPz2dDRV51gWKupd4jyWZrl8mHNLjjQkmQuTHkt
RxnS3bpgR1BtdB+DhBS7lTj21S6YM5/7/IRyUXiDvOt4F2AS0cF7KE9Mu+jv
zu8Ghd0jF06+JuF8kvHpaz3dIBc4rrudMm2TxNAojQUZGzXE5xtJSC3/oKlu
xoLbkn5u5yg/m35enH6LBfl1NNqRBhIu2OW7Vv/FgocVVRqKlG2Tbs+zG1mg
hsgTLTgJbXphVgqfWBAc/z7BgDLpZ8v440APfN0fOzlYT0JJueHxolOUl+wu
xlC+SNOQbLveA5sETUZ6lDc8WHcVq+wBlX/C9ELrSNgy2DR0DXsDP6vk7iFe
kuDl5vYprPcNmFnbGET8TcJ/25s/Z828gbKZ4ZylFyQky9ktN0qwodQkdTac
8qtOXZqcAxs6ToVsC60mQXvfmuyTx2y4p2NFQ5UkfHAuMeCE90LlbzG7rpaS
EKv/nfFqWi84COpTRkpIUJfINNUu7gXrdd9aG8qurXFWp8d6QYf9fcVUMQkV
9CN0Mec+yJZVU7D8i4QoR2lfSxUO6LPkigIekrBJOybgyE4ObCjrnsorIKFU
aDHo+n4O+Mfly77NJ2G8gXe6K4YDB30+zjvnkbAHXl4+/oEDfvkhSDqHBBn7
k/fSa/tB8IUuvy2dhGyL1u4vRwfBKqggsOcGCWkax218wweBM/Hp9Nt4EuJE
RR8ybw7C94y6fCKOhJA+x/A8fBC8TtrHzVwnwSHslbqL1hAYTYWjmWgSRquq
T+ZMDIHc3HLF3XASNM0fbdgTPAwZv14Piw+g6lffHVoaOwyqD/bPHfQnQUKE
x1HOHgbHI8KZ2n4kzLE1iz52DMPwdPPFmmMkNFzIcs/YPgKJLgpeXV4k/Fp5
O+fD/AgceuW5XuBO/YMdMVa3IsYg1ZQxMmdLAuNxkGhM2hhVr2RCig21r8qu
7LNPx8DZNypM35oEvXXVM+4DY7DUkqrtaUECJ9CLLa4+Dpe1PF8/NiHhyI4F
qdaocTh4aRWmvyMhiKkXSbfjgqvUWKSJNAlLImq+Dk5c+KOqRvuuJPUfdsk5
W/zEhfmlgs3L4tS9lC9s3hrMBQ3WhZFaERKmMxrLRbK4cPZJlsBojQ/nA7wn
GQIubI46dK9+jg9Xvt487PiSB9KFZZzMXj6EX22adWjlQRr9xZv8N3w4KyS4
YdPLgwrVuN5CFh8CRAOrTWd4kLGe9aGkgw8usnaKmtoEpNs3nyho4oOSxjvm
SiIBh8z1Z4yq+PDcHqDacwJKQ/rM22/xgRs1u1V/mQ/0xBV3Kyc+SFy3maOL
kvDCJeS7j3v4YPp77Et/BRJ8Hj1yzXfkQ/Sdb9xyDUgQikgrE9nFB9USiFCi
5qD0/mjR3+Z8ODCa2i5SS0Le67oXXVp8aEKmZ7iX34GSjvgehmACCkXP1dyn
TUJ0WJp3f+EEPPkrznvZeRqat71QKxslwLUyMUHk+izk2lt7aK3xwGjiF/uu
7+fh2BYhOWMlHnSt7HSQJz6BAUcvQluEC1qZeXn3TixAtM7NdjqPmutkvPNv
5Gc4ORVPky8cgeQfqpaYcYugO7WqNqf2FmIMLkgHiS/DbqujiT88HIDbKlG6
EUUCkFLuN5Ic64OIupX4Mfoq7CCcdL5uZsNGvoxzSvNXSJYe0Ik9x4LXqkGK
5YHrwN3Kchn6hgmKU09zZcNoaHG7umDtaTN4dDu+vOIkhFa6FeXDUnFYkVFZ
VFYSRuMFT6XPKFfBlRSrwH6OMPLIOjq2JPsQUu5E9rMKN6Dpm11h9a1RePio
aNTHUyJIYWvNsLDMU7wtphNZbBNF5j4fbVlD1XhR8T9SNcuiaJpvkuWk0oAH
KM+I+tSKoWNiBSXzjU34M2knUUgRR+direYMsttwn8PDunu9JRBdN/zXTIMu
fPLdP5ci1SSR07//tmBqPbjwWi1rYkoSPavOKMVN2fh/h8Q8z5dKoUGP5M4W
8T7cTTJlg2GoNJqVVc0equXgNo7WFd/ay6ATRT4zThED+Eq94W2LrzJooWQg
Wnd1EN/bsDs8oUsWIathn+HYt/hF0Ud/rN6SQ/70S9IW/cO4+CPEyPbYiDzt
ipLY0qP4nYlr67Xy8sihdN9KMhrDb90Ttaw9J4+iV5gB93XGcU5q9kz/kDwy
S48LYxaO46xKD2spRwXUq229dVydi1suF6m6FiigYmcmZnmNixMxSlefSymi
tzOCHR1cLr5qqHtZO0QRjT1xzRYy5+HtwgelipmKqDeyiMG+zMPH1O+oeuzE
0PGhHs/XDB7ueziCIXEHQ5nV1enzazx8n6F7Xs1dDJkZix6eWufhlmt6V05k
YGiZkZAzQSNwqUf9lv/ex9Apr7HqPmECr5q1LErIx9CP3fwtFWIELpbwOU3s
OYZUWx9KHJQj8KLq8z4i7RhyiZs85qBB4Hd+d7GrYmKIKfSMpv8tgUd7aysH
dGJoo6q3oaImgf8k9KaHwcJQm5m5Jn8Lga/uM6PH9mNIuYcRH69D4G4Ts4bC
fAzZmnWElRkSuO3frRIVJIZq+Vfb/zQicJ2kXL7vewzRO+eKw40JfMnELbdx
CkP3Leo325kQeEFUqWLMJwwZpxKJr3YQeLLrjVnTBQxttwv48cFOAg/X8ukY
/4yhRHvxjCvmBL63VfYGWsaQn/HxEVtLAre8z/ebE2Do0FokR9mKwLeE1kPe
KoZi3/n7fKEshe6qu69haHH3/jC2NYEvKIYur69T/R33VyuzIfD/AQtS7pM=

          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV1Hk8lfkXB3DbRbrWp0XSiIqMFpQrXJ0vjTLIFmlSSsMYg2ghaxIt9mUk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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJw91nk4VVsfB/C9j0ODMSREMoSK6lLJuJaKFBqkSGXInG5CQqb0yjVEmedC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          "]], LineBox[CompressedData["
1:eJxF1HlYTO0bB3DKzJylQgihEt4okSgJnbvQYmlRUalUlES0qexRpFVplSSR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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwt13k4VN//APAxc+/M2JdpUUpIpO2DpPq0nHfKUpSkhZREpbJ8RElZ+iQU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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJw12Hk4Vd/XAPA7nHMNyXRLKkMkFBWFJtorEUWJEhJp0qQyFEoqlTlkCAkh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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJxF13k4VV0XAHCEIsPZ50YlKWODBkSZ6iwUiogGFJUIIYoyVaZQSL1ImoxR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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 1, 0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV03s0ldkbB3DkkjvvbkzF1NBQM2olQqU8TydFCekqxa+LqFAThQplDpJL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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV0nk4l1kUB/CftWzFe4tWDSWKJiVLUeeUGsqWtFhipmyVVo0y2VKiLFkG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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    StyleBox[
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJxF13k01N//wHG7yFIi0YYS7SpUtpeEJqQQKUkqS1F2KUspio+llDYJyVJI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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwV1Hk4lfkXAPBL9i28ZawjRpYQyr50vqPuMCpL0zShNLZUaGdEKSHDEDVF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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJwV1Hk8lfkXB3DbRbrWp0XSiIqMFpQrXJ0vjTLIFmlSSsMYg2ghaxIt9mUk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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJw91nk4VVsfB/C9j0ODMSREMoSK6lLJuJaKFBqkSGXInG5CQqb0yjVEmedC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              "]], 
             Line[CompressedData["
1:eJxF1HlYTO0bB3DKzJylQgihEt4okSgJnbvQYmlRUalUlES0qexRpFVplSSR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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwt13k4VN//APAxc+/M2JdpUUpIpO2DpPq0nHfKUpSkhZREpbJ8RElZ+iQU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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJw12Hk4Vd/XAPA7nHMNyXRLKkMkFBWFJtorEUWJEhJp0qQyFEoqlTlkCAkh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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[1, 0, 0]], 
             Line[CompressedData["
1:eJxF13k4VV0XAHCEIsPZ50YlKWODBkSZ6iwUiogGFJUIIYoyVaZQSL1ImoxR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              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 1, 0]], 
             Line[CompressedData["
1:eJwV03s0ldkbB3DkkjvvbkzF1NBQM2olQqU8TydFCekqxa+LqFAThQplDpJL
VAjjPkoZuURS6BWpEGFw0MXtvLsplZLSkTLv74+99vqsvdfa32fvZ+vuObxx
n4yUlFQaP/4/E4sxz5TkelB336tdtHSQze7qLhbV14NQ++To6yWDrJFf5di0
8XpwOhLsq8/bvjhEGOvcAO0n6vckmw2yEXNV/gzVboRC83GZIJNBdoLoNhxK
ewwXu78tMFkwyIrfrJu3KusJXLxk6OD88yDr7OAwcqy9DZ6qxhdHyw2yqaYP
n3x26QadlBO6Wg8G2GzjEPPzAb0QXFlGK4UDbNC3c06COwPwvGiXMMhigO0/
Oaw/T8KB7cq+1d7ifjZX7kh5itQriCuoMDoY2c9euRa6Q2LzBp7N73uXM6uf
tS85e0b2j2GoXDV1Ttu1Pna+eNvy5pUfIFKv7pGncR/b/NVkhcbgCAS7kDtD
a3tZ3eTMzKT9o2DbYRhu/tsL1uZVmI0//QQfHyoFG0iesdFrSr80ho7Brx3h
s49efMqG/Oqr7KEggZnjMdOoYQ97YcZJg4C8cTjLhba4nu1iAyq/hvWunoC7
n/ttaUsnq86p2MTUfYOcoYXm/todbM1MD6Z43yR4XIqoGpnzD8sMXc1QPSaF
Md3s49fGrazjE8GdIGtptHc1qvjncxP7VWXG2HQtGXR6Wt1QsreeDYox3yfq
lEGhk8Qg5d19Nib+hKgldwpmXbhuKfOEZf1eyJ18e1AWPd0WPyubVsbWhzSh
6W9yOOZcd05BeJXN+/u2UrlEDtvGN6lWSh9j3aa/k3OtkEd3xsqLwWzIV7aW
gxgFFBRPRhtkl4Kr0zMD2x1TUX3tGm8rxWp49fL28RPaihibNrJbYX8dyHyv
aBEPKaJwbF5r6vJG+LhVfrtPgRI6SRiLR5tawEExZoqhtzL+5nFmacVoGywV
LLkxa7kK7tTeuqimpgO+VhleMP2mgsVzu/Q/bOgC2+pVfmeaVfHYv2HWSlJP
4ahcTtTEeTWcEdfYsWv/c1DIwdpUR3Vkx7Pf3L/aC/Hi05MVGhroVn0rUftr
H5xPkjOrOKKBn+eJRI5f+6EzNvWdqEcD89Tsty8eH4CWEsclSgJN7Em+YLfp
6SCYSfJm2mdr4upCD7uFCWLYnrs8c/gvTfRc4PVkdpIYArc065+/rIk/SLxP
qf0phnvFH4zar2rip8YqD5ophvUHl1g7F2ribI3XdqfzxbD7aZ2ve6UmTvbr
TNtZK4boqr7HwZ2a2F33rrhoWAyDIVqnCpUYBJ2wTeUCDqKrlWxNVRg8YDzN
QmE1B4snv2tVqDIYKvXCb7M1B6GBLwseaDD4fljy6pUtBwb+5S+eazHI+VmX
SW3h4KCXs6XKHAavLQjNfe7Owfut6d/2WzA4nOsj2XiWg6SEC/XvljNYmtj9
zDOKg5Xt4QlHLRnsGktXFsZwcMHx8ILTKxkMMjFfl3+eA5P16HLJmkE/YmP1
OpkDv5UDlXWbGKyqfvuB5HEwYWgQqMd3SmSzwyGdeg62DbqmZ3ozaGBs1DDa
wMGNlEvVsw7z+VrLTjQ+5uCAoqKctg+Dlo9au3xbOOikQzEkgME3V+WFRSIO
irKKM2RDGdQd2ujazXGw98cVtfRPBjPUp994KUXhbvMxzi2NQWmVi+aRMhRm
hhcoDKYzaGfxVslQlkLL6Oz1vVkMxlT5pngoUFjeJtMhymXQ54jVtseqFLRi
HtFHJQxaffHXsZpJoUFms9LfjQwaj48KhxZRMJ6SkL22icHiwGgLPxMKKVM6
l/3bzOBbr2lvvy+m4Cnr5KnfxqCZE1mhtISCivzOxxldDP5Qdj1yqiXl+9vt
XDzHv5/EJv+vtRTa1Y8ywZMMpk6nlzb+j8+jcTNPR5rggip3/dRdFC5rfBZU
yBDcV73xyuBuCn6aAb5f5Ai2VhSGeLlR+JEEtvuoEIx8vjt53wEKzlqhiR4z
CKaqVf/yyYdCr078TEcTgncTc05GhFJovm4u+Wcxv/4iJTY4jEKl5VPRVjOC
QeUGnT7hFJJ26SXsXEqwQyV0fEsEhQ05Rer7geAGa9k0+WgK1YZNsqdsCVac
cFyoeZFCQeXvg9J2BJOM811f8061m1YTak8w2K3h7r14CgGHd5yKdCTYmCHW
8EykYFTySpKwjeBuzcuS3GQKmcvkh/P3ElT7cvtBQwaFc43XmhbuI2i5Svlz
eCaFwJ12+TfcCYZqRWxemUXBKTj+QPkBgsc3X0kvyqagUaMnrj1MsPPTsNvx
yxROr4XunpMEX9vYXynJo3CoZ+CWSxDBfmiq2vg3hZ2e4Yl9wQTf2syc8p73
kpimTTSEoPSyJ1r61ym8b9nR/OEMwTAmfNfxQgq7nQJqp8YTzDo/6tVQQmG9
4YbM8gSC96JXbd1RSsHs+9yg/ZcI/t5vKnnFWylHZPYohaCUJM9TqoxC6bBZ
3pksgjNS/KWYcgrpNWpnzP8iGJF8qjSOd0QC3fsyh+Bs+RBd1dsUXCwSf7K+
StBKSs9gkrf8mU9x8oUEL//RJHpYwefb3uRdVkRQ3TfWcXElhZ75l9e53+DP
77olTOdd2LZZ9sFNfr+TRMOrir+vWaX+YZUERfmnm4buUhB8iNpsepegA9yc
uoalMP/+3kUcS9B9ffvXNN7SB8mQVS1B/4IURetqCnk3fVxlGwiuyeq5F3SP
QnzEOovSRoIrLo7cqeMdvENvulsTwVPKcZ7KNRQ2Sbe11rYQnBxa+DGWt2X7
tQLfNoJbDvzU0Mx7Xm5I1Jx2gkaX3J2UaylMrF+0WigiuESfpgTxprMV9Uy6
CR4KVHIo4d060vd9oIegwMf9DuV9JSmuXPCCYMOsy2Vr7lOI89yfMNJL8GFB
gLUv7xOW6JPdT3A4dl9sGm8H8bChDEfwyvDvVkO8l916OPUGJfjpV2GxWh2F
XyIzuN3/Ehybn9ixkLeai3+N5muCLlU5Rfa8vyx0yLg3RNB04prAk/eAzNzA
I2/5fnLPigrj3dTx3Ul3mKC+KDwqjXf51U7T1vcEfxRuFZTwzj5ZwISM8P/5
m0rRA97R9uHDRqN8vYtz20W8/XRdH/d9Iujlq1dEee8aNb0WN0Zw855AwUfe
tg9Vw1FCsFe2JOobb7MUbs/7cYLbK+5HyT2g8LN3FWROEDwiKBIo81bCBJ0N
3wkalxwtUuM9ynhLJicJKgk1O9R5/wf6bMyA
              "]]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]], 
             Line[CompressedData["
1:eJwV0nk4l1kUB/CftWzFe4tWDSWKJiVLUeeUGsqWtFhipmyVVo0y2VKiLFkG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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{0., 4.999999902040816}, {-0.9810610955304192, 
            1.755105252879232}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              AbsoluteThickness[2], 
              RGBColor[0, 0, 1]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PanelPlotLayout" -> <||>, 
          "PlotRange" -> {{0., 4.999999902040816}, {-0.9810610955304192, 
           1.755105252879232}}, "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
          GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             RGBColor[0, 0, 1]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}],
     Selectable->False]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJxF13k01N//wHG7yFIi0YYS7SpUtpeEJqQQKUkqS1F2KUspio+llDYJyVJI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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwV1Hk4lfkXAPBL9i28ZawjRpYQyr50vqPuMCpL0zShNLZUaGdEKSHDEDVF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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJwV1Hk8lfkXB3DbRbrWp0XSiIqMFpQrXJ0vjTLIFmlSSsMYg2ghaxIt9mUk
KkONmZGtsTWy9FjjWu9FLrI9jxvDVbL0s/N75o/zOq/363Ve53z+OspXvG1d
hQQEBNKp+q9jBgseT9JY4GPqGW9hSMKL3r5CLosFepVzSv9Z069yYcsyCxKK
EzlmlHEsw9D222bo1zuZZUrZsjAsPP58MyhckU01oTxg6cJqjWoG3sm5PCPK
HlMnpSUqmsFTYopkUl6OVLc/xW+G2z0rerqUH6rRn0bsbIHAAZUiTcrbGj6P
1Ji3gJO9s7k65T+ucFQ3glqgNuwfmjLlowIlnsy8Fuh5uY/YTrk2PaUoYKAF
Lu/KG5SkbG0QsPia3gp1R8xXhCgP9zoen2e2wqq5sP4Ck4RVTLn5anortO2p
VhikHFUoLJPX1goXGxsq2ynvsBqzn1hrhayjY6E4ZUZULvGjUxv0Pwhw/41y
vVqc2vO4NgiL+xQfQ/lMg4/X0Ns2OJt5mxtA2UeAsXROqR0eBS6zbCivp8tD
ilU73Mkcu8mkHGuwEtEV2g5pMbNIlXKOX7WM5Ug7LDR4MhcMSOBNme0/8bwD
XrYK1sRRvh518OodTgfYrgv5XqcssEW8f0iADZzeb83sKccXTioparGBHznr
IE85b+pVbkoiG04nhgom65Nww+C5ZelLNihHdr31oawflTTTVcOG8Nmz6RaU
WWq+urKzbAiTmqkSpDx2Rb8u2pYDOxpSYp31SMgv1Pgp5xcOFHpF2elSvimw
axPrLgcCGGVMOmXh3zYsRYs5wJBp8ik+RsLuvvr+O1gnGJGjbgu6JJy3spr1
7e4EKW7wr/YMEuYONXx9+rkT9GbKcuUpx0gZLNWId4FqktHbfh0S3rapCkgZ
dkGuk3GnI2UVi3XJP//oglZ1s9c2R0mYNM1X7/HrhqvK733o2iSE799zcDWh
GzgMhcO4FgmK4mmaKrnd4O7RO+5D2bIxQvfqcDdUvWs15WiSUGRywUTU9D2k
ZUw33TtMQpDxZmfGjh6wXZZrqDpAwhaVMJcLR3rAHgs4cJlygeCC293TPSDh
GB8nSHmkmrzaHtYDF7I/GBtpkPAdlAf/NNkDV0YueZaok0BnuqemVHBhUP+3
d+6qJDzTaez438U+qDCzfS2jRELCrp/0nP36YNH9IvHkGxIiaLTfW+L6wH+3
jPpeyp7vjf0y8T5YmwqWOrqLBEPft4pmyv2Az01ofb+ThKGSUvd0Xj+8Vf8w
ZLqdBKWjWcLfeQxAyjuRmXQpKr/iCa+C8AFYyXnxZjNlcRGyR/7ZALiIBmf4
S5LwpUsp51PrAEi++lprRSeh+sZT68eHBmG7Y4r73CYSLhcnpU/ODMJA/BF9
GRr1D7TDdBP9h8F1e4F05jIBdX+40cIShmET/f3i/BIBPHnLLp/sYchdKBL/
nrLahoK3dS81X5/z7PMCAT2u57vEFEfgC/NgyuGvBFzQnpdoDBqBs8X53Q+n
CXBrUQs0MSCgNjo1J3WUgEWRnc6Gpwg4RDvj10kS8PC4lKnOGQJGaqLcN1PO
KZzfus+DgK1FMe8CRwiYelxTKPKUgMyKFEerQQKuuzhO1FE5XwdXLXT0EBCy
FnfOuJyEPYcy1A+zCPALrZ82bCRBrYzL0W8iwEdw+b5eNwlPcx2CTRoJcKG5
lmp+JsHB167XoYEAM0kDOSWVUVCysM33qSFg267xlpXIUXiuR+u+/oaAV0yA
0h94MCt0x/FNNgFE0PS+/UsfYUtqZ55NBAHid/W+mNDGoC05sUE7nADNh+Hl
P8qOwV+Dfwtjdwm4nbzdKkN9DI6X6n5hhxKgkA/+286PwXJtULRxEAG2Q/HN
IhVj8KIyo2v1GgH1SNObCB4HSZiaaXMi4C/atbInAhOwFHmqgqdDwJ8vIxyX
TKdg3/ylE7mcEbAsjnwgcncalI1sD8pfHoEDPAdmu9EMeNzwW8vjDEP7yhFD
mdFZMAjdf/xR0RAop2Vmpv48DyYdYjLXYgbBdOKe6a2xrzCxr+uTjt0AxJws
WWyJWADdkDsz3uP9EKZ+Y7Ob2BKYRSiy3YL6IGlHkKp/zjJ80o88RnK54F+5
cm/YZBVo27Otqvf0gPRHumlswxrM/5glpePfDbUKbnKFrhtwj9Z/rDmpE+T4
2RmSvgJoLjlVy6ycDTYdxuUhpwSRUj47yN+iDVboOxbktwkhT0eyxEOWBSGx
uq7cHiEUHdzJHF+vh9jkQC77L2G0e/1009CNavAbogV9+kUEMaoPWvRplwEr
rA3pfEtDIyFDqUlfCiAn941E2RINHZ/Odf1V5zG4yH+mOVWIoo0jdjEOO6Px
vM2naBArhqJ6u2fPiOXiTucGVM0dxZHwmSjOhSf/4BPjbwICd25CWiLcVeuE
alxovYLN429CpdJigWJNDfjcWdEfrhdIoNXftzaFFzbjVptihTW8NiOOzPd7
D0V14HrGx4q+YdLRgfvq38W7d+IrVRpJOmt0JBewkcUlu3Hz6hN+D9olkcEt
z/m4JC5+k5YVvZoohdTLB3z6t/TjYlmo7pmNNBJzlzWpjRzAk3l3NipkZNCy
l7QGXXsYT0ylMSquyaCbVT4Gqu9H8J74Z5+5/TLog71lWpM6ibOLbY5JGMui
H0DV+53vKM5YylGwfCGLtiRybXjZPHw0bFvoKwk5RF9tkM6b/YivaqgGq3jK
oacGWi/27xnHm4XsJHJb5NCHFLsgNbN/8WHFZAWbIxjymxfMnLk3gTuf868T
T8bQNd6tS9bZk7iFhnVm2SMMKTQYYQ75kzhjXS3k58cYSteuvHqxaBKXyOIy
mp5gSNfqZ0X3ykm8ZJqR8+A5horcVK2D2ZO46IOvCaKvMBQikEZLWpzEc0qv
O4k0Y+hcMIceaMrHkx+aGZS0YOiihHe072k+fttRRd6lDUPGIosFPrZ8/Ixg
J6eOjSFWhC/P9QIfX7XQMgnnYkjHvkbUwoePW/GmNYQ+YmifMWurWCof1/+n
UbxoDENrl4T7Vp/x8b1RGR+d/8VQgQsHZp/z8cXDVhk1fAyhE90LH3L5+Iug
ArmwWQx1vd8rnYvz8RjL+9Oa8xj6+1b+VHo9H/dTdmod+UrtF1T2SmDxcfNG
yftoCUNa3Jtnb3bxccaTj1e+LGPoMlMDd+3l47u9qiBzFUN25f7NZwf5uAR6
pGi9jqFmb1P/UyQfn5fzWtrYoO7dvdekO87H/w8Xg97U
          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJw91nk4VVsfB/C9j0ODMSREMoSK6lLJuJaKFBqkSGXInG5CQqb0yjVEmedC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          "]], 
         Line[CompressedData["
1:eJxF1HlYTO0bB3DKzJylQgihEt4okSgJnbvQYmlRUalUlES0qexRpFVplSSR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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwt13k4VN//APAxc+/M2JdpUUpIpO2DpPq0nHfKUpSkhZREpbJ8RElZ+iQU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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJw12Hk4Vd/XAPA7nHMNyXRLKkMkFBWFJtorEUWJEhJp0qQyFEoqlTlkCAkh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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJxF13k4VV0XAHCEIsPZ50YlKWODBkSZ6iwUiogGFJUIIYoyVaZQSL1ImoxR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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 1, 0]], 
         Line[CompressedData["
1:eJwV03s0ldkbB3DkkjvvbkzF1NBQM2olQqU8TydFCekqxa+LqFAThQplDpJL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          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]], 
         Line[CompressedData["
1:eJwV0nk4l1kUB/CftWzFe4tWDSWKJiVLUeeUGsqWtFhipmyVVo0y2VKiLFkG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          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PanelPlotLayout" -> <||>, 
       "PlotRange" -> {{0., 4.999999902040816}, {-0.9810610955304192, 
        1.755105252879232}}, "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
       "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
       GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          RGBColor[0, 0, 1]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{502.68646240234375`, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.999999902040816}, {-0.9810610955304192, 
   1.755105252879232}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.921767733837853*^9, 3.92176781078128*^9, 3.921767845700141*^9, {
   3.9217700618558693`*^9, 3.921770121022317*^9}, 3.922105669836732*^9, 
   3.922105721472352*^9, {3.922105882409622*^9, 3.922105906100602*^9}, 
   3.9221059483061247`*^9, {3.922105984003936*^9, 3.922106003618525*^9}, {
   3.9221073273278837`*^9, 3.9221073732259283`*^9}, {3.922107804548157*^9, 
   3.922107811945222*^9}, {3.9221175807085114`*^9, 3.922117593148942*^9}, {
   3.9221892435746098`*^9, 3.922189277287222*^9}, 3.922189320002033*^9, 
   3.922189539020043*^9, {3.922189569640163*^9, 3.922189598126857*^9}, 
   3.922189877622743*^9, 3.922189912065086*^9, 3.9221900024335136`*^9, 
   3.92219062546271*^9, 3.92219069512157*^9, {3.922214100106464*^9, 
   3.9222141359806957`*^9}, 3.9222141877592907`*^9},
 CellLabel->
  "Out[3552]=",ExpressionUUID->"71703006-8d24-4ccf-bd57-cddc44a72370"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9217678220413227`*^9, 3.921767827430851*^9}},
 CellLabel->
  "In[3646]:=",ExpressionUUID->"eac26ca2-253e-4066-a9ba-80d6fddac92c"]
}, Closed]]
}, Open  ]]
},
WindowSize->{1184, 911},
WindowMargins->{{201, Automatic}, {Automatic, 23}},
FrontEndVersion->"14.0 for Mac OS X x86 (64-bit) (December 12, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3e6a5fe9-5ac0-4a3d-a7c6-6e6ff1f351cd"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 166, 3, 69, "Chapter",ExpressionUUID->"23601fc3-e0e5-4798-8a4b-a7d16a3bcd44"],
Cell[CellGroupData[{
Cell[771, 29, 160, 3, 67, "Section",ExpressionUUID->"c7ed6467-48d7-42a3-aca2-a8261b9fba92"],
Cell[934, 34, 462, 9, 35, "Text",ExpressionUUID->"3b5c7d96-f407-4175-a36b-70a68849c994"],
Cell[CellGroupData[{
Cell[1421, 47, 407, 7, 52, "Code",ExpressionUUID->"449ee415-9749-497e-9f30-59a880abade1"],
Cell[1831, 56, 307, 5, 34, "Output",ExpressionUUID->"0661305a-8618-4bbd-a5cb-23f706295e35"]
}, Open  ]],
Cell[2153, 64, 243, 4, 35, "Text",ExpressionUUID->"9a762c31-5374-40b5-be1f-200e16b19914"],
Cell[CellGroupData[{
Cell[2421, 72, 998, 29, 75, "Code",ExpressionUUID->"87194c35-81e1-44c5-83d4-7ac94719265f"],
Cell[3422, 103, 706, 19, 34, "Output",ExpressionUUID->"76648d72-e1a9-47ee-9ff4-f1df315673f4"]
}, Open  ]],
Cell[4143, 125, 523, 9, 58, "Text",ExpressionUUID->"b958213a-f532-43f0-b69e-26c60017b2fd"],
Cell[CellGroupData[{
Cell[4691, 138, 2675, 73, 255, "Code",ExpressionUUID->"3dab6a2a-3768-4e20-99d3-4e982fdd22a0"],
Cell[7369, 213, 738, 12, 34, "Output",ExpressionUUID->"03bf7523-0e2d-4cc6-9b2b-3a4bcc852985"],
Cell[8110, 227, 736, 12, 34, "Output",ExpressionUUID->"dd5d4189-f9e7-4003-b765-fd5cacef2098"]
}, Open  ]],
Cell[8861, 242, 1165, 22, 173, "Text",ExpressionUUID->"60803014-f32d-4fda-96f8-cb987c21117c"],
Cell[10029, 266, 10102, 198, 852, "Code",ExpressionUUID->"1fc4fead-e35e-4041-b6ee-28b0d9ccffe0"],
Cell[CellGroupData[{
Cell[20156, 468, 2057, 46, 132, "Code",ExpressionUUID->"4eb19f65-833f-4e8b-9808-37d43ec6f9cf",
 InitializationCell->False],
Cell[22216, 516, 874, 18, 44, "Print",ExpressionUUID->"7a72eda6-b2f5-4427-a3a0-375fd33f35d1"],
Cell[23093, 536, 74090, 1310, 242, "Output",ExpressionUUID->"f6649820-ba36-4f18-a7a0-4de4659b60d6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97232, 1852, 224, 4, 67, "Section",ExpressionUUID->"1ecec569-c719-4c5b-a58d-b38e56023403"],
Cell[CellGroupData[{
Cell[97481, 1860, 169, 3, 54, "Subsection",ExpressionUUID->"0a33d9a9-249e-4d2b-8ba4-9267eba4d7e9"],
Cell[CellGroupData[{
Cell[97675, 1867, 1054, 17, 52, "Input",ExpressionUUID->"4deff788-0de7-4c0b-abe4-226632fdbf71"],
Cell[98732, 1886, 1185, 22, 44, "Print",ExpressionUUID->"97919744-7f5d-498e-895b-09af8727bef2"]
}, Open  ]],
Cell[99932, 1911, 307, 7, 35, "Text",ExpressionUUID->"3d704d37-c02b-415f-af17-b13072b45150"],
Cell[CellGroupData[{
Cell[100264, 1922, 1128, 30, 110, "Code",ExpressionUUID->"3abb3b64-82ae-4894-a13f-96b2c6f5f8ab",
 InitializationCell->False],
Cell[101395, 1954, 1131, 21, 44, "Print",ExpressionUUID->"068a7057-35e4-494e-89c5-7165129306ed"],
Cell[102529, 1977, 1772, 26, 140, "Output",ExpressionUUID->"fb5ac1c4-80d5-489c-abc5-864591e2fd31"]
}, Open  ]],
Cell[104316, 2006, 376, 8, 58, "Text",ExpressionUUID->"cd72045f-e24e-4622-8744-d92506318a92"],
Cell[CellGroupData[{
Cell[104717, 2018, 937, 19, 68, "Input",ExpressionUUID->"510dd3c1-7640-4524-8088-c40e9ea08bee"],
Cell[105657, 2039, 1263, 18, 34, "Output",ExpressionUUID->"3389e324-b154-4e91-a927-ff0205f40e0d"]
}, Open  ]],
Cell[106935, 2060, 357, 7, 58, "Text",ExpressionUUID->"68e3c5b8-c6ae-4dff-a056-6962078a599a"],
Cell[CellGroupData[{
Cell[107317, 2071, 2170, 47, 133, "Input",ExpressionUUID->"7337113a-f989-40b3-8498-c51cfeae7378"],
Cell[109490, 2120, 1112, 20, 44, "Print",ExpressionUUID->"7527d1ec-14f4-4e8f-aa1c-eda06a6cac6c"],
Cell[110605, 2142, 1425, 21, 119, "Output",ExpressionUUID->"3b5b5658-e01a-4ada-9b27-d09375d8a1b3"],
Cell[112033, 2165, 38326, 706, 237, "Output",ExpressionUUID->"78d05b80-bebc-4005-98ce-14071ca2f9d9"]
}, Open  ]],
Cell[150374, 2874, 168, 3, 35, "Text",ExpressionUUID->"01e3f48d-798c-475e-bcd1-47d470fb9c5b"],
Cell[CellGroupData[{
Cell[150567, 2881, 607, 16, 46, "Input",ExpressionUUID->"d2342067-00a4-4ade-afce-b3bbe24557f3"],
Cell[151177, 2899, 13763, 288, 237, "Output",ExpressionUUID->"3de9594c-0698-4f87-ba66-a39a639b1304"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[164989, 3193, 172, 3, 54, "Subsection",ExpressionUUID->"6a09cccf-4668-4b7c-bc21-f471f4eb208c"],
Cell[CellGroupData[{
Cell[165186, 3200, 492, 9, 52, "Input",ExpressionUUID->"0aaa9d2a-5ed6-470a-9b6c-ed30742fc436"],
Cell[165681, 3211, 743, 15, 44, "Print",ExpressionUUID->"884cb999-21ea-4f5f-87a1-d6c6a3b26b06"]
}, Open  ]],
Cell[166439, 3229, 286, 6, 35, "Text",ExpressionUUID->"17281b20-9a2f-42ff-b13b-a84329301fcd"],
Cell[CellGroupData[{
Cell[166750, 3239, 1190, 20, 68, "Input",ExpressionUUID->"3427c13f-c2f9-4d7d-be26-34a0bd935d8a"],
Cell[167943, 3261, 856, 17, 44, "Print",ExpressionUUID->"a6dc728b-22a9-47a1-842c-3c6d9b3eb50c"]
}, Open  ]],
Cell[168814, 3281, 910, 18, 46, "Input",ExpressionUUID->"47c68847-3877-4279-a323-8987345e637d"],
Cell[169727, 3301, 311, 7, 58, "Text",ExpressionUUID->"55811c6a-95f6-4cb6-8b16-d597fdbdc53e"],
Cell[CellGroupData[{
Cell[170063, 3312, 2449, 54, 154, "Input",ExpressionUUID->"f3cac34a-b41d-4d06-b426-81569ca25e39"],
Cell[CellGroupData[{
Cell[172537, 3370, 972, 18, 44, "Print",ExpressionUUID->"8ff99ac9-2fc1-43c3-aa9e-ff36664188da"],
Cell[173512, 3390, 706, 13, 25, "Print",ExpressionUUID->"f7adf1a9-c0e6-4396-8b24-eb15080aa1ba"]
}, Open  ]],
Cell[174233, 3406, 58223, 1033, 237, "Output",ExpressionUUID->"4e075dd1-d1e0-4761-b178-a4fb0676f193"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232493, 4444, 925, 21, 112, "Input",ExpressionUUID->"81ba87eb-c6c9-4a12-8f86-0d92d68f03c8"],
Cell[233421, 4467, 741, 15, 44, "Print",ExpressionUUID->"e4a3ede6-b66e-4ce9-88cb-6ae5d251e303"],
Cell[234165, 4484, 507, 8, 34, "Output",ExpressionUUID->"a81b67a0-2778-433b-9b03-0669213fc293"],
Cell[234675, 4494, 528, 8, 34, "Output",ExpressionUUID->"25d6a2a7-ac82-453b-b6d4-8f6c93b4a3c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235240, 4507, 885, 21, 46, "Input",ExpressionUUID->"bbc96b7b-0c89-4c16-9f7c-698245ec32a6"],
Cell[236128, 4530, 15227, 317, 234, "Output",ExpressionUUID->"d4700a12-b7ce-41d9-bdff-f74e9ccae251"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[251416, 4854, 161, 3, 67, "Section",ExpressionUUID->"d94d888e-ec2a-43c0-931f-f217936de121"],
Cell[251580, 4859, 569, 15, 46, "Input",ExpressionUUID->"1c98e6f1-af0f-4f5a-bcc0-6dfd58a894e5"],
Cell[CellGroupData[{
Cell[252174, 4878, 174, 3, 54, "Subsection",ExpressionUUID->"2a3133d3-f718-4076-a504-7d2b056ec1fd"],
Cell[252351, 4883, 234, 5, 30, "Input",ExpressionUUID->"ce7a7d34-f866-445e-aa9a-d78bcf57ea8d"],
Cell[252588, 4890, 192, 3, 35, "Text",ExpressionUUID->"31b900d5-1050-4e85-be95-6b52e0deb81b"],
Cell[CellGroupData[{
Cell[252805, 4897, 1006, 20, 72, "Code",ExpressionUUID->"e3723530-37e6-4744-b85a-ae4515ebc664",
 InitializationCell->False],
Cell[253814, 4919, 627, 13, 44, "Print",ExpressionUUID->"660116db-7860-499b-9719-11114c59e244"]
}, Open  ]],
Cell[254456, 4935, 169, 3, 35, "Text",ExpressionUUID->"fa4765c9-c3f0-4795-abe5-dda6d9cd4aec"],
Cell[CellGroupData[{
Cell[254650, 4942, 1200, 23, 72, "Code",ExpressionUUID->"99e00cf2-6fca-4405-a048-13c3f163d6aa",
 InitializationCell->False],
Cell[255853, 4967, 654, 14, 44, "Print",ExpressionUUID->"5c0a0382-724d-44ae-9cff-32812350d099"]
}, Open  ]],
Cell[256522, 4984, 255, 4, 35, "Text",ExpressionUUID->"64874937-abc5-405c-ae1f-9eafc9048092"],
Cell[CellGroupData[{
Cell[256802, 4992, 846, 20, 112, "Input",ExpressionUUID->"e1a5b057-c311-4c96-bb6a-910d65381e37"],
Cell[257651, 5014, 392, 6, 48, "Output",ExpressionUUID->"a1ceca30-7996-40fd-b8bf-ab0adf8e309c"],
Cell[258046, 5022, 394, 6, 48, "Output",ExpressionUUID->"a35df2be-1b37-4a77-8f39-74e9129047aa"],
Cell[258443, 5030, 409, 6, 48, "Output",ExpressionUUID->"7e29495c-d5fd-4142-805e-d4630ca4cfcd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258889, 5041, 2274, 50, 133, "Input",ExpressionUUID->"bbfa349b-70c7-4143-8ee3-6acd79f2c2f1"],
Cell[CellGroupData[{
Cell[261188, 5095, 679, 14, 44, "Print",ExpressionUUID->"abe4f38f-ddb8-4f1c-b946-465e5f5af172"],
Cell[261870, 5111, 427, 10, 24, "Print",ExpressionUUID->"8bba4347-b227-4c69-9c62-3b3353d365a1"]
}, Open  ]],
Cell[262312, 5124, 63472, 1119, 251, "Output",ExpressionUUID->"784d2969-25e6-4eb9-8514-cebd7ecf8c60"]
}, Open  ]],
Cell[325799, 6246, 1586, 40, 175, "Code",ExpressionUUID->"d71516d4-549d-4298-89d5-715941d1cff5"],
Cell[CellGroupData[{
Cell[327410, 6290, 263, 5, 30, "Input",ExpressionUUID->"978652c0-74b9-4a66-b525-1fe86fd4e670"],
Cell[327676, 6297, 662, 15, 44, "Print",ExpressionUUID->"8876470b-cc03-4b99-a2e0-e582d5d4c221"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328375, 6317, 1170, 25, 133, "Input",ExpressionUUID->"c90f095b-00c1-41d7-855f-01e1a59bcaf9"],
Cell[CellGroupData[{
Cell[329570, 6346, 793, 16, 44, "Print",ExpressionUUID->"65855a46-dee9-483c-a3c4-56900890f00d"],
Cell[330366, 6364, 546, 12, 24, "Print",ExpressionUUID->"a5a2c6bc-077f-4166-89da-d995a7e8505d"]
}, Open  ]],
Cell[330927, 6379, 3277, 90, 112, "Output",ExpressionUUID->"48815ae3-36f7-4876-9a3e-7386ae575b25"],
Cell[334207, 6471, 16779, 393, 265, "Output",ExpressionUUID->"d08b05be-5081-4a80-9498-3acd66ff8749"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351023, 6869, 851, 21, 91, "Input",ExpressionUUID->"ffcacb68-5c46-4934-ba53-a2d9fbf2afd5"],
Cell[351877, 6892, 379, 9, 24, "Print",ExpressionUUID->"2f3e7a22-4eb8-4d76-b7aa-8a192df10c77"],
Cell[352259, 6903, 5723, 164, 217, "Output",ExpressionUUID->"d3da2549-880d-465d-b870-c34265c9b99e"],
Cell[357985, 7069, 14625, 331, 264, "Output",ExpressionUUID->"3f64f5a5-4447-43a4-aef6-874a7442a5fe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372647, 7405, 2152, 54, 134, "Code",ExpressionUUID->"0c066f68-58e5-4bc9-8211-f743bc6f2a44",
 InitializationCell->False],
Cell[374802, 7461, 68324, 1200, 251, "Output",ExpressionUUID->"259a0c39-14b3-472e-ae53-1d31c10682e7"],
Cell[443129, 8663, 250, 5, 48, "Output",ExpressionUUID->"47111b3f-b3cc-4eeb-8fd7-bfd7d3507350"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[443428, 8674, 171, 3, 38, "Subsection",ExpressionUUID->"0bb42eaa-94fb-48b5-a3ef-5e38d8220984"],
Cell[443602, 8679, 299, 7, 35, "Text",ExpressionUUID->"f633b059-a9e7-4556-bb7c-f182ed0445ed"],
Cell[CellGroupData[{
Cell[443926, 8690, 977, 23, 89, "Input",ExpressionUUID->"82f19390-acc6-4eec-82c7-93c1f0424b29"],
Cell[444906, 8715, 391, 7, 34, "Output",ExpressionUUID->"90095aa4-5704-4323-b3d8-e4f1c38d1be3"]
}, Open  ]],
Cell[445312, 8725, 233, 6, 35, "Text",ExpressionUUID->"1384368d-8026-4d97-83b6-6f90a740c49a"],
Cell[CellGroupData[{
Cell[445570, 8735, 926, 17, 91, "Code",ExpressionUUID->"17578c4a-803b-4deb-921f-36f6d47c4c11",
 InitializationCell->False],
Cell[446499, 8754, 1404, 27, 60, "Output",ExpressionUUID->"4c88185f-5d78-4a44-b7a4-f711cfd9d6df"],
Cell[447906, 8783, 1506, 29, 102, "Output",ExpressionUUID->"9be1f712-436a-4177-af9c-eb30080e3747"],
Cell[449415, 8814, 418, 6, 34, "Output",ExpressionUUID->"9817e094-e247-4b43-9eba-0efc71e0269e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449870, 8825, 2073, 48, 112, "Input",ExpressionUUID->"de48d650-ae75-4e17-9b51-ce104c50ae2b"],
Cell[451946, 8875, 42337, 773, 251, "Output",ExpressionUUID->"c8df772a-6cfd-4fa4-bc72-d45805fbc83b"],
Cell[494286, 9650, 393, 7, 48, "Output",ExpressionUUID->"e629fe4d-db4a-4cd1-89c0-7c34cfc145be"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[494740, 9664, 210, 4, 67, "Section",ExpressionUUID->"219b7d6a-bc4d-4fe4-9964-db2508dfa524"],
Cell[494953, 9670, 269, 6, 46, "Input",ExpressionUUID->"e65b88f7-3757-4ae2-9613-f3ae8c5ccace"],
Cell[495225, 9678, 195, 3, 35, "Text",ExpressionUUID->"57586e85-660a-4ee3-9260-67e3ff55fcef"],
Cell[495423, 9683, 685, 16, 46, "Input",ExpressionUUID->"da68f7b1-5baa-4e8f-8f24-811cd67dc0fb"],
Cell[CellGroupData[{
Cell[496133, 9703, 260, 5, 30, "Input",ExpressionUUID->"9d4b5339-cb31-4b55-a117-9bc1b21bec60"],
Cell[496396, 9710, 679, 15, 44, "Print",ExpressionUUID->"2e842825-784d-4986-92ef-9d90a6d8a095"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497112, 9730, 174, 3, 54, "Subsection",ExpressionUUID->"ce16388b-7869-44fe-92b2-17e27a023a02"],
Cell[497289, 9735, 192, 3, 35, "Text",ExpressionUUID->"34c6516b-e321-4e10-b8f9-a48a2df6890b"],
Cell[CellGroupData[{
Cell[497506, 9742, 1102, 22, 72, "Code",ExpressionUUID->"c3b10ff8-721e-4965-845c-5c1f16612049",
 InitializationCell->False],
Cell[498611, 9766, 827, 18, 44, "Print",ExpressionUUID->"b56022e3-96a1-469f-8e5c-2759fe53b19f"]
}, Open  ]],
Cell[499453, 9787, 169, 3, 35, "Text",ExpressionUUID->"8dd7f499-62c1-42bd-b462-834d12e645f5"],
Cell[CellGroupData[{
Cell[499647, 9794, 1242, 24, 72, "Code",ExpressionUUID->"d07665cb-82d3-4d91-8718-4c9af34ffaca",
 InitializationCell->False],
Cell[500892, 9820, 845, 17, 44, "Print",ExpressionUUID->"8a37d5ce-b57b-4a38-a384-85ea09051466"]
}, Open  ]],
Cell[501752, 9840, 279, 4, 35, "Text",ExpressionUUID->"282b8367-8fd5-44b6-8a10-37441c4d2ae6"],
Cell[CellGroupData[{
Cell[502056, 9848, 894, 21, 112, "Input",ExpressionUUID->"57aca6da-31d6-440d-a6fc-315b19286a3f"],
Cell[502953, 9871, 584, 9, 34, "Output",ExpressionUUID->"7448f1b4-3129-4ac6-aa2a-df622ffd626f"],
Cell[503540, 9882, 585, 9, 34, "Output",ExpressionUUID->"5b5142cc-c1b2-43b6-9e4c-692bd29eeb63"],
Cell[504128, 9893, 600, 9, 34, "Output",ExpressionUUID->"edf90766-4b86-48a0-b89b-16792c47e40b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[504765, 9907, 2323, 51, 133, "Input",ExpressionUUID->"3afcc535-ec34-4020-84c4-b6344ef52bf8"],
Cell[CellGroupData[{
Cell[507113, 9962, 753, 16, 44, "Print",ExpressionUUID->"3cf51bf0-8d8f-4e88-9ac7-4a7c3bfa8fbd"],
Cell[507869, 9980, 494, 11, 25, "Print",ExpressionUUID->"373fc8d6-9f33-4787-89b3-f8b98b4537dd"]
}, Open  ]],
Cell[508378, 9994, 67846, 1189, 237, "Output",ExpressionUUID->"0e954208-75c4-4526-af8a-a504906d0558"]
}, Open  ]],
Cell[576239, 11186, 2824, 71, 298, "Code",ExpressionUUID->"54b085b1-bccb-4084-a6d1-ed263fc4bafb"],
Cell[CellGroupData[{
Cell[579088, 11261, 261, 5, 30, "Input",ExpressionUUID->"6744cd1a-2174-40e9-bc2f-8dd6b53ea2d4"],
Cell[579352, 11268, 686, 15, 44, "Print",ExpressionUUID->"ffaba0d8-7e1d-4dc2-98f6-996cf3e4cccc"]
}, Open  ]],
Cell[580053, 11286, 226, 5, 35, "Text",ExpressionUUID->"3ad2e352-2a38-48cc-be8d-4489d41d8927"],
Cell[CellGroupData[{
Cell[580304, 11295, 1378, 29, 133, "Input",ExpressionUUID->"aef97820-b371-43ca-af0d-e257c6a5b72c"],
Cell[CellGroupData[{
Cell[581707, 11328, 918, 19, 44, "Print",ExpressionUUID->"4f3d8b07-732d-49b5-b04d-a5991b0f7764"],
Cell[582628, 11349, 665, 14, 25, "Print",ExpressionUUID->"8f089455-e43c-40e6-9ac2-30a7eca052e9"]
}, Open  ]],
Cell[583308, 11366, 1355, 32, 34, "Output",ExpressionUUID->"0b4eea42-b016-47bd-899b-df91f0d179f7"],
Cell[584666, 11400, 14296, 333, 251, "Output",ExpressionUUID->"838d3bf4-fea4-43c8-be05-133c0765579c"]
}, Open  ]],
Cell[598977, 11736, 186, 3, 35, "Text",ExpressionUUID->"0fb3b5f0-af04-4eb8-8268-9d4de5a60dee"],
Cell[CellGroupData[{
Cell[599188, 11743, 1443, 30, 133, "Input",ExpressionUUID->"8be18d89-7e86-46f2-8643-3cee1b926a0b"],
Cell[CellGroupData[{
Cell[600656, 11777, 660, 15, 44, "Print",ExpressionUUID->"01284a8c-610b-4a57-a588-6769f4ee5a5c"],
Cell[601319, 11794, 370, 9, 24, "Print",ExpressionUUID->"115eacc5-6935-4938-95be-c1a28dbba0c0"]
}, Open  ]],
Cell[601704, 11806, 713, 24, 48, "Output",ExpressionUUID->"36cc54a8-c82c-41ee-bc52-53eabee73d54"],
Cell[602420, 11832, 11289, 262, 265, "Output",ExpressionUUID->"93579492-4eb8-4776-a229-80e4a06f2537"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613746, 12099, 2202, 55, 134, "Code",ExpressionUUID->"3525025a-e85d-4e1f-bf66-760c776d5eeb",
 InitializationCell->False],
Cell[615951, 12156, 39058, 720, 251, "Output",ExpressionUUID->"16d4a813-518e-45f7-99b5-5e60af0a5531"],
Cell[655012, 12878, 252, 5, 48, "Output",ExpressionUUID->"e6c68a29-0402-4b04-9a57-5403937c09fc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[655325, 12890, 157, 3, 53, "Section",ExpressionUUID->"6202bcfc-a983-4aca-8e35-40a78811fa40"],
Cell[655485, 12895, 339, 7, 58, "Text",ExpressionUUID->"68ec75cd-a745-44a9-a48e-a4bc322c9d90"],
Cell[CellGroupData[{
Cell[655849, 12906, 392, 8, 52, "Input",ExpressionUUID->"44be5302-bf35-4094-85bd-bd083720d316"],
Cell[CellGroupData[{
Cell[656266, 12918, 311, 7, 24, "Print",ExpressionUUID->"e261a5f2-348a-44ac-b362-2cfd58506086"],
Cell[656580, 12927, 686, 14, 44, "Print",ExpressionUUID->"cee26893-70c1-42c5-b2de-f5038a7f1875"]
}, Open  ]]
}, Open  ]],
Cell[657293, 12945, 922, 24, 73, "Input",ExpressionUUID->"c6171874-df8e-4847-9d93-edf6f6b2bb71"],
Cell[CellGroupData[{
Cell[658240, 12973, 3139, 94, 389, "Input",ExpressionUUID->"68b613fb-1c27-4221-928f-586b28ed6d96"],
Cell[661382, 13069, 1761, 31, 60, "Output",ExpressionUUID->"0c0f2f9e-46bb-4099-ba3c-00d25b651057"],
Cell[663146, 13102, 919, 16, 34, "Output",ExpressionUUID->"0f8056a6-af20-40f8-b1e2-cdad552c591b"],
Cell[664068, 13120, 882, 15, 34, "Output",ExpressionUUID->"b5b1e17a-1e06-4184-a712-59e759739c09"],
Cell[664953, 13137, 1270, 25, 34, "Output",ExpressionUUID->"14941564-965c-4354-9c54-58005e01c1eb"],
Cell[666226, 13164, 1984, 46, 56, "Output",ExpressionUUID->"f023f908-f49f-459c-9cfb-f2103e322da6"],
Cell[668213, 13212, 853, 13, 34, "Output",ExpressionUUID->"d74ab9a5-c2df-47a5-a90f-4e57c6208ad9"],
Cell[669069, 13227, 984, 18, 34, "Output",ExpressionUUID->"53caf9ec-6f47-47c4-aca6-938c2aef76c8"],
Cell[670056, 13247, 1184, 21, 34, "Output",ExpressionUUID->"00b12884-a869-4209-b732-525b53ee2e82"],
Cell[671243, 13270, 1812, 33, 56, "Output",ExpressionUUID->"232f2726-2570-414f-8641-8aa3e34f89ba"],
Cell[673058, 13305, 927, 16, 37, "Output",ExpressionUUID->"d122d0b0-4521-468e-ac55-3f52a9927039"],
Cell[673988, 13323, 857, 13, 34, "Output",ExpressionUUID->"d9db2bff-7972-410f-8782-1e71d7f31b49"],
Cell[674848, 13338, 1212, 21, 60, "Output",ExpressionUUID->"83f54594-e8fb-428e-8ae7-7b020f0eca66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676097, 13364, 194, 3, 52, "Input",ExpressionUUID->"b4231899-7689-4923-bc3b-74255e9f666b"],
Cell[676294, 13369, 313, 7, 34, "Output",ExpressionUUID->"62704376-c612-43b7-b21c-c81d7effebcf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676644, 13381, 269, 5, 30, "Input",ExpressionUUID->"248b69be-a04b-4c71-abbe-2b8f84f85eb1"],
Cell[676916, 13388, 1223, 31, 56, "Output",ExpressionUUID->"9ac65a60-91be-450d-b112-c036a6f8e439"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[678188, 13425, 167, 3, 53, "Section",ExpressionUUID->"0d8f6300-c53a-4639-ab1f-2c6f7a0816a6"],
Cell[CellGroupData[{
Cell[678380, 13432, 2514, 59, 136, "Input",ExpressionUUID->"051783ed-164a-4acf-bc3b-acccd8df9853"],
Cell[680897, 13493, 910, 18, 44, "Print",ExpressionUUID->"46c484e0-40cf-4dc0-9fe7-1654be1ac831"],
Cell[681810, 13513, 222314, 3774, 339, "Output",ExpressionUUID->"97b471b6-f74f-4ee3-a3d5-eef5e3ca5d54"],
Cell[904127, 17289, 158937, 2743, 335, "Output",ExpressionUUID->"71703006-8d24-4ccf-bd57-cddc44a72370"]
}, Open  ]],
Cell[1063079, 20035, 267, 6, 30, "Input",ExpressionUUID->"eac26ca2-253e-4066-a9ba-80d6fddac92c"]
}, Closed]]
}, Open  ]]
}
]
*)

